@@ -39,9 +39,9 @@ static gpointer vala_ccode_break_statement_parent_class = NULL;
 
 static void vala_ccode_break_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeBreakStatement * self;
-	self = ((ValaCCodeBreakStatement*) (base));
+	self = (ValaCCodeBreakStatement*) base;
 	g_return_if_fail (writer != NULL);
-	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (((ValaCCodeNode*) (self))));
+	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line ((ValaCCodeNode*) self));
 	vala_ccode_writer_write_string (writer, "break;");
 	vala_ccode_writer_write_newline (writer);
 }
@@ -52,7 +52,7 @@ static void vala_ccode_break_statement_real_write (ValaCCodeNode* base, ValaCCod
  */
 ValaCCodeBreakStatement* vala_ccode_break_statement_construct (GType object_type) {
 	ValaCCodeBreakStatement* self;
-	self = ((ValaCCodeBreakStatement*) (g_type_create_instance (object_type)));
+	self = (ValaCCodeBreakStatement*) g_type_create_instance (object_type);
 	return self;
 }
 
