@@ -58,8 +58,8 @@ ValaCCodeLineDirective* vala_ccode_line_directive_construct (GType object_type,
 ValaCCodeLineDirective* vala_ccode_line_directive_new (const char* _filename, gint _line);
 const char* vala_ccode_line_directive_get_filename (ValaCCodeLineDirective* self);
 void vala_ccode_line_directive_set_filename (ValaCCodeLineDirective* self, const char* value);
-gint vala_ccode_line_directive_get_line (ValaCCodeLineDirective* self);
-void vala_ccode_line_directive_set_line (ValaCCodeLineDirective* self, gint value);
+gint vala_ccode_line_directive_get_line_number (ValaCCodeLineDirective* self);
+void vala_ccode_line_directive_set_line_number (ValaCCodeLineDirective* self, gint value);
 GType vala_ccode_line_directive_get_type (void);
 
 
