@@ -1,6 +1,6 @@
 /* valaccodenode.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -43,27 +43,42 @@ typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 #define VALA_CCODE_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_NODE, ValaCCodeNodeClass))
 
 typedef struct _ValaCCodeNodePrivate ValaCCodeNodePrivate;
+typedef struct _ValaParamSpecCCodeNode ValaParamSpecCCodeNode;
 
 /**
  * Represents a node in the C code tree.
  */
 struct _ValaCCodeNode {
-	GObject parent;
+	GTypeInstance parent_instance;
+	volatile int ref_count;
 	ValaCCodeNodePrivate * priv;
 };
+
 struct _ValaCCodeNodeClass {
-	GObjectClass parent;
+	GTypeClass parent_class;
+	void (*finalize) (ValaCCodeNode *self);
 	void (*write) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 	void (*write_declaration) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
+struct _ValaParamSpecCCodeNode {
+	GParamSpec parent_instance;
+};
+
+
 void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
 void vala_ccode_node_write_declaration (ValaCCodeNode* self, ValaCCodeWriter* writer);
 void vala_ccode_node_write_combined (ValaCCodeNode* self, ValaCCodeWriter* writer);
 ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self);
 void vala_ccode_node_set_line (ValaCCodeNode* self, ValaCCodeLineDirective* value);
+GParamSpec* vala_param_spec_ccode_node (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+gpointer vala_value_get_ccode_node (const GValue* value);
+void vala_value_set_ccode_node (GValue* value, gpointer v_object);
 GType vala_ccode_node_get_type (void);
+gpointer vala_ccode_node_ref (gpointer instance);
+void vala_ccode_node_unref (gpointer instance);
+
 
 G_END_DECLS
 
