@@ -1,6 +1,6 @@
 /* valaccodevariabledeclarator.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -58,10 +58,8 @@ struct _ValaCCodeVariableDeclaratorClass {
 };
 
 
-ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_construct (GType object_type, const char* name);
-ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* name);
-ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_construct_with_initializer (GType object_type, const char* name, ValaCCodeExpression* initializer);
-ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new_with_initializer (const char* name, ValaCCodeExpression* initializer);
+ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_construct (GType object_type, const char* name, ValaCCodeExpression* initializer);
+ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* name, ValaCCodeExpression* initializer);
 const char* vala_ccode_variable_declarator_get_name (ValaCCodeVariableDeclarator* self);
 void vala_ccode_variable_declarator_set_name (ValaCCodeVariableDeclarator* self, const char* value);
 ValaCCodeExpression* vala_ccode_variable_declarator_get_initializer (ValaCCodeVariableDeclarator* self);
