@@ -85,7 +85,7 @@ gboolean vala_ccode_writer_open (ValaCCodeWriter* self) {
 		_tmp2 = NULL;
 		self->priv->stream = (_tmp2 = fopen (self->priv->_filename, "w"), (self->priv->stream == NULL) ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)), _tmp2);
 	}
-	return (self->priv->stream != NULL);
+	return self->priv->stream != NULL;
 }
 
 
