@@ -25,6 +25,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/collectionobject.h>
 #include <gee/map.h>
 #include <gee/set.h>
 #include <gee/collection.h>
@@ -47,17 +48,21 @@ typedef struct _GeeReadOnlyMapPrivate GeeReadOnlyMapPrivate;
  * Represents a read-only collection of key/value pairs.
  */
 struct _GeeReadOnlyMap {
-	GObject parent_instance;
+	GeeCollectionObject parent_instance;
 	GeeReadOnlyMapPrivate * priv;
 };
+
 struct _GeeReadOnlyMapClass {
-	GObjectClass parent_class;
+	GeeCollectionObjectClass parent_class;
 };
 
+
+GeeReadOnlyMap* gee_read_only_map_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeMap* map);
 GeeReadOnlyMap* gee_read_only_map_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeMap* map);
 void gee_read_only_map_set_map (GeeReadOnlyMap* self, GeeMap* value);
 GType gee_read_only_map_get_type (void);
 
+
 G_END_DECLS
 
 #endif
