@@ -42,14 +42,15 @@
 #include <vala/valafield.h>
 #include <vala/valadelegatetype.h>
 #include <vala/valadelegate.h>
-#include <vala/valalocalvariable.h>
-#include <gee/list.h>
-#include <ccode/valaccodeassignment.h>
-#include <vala/valasymbol.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ccode/valaccodeelementaccess.h>
-#include <ccode/valaccodeidentifier.h>
+#include <vala/valalocalvariable.h>
+#include <vala/valasourcereference.h>
+#include <gee/list.h>
+#include <ccode/valaccodeassignment.h>
+#include <ccode/valaccodeunaryexpression.h>
+#include <ccode/valaccodeparenthesizedexpression.h>
+#include <vala/valasymbol.h>
 #include <gobject/valaccodebasemodule.h>
 
 
@@ -186,7 +187,7 @@ static ValaCCodeExpression* vala_ccode_assignment_module_emit_property_assignmen
 		}
 		ccall = vala_ccode_base_module_get_property_set_call ((ValaCCodeBaseModule*) self, prop, ma, cexpr);
 		/* assignments are expressions, so return the current property value, except if we're sure that it can't be used*/
-		if (!(VALA_IS_EXPRESSION_STATEMENT (vala_code_node_get_parent_node ((ValaCodeNode*) assignment)))) {
+		if (!VALA_IS_EXPRESSION_STATEMENT (vala_code_node_get_parent_node ((ValaCodeNode*) assignment))) {
 			ValaCCodeCommaExpression* ccomma;
 			ValaCCodeExpression* _tmp13;
 			ValaCCodeExpression* _tmp14;
@@ -215,21 +216,22 @@ static ValaCCodeExpression* vala_ccode_assignment_module_emit_property_assignmen
 static ValaCCodeExpression* vala_ccode_assignment_module_emit_simple_assignment (ValaCCodeAssignmentModule* self, ValaAssignment* assignment) {
 	ValaCCodeExpression* _tmp0;
 	ValaCCodeExpression* rhs;
+	ValaCCodeExpression* lhs;
+	ValaCCodeCommaExpression* outer_ccomma;
 	gboolean unref_old;
 	gboolean array;
 	gboolean instance_delegate;
 	gboolean _tmp5;
 	gboolean _tmp6;
 	ValaCCodeAssignmentOperator cop;
-	ValaCCodeExpression* _tmp22;
-	ValaCCodeExpression* _tmp23;
 	ValaCCodeExpression* codenode;
-	gboolean _tmp24;
 	ValaCCodeExpression* _tmp32;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (assignment != NULL, NULL);
 	_tmp0 = NULL;
 	rhs = (_tmp0 = VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode ((ValaCodeNode*) vala_assignment_get_right (assignment))), (_tmp0 == NULL) ? NULL : vala_ccode_node_ref (_tmp0));
+	lhs = VALA_CCODE_EXPRESSION (vala_ccode_base_module_get_ccodenode ((ValaCCodeBaseModule*) self, (ValaCodeNode*) vala_assignment_get_left (assignment)));
+	outer_ccomma = NULL;
 	unref_old = vala_ccode_base_module_requires_destroy ((ValaCCodeBaseModule*) self, vala_expression_get_value_type (vala_assignment_get_left (assignment)));
 	array = FALSE;
 	instance_delegate = FALSE;
@@ -247,7 +249,7 @@ static ValaCCodeExpression* vala_ccode_assignment_module_emit_simple_assignment
 		} else {
 			_tmp3 = !vala_field_get_no_array_length (array_field);
 		}
-		array = (_tmp3);
+		array = _tmp3;
 		(array_field == NULL) ? NULL : (array_field = (vala_code_node_unref (array_field), NULL));
 	} else {
 		if (VALA_IS_DELEGATE_TYPE (vala_expression_get_value_type (vala_assignment_get_left (assignment)))) {
@@ -274,85 +276,121 @@ static ValaCCodeExpression* vala_ccode_assignment_module_emit_simple_assignment
 	if (_tmp5) {
 		ValaCCodeCommaExpression* ccomma;
 		ValaLocalVariable* temp_decl;
-		ValaCCodeAssignment* _tmp8;
-		ValaCCodeExpression* _tmp7;
-		ValaCCodeExpression* _tmp19;
-		ValaCCodeExpression* _tmp21;
-		ValaCCodeExpression* _tmp20;
+		ValaCCodeAssignment* _tmp17;
+		ValaCCodeExpression* _tmp16;
+		ValaCCodeExpression* _tmp27;
+		ValaCCodeExpression* _tmp29;
+		ValaCCodeExpression* _tmp28;
 		ccomma = vala_ccode_comma_expression_new ();
+		if (!vala_ccode_base_module_is_pure_ccode_expression ((ValaCCodeBaseModule*) self, lhs)) {
+			ValaCCodeCommaExpression* _tmp7;
+			ValaDataType* lhs_value_type;
+			char* lhs_temp_name;
+			char* _tmp8;
+			ValaLocalVariable* _tmp9;
+			ValaLocalVariable* lhs_temp;
+			ValaCCodeAssignment* _tmp12;
+			ValaCCodeUnaryExpression* _tmp11;
+			ValaCCodeExpression* _tmp10;
+			ValaCCodeExpression* _tmp15;
+			ValaCCodeUnaryExpression* _tmp14;
+			ValaCCodeExpression* _tmp13;
+			/* Assign lhs to temp var to avoid repeating side effect */
+			_tmp7 = NULL;
+			outer_ccomma = (_tmp7 = vala_ccode_comma_expression_new (), (outer_ccomma == NULL) ? NULL : (outer_ccomma = (vala_ccode_node_unref (outer_ccomma), NULL)), _tmp7);
+			lhs_value_type = vala_data_type_copy (vala_expression_get_value_type (vala_assignment_get_left (assignment)));
+			lhs_temp_name = g_strdup_printf ("_tmp%d", ((ValaCCodeBaseModule*) self)->next_temp_var_id++);
+			_tmp8 = NULL;
+			_tmp9 = NULL;
+			lhs_temp = (_tmp9 = vala_local_variable_new (lhs_value_type, _tmp8 = g_strconcat ("*", lhs_temp_name, NULL), NULL, NULL), _tmp8 = (g_free (_tmp8), NULL), _tmp9);
+			gee_list_insert ((GeeList*) ((ValaCCodeBaseModule*) self)->temp_vars, 0, lhs_temp);
+			_tmp12 = NULL;
+			_tmp11 = NULL;
+			_tmp10 = NULL;
+			vala_ccode_comma_expression_append_expression (outer_ccomma, (ValaCCodeExpression*) (_tmp12 = vala_ccode_assignment_new (_tmp10 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, lhs_temp_name), (ValaCCodeExpression*) (_tmp11 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, lhs)), VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
+			(_tmp12 == NULL) ? NULL : (_tmp12 = (vala_ccode_node_unref (_tmp12), NULL));
+			(_tmp11 == NULL) ? NULL : (_tmp11 = (vala_ccode_node_unref (_tmp11), NULL));
+			(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_ccode_node_unref (_tmp10), NULL));
+			_tmp15 = NULL;
+			_tmp14 = NULL;
+			_tmp13 = NULL;
+			lhs = (_tmp15 = (ValaCCodeExpression*) vala_ccode_parenthesized_expression_new ((ValaCCodeExpression*) (_tmp14 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_POINTER_INDIRECTION, _tmp13 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, lhs_temp_name)))), (lhs == NULL) ? NULL : (lhs = (vala_ccode_node_unref (lhs), NULL)), _tmp15);
+			(_tmp14 == NULL) ? NULL : (_tmp14 = (vala_ccode_node_unref (_tmp14), NULL));
+			(_tmp13 == NULL) ? NULL : (_tmp13 = (vala_ccode_node_unref (_tmp13), NULL));
+			(lhs_value_type == NULL) ? NULL : (lhs_value_type = (vala_code_node_unref (lhs_value_type), NULL));
+			lhs_temp_name = (g_free (lhs_temp_name), NULL);
+			(lhs_temp == NULL) ? NULL : (lhs_temp = (vala_code_node_unref (lhs_temp), NULL));
+		}
 		temp_decl = vala_ccode_base_module_get_temp_variable ((ValaCCodeBaseModule*) self, vala_expression_get_value_type (vala_assignment_get_left (assignment)), TRUE, NULL);
 		gee_list_insert ((GeeList*) ((ValaCCodeBaseModule*) self)->temp_vars, 0, temp_decl);
-		_tmp8 = NULL;
-		_tmp7 = NULL;
-		vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp8 = vala_ccode_assignment_new (_tmp7 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, vala_symbol_get_name ((ValaSymbol*) temp_decl)), rhs, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
-		(_tmp8 == NULL) ? NULL : (_tmp8 = (vala_ccode_node_unref (_tmp8), NULL));
-		(_tmp7 == NULL) ? NULL : (_tmp7 = (vala_ccode_node_unref (_tmp7), NULL));
+		_tmp17 = NULL;
+		_tmp16 = NULL;
+		vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp17 = vala_ccode_assignment_new (_tmp16 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, vala_symbol_get_name ((ValaSymbol*) temp_decl)), rhs, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
+		(_tmp17 == NULL) ? NULL : (_tmp17 = (vala_ccode_node_unref (_tmp17), NULL));
+		(_tmp16 == NULL) ? NULL : (_tmp16 = (vala_ccode_node_unref (_tmp16), NULL));
 		if (unref_old) {
-			ValaCCodeExpression* _tmp10;
-			ValaCCodeExpression* _tmp9;
+			ValaCCodeExpression* _tmp18;
 			/* unref old value */
-			_tmp10 = NULL;
-			_tmp9 = NULL;
-			vala_ccode_comma_expression_append_expression (ccomma, _tmp10 = vala_ccode_base_module_get_unref_expression ((ValaCCodeBaseModule*) self, _tmp9 = VALA_CCODE_EXPRESSION (vala_ccode_base_module_get_ccodenode ((ValaCCodeBaseModule*) self, (ValaCodeNode*) vala_assignment_get_left (assignment))), vala_expression_get_value_type (vala_assignment_get_left (assignment)), vala_assignment_get_left (assignment)));
-			(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_ccode_node_unref (_tmp10), NULL));
-			(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL));
+			_tmp18 = NULL;
+			vala_ccode_comma_expression_append_expression (ccomma, _tmp18 = vala_ccode_base_module_get_unref_expression ((ValaCCodeBaseModule*) self, lhs, vala_expression_get_value_type (vala_assignment_get_left (assignment)), vala_assignment_get_left (assignment)));
+			(_tmp18 == NULL) ? NULL : (_tmp18 = (vala_ccode_node_unref (_tmp18), NULL));
 		}
 		if (array) {
-			ValaArrayType* _tmp11;
+			ValaArrayType* _tmp19;
 			ValaArrayType* array_type;
-			_tmp11 = NULL;
-			array_type = (_tmp11 = VALA_ARRAY_TYPE (vala_expression_get_value_type (vala_assignment_get_left (assignment))), (_tmp11 == NULL) ? NULL : vala_code_node_ref (_tmp11));
+			_tmp19 = NULL;
+			array_type = (_tmp19 = VALA_ARRAY_TYPE (vala_expression_get_value_type (vala_assignment_get_left (assignment))), (_tmp19 == NULL) ? NULL : vala_code_node_ref (_tmp19));
 			{
 				gint dim;
 				dim = 1;
 				for (; dim <= vala_array_type_get_rank (array_type); dim++) {
 					ValaCCodeExpression* lhs_array_len;
 					ValaCCodeExpression* rhs_array_len;
-					ValaCCodeAssignment* _tmp12;
+					ValaCCodeAssignment* _tmp20;
 					lhs_array_len = vala_ccode_module_get_array_length_cexpression (vala_ccode_module_get_head ((ValaCCodeModule*) self), vala_assignment_get_left (assignment), dim);
 					rhs_array_len = vala_ccode_module_get_array_length_cexpression (vala_ccode_module_get_head ((ValaCCodeModule*) self), vala_assignment_get_right (assignment), dim);
-					_tmp12 = NULL;
-					vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp12 = vala_ccode_assignment_new (lhs_array_len, rhs_array_len, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
-					(_tmp12 == NULL) ? NULL : (_tmp12 = (vala_ccode_node_unref (_tmp12), NULL));
+					_tmp20 = NULL;
+					vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp20 = vala_ccode_assignment_new (lhs_array_len, rhs_array_len, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
+					(_tmp20 == NULL) ? NULL : (_tmp20 = (vala_ccode_node_unref (_tmp20), NULL));
 					(lhs_array_len == NULL) ? NULL : (lhs_array_len = (vala_ccode_node_unref (lhs_array_len), NULL));
 					(rhs_array_len == NULL) ? NULL : (rhs_array_len = (vala_ccode_node_unref (rhs_array_len), NULL));
 				}
 			}
 			if (vala_array_type_get_rank (array_type) == 1) {
-				ValaSymbol* _tmp13;
+				ValaSymbol* _tmp21;
 				ValaSymbol* array_var;
-				gboolean _tmp14;
-				gboolean _tmp15;
-				_tmp13 = NULL;
-				array_var = (_tmp13 = vala_expression_get_symbol_reference (vala_assignment_get_left (assignment)), (_tmp13 == NULL) ? NULL : vala_code_node_ref (_tmp13));
-				_tmp14 = FALSE;
-				_tmp15 = FALSE;
+				gboolean _tmp22;
+				gboolean _tmp23;
+				_tmp21 = NULL;
+				array_var = (_tmp21 = vala_expression_get_symbol_reference (vala_assignment_get_left (assignment)), (_tmp21 == NULL) ? NULL : vala_code_node_ref (_tmp21));
+				_tmp22 = FALSE;
+				_tmp23 = FALSE;
 				if (array_var != NULL) {
-					_tmp15 = vala_symbol_is_internal_symbol (array_var);
+					_tmp23 = vala_symbol_is_internal_symbol (array_var);
 				} else {
-					_tmp15 = FALSE;
+					_tmp23 = FALSE;
 				}
-				if (_tmp15) {
-					gboolean _tmp16;
-					_tmp16 = FALSE;
+				if (_tmp23) {
+					gboolean _tmp24;
+					_tmp24 = FALSE;
 					if (VALA_IS_LOCAL_VARIABLE (array_var)) {
-						_tmp16 = TRUE;
+						_tmp24 = TRUE;
 					} else {
-						_tmp16 = VALA_IS_FIELD (array_var);
+						_tmp24 = VALA_IS_FIELD (array_var);
 					}
-					_tmp14 = (_tmp16);
+					_tmp22 = _tmp24;
 				} else {
-					_tmp14 = FALSE;
+					_tmp22 = FALSE;
 				}
-				if (_tmp14) {
+				if (_tmp22) {
 					ValaCCodeExpression* lhs_array_size;
 					ValaCCodeExpression* rhs_array_len;
-					ValaCCodeAssignment* _tmp17;
+					ValaCCodeAssignment* _tmp25;
 					lhs_array_size = vala_ccode_module_get_array_size_cexpression (vala_ccode_module_get_head ((ValaCCodeModule*) self), vala_assignment_get_left (assignment));
 					rhs_array_len = vala_ccode_module_get_array_length_cexpression (vala_ccode_module_get_head ((ValaCCodeModule*) self), vala_assignment_get_left (assignment), 1);
-					_tmp17 = NULL;
-					vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp17 = vala_ccode_assignment_new (lhs_array_size, rhs_array_len, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
-					(_tmp17 == NULL) ? NULL : (_tmp17 = (vala_ccode_node_unref (_tmp17), NULL));
+					_tmp25 = NULL;
+					vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp25 = vala_ccode_assignment_new (lhs_array_size, rhs_array_len, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
+					(_tmp25 == NULL) ? NULL : (_tmp25 = (vala_ccode_node_unref (_tmp25), NULL));
 					(lhs_array_size == NULL) ? NULL : (lhs_array_size = (vala_ccode_node_unref (lhs_array_size), NULL));
 					(rhs_array_len == NULL) ? NULL : (rhs_array_len = (vala_ccode_node_unref (rhs_array_len), NULL));
 				}
@@ -363,22 +401,22 @@ static ValaCCodeExpression* vala_ccode_assignment_module_emit_simple_assignment
 			if (instance_delegate) {
 				ValaCCodeExpression* lhs_delegate_target;
 				ValaCCodeExpression* rhs_delegate_target;
-				ValaCCodeAssignment* _tmp18;
+				ValaCCodeAssignment* _tmp26;
 				lhs_delegate_target = vala_ccode_base_module_get_delegate_target_cexpression ((ValaCCodeBaseModule*) self, vala_assignment_get_left (assignment));
 				rhs_delegate_target = vala_ccode_base_module_get_delegate_target_cexpression ((ValaCCodeBaseModule*) self, vala_assignment_get_right (assignment));
-				_tmp18 = NULL;
-				vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp18 = vala_ccode_assignment_new (lhs_delegate_target, rhs_delegate_target, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
-				(_tmp18 == NULL) ? NULL : (_tmp18 = (vala_ccode_node_unref (_tmp18), NULL));
+				_tmp26 = NULL;
+				vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp26 = vala_ccode_assignment_new (lhs_delegate_target, rhs_delegate_target, VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
+				(_tmp26 == NULL) ? NULL : (_tmp26 = (vala_ccode_node_unref (_tmp26), NULL));
 				(lhs_delegate_target == NULL) ? NULL : (lhs_delegate_target = (vala_ccode_node_unref (lhs_delegate_target), NULL));
 				(rhs_delegate_target == NULL) ? NULL : (rhs_delegate_target = (vala_ccode_node_unref (rhs_delegate_target), NULL));
 			}
 		}
-		_tmp19 = NULL;
-		vala_ccode_comma_expression_append_expression (ccomma, _tmp19 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, vala_symbol_get_name ((ValaSymbol*) temp_decl)));
-		(_tmp19 == NULL) ? NULL : (_tmp19 = (vala_ccode_node_unref (_tmp19), NULL));
-		_tmp21 = NULL;
-		_tmp20 = NULL;
-		rhs = (_tmp21 = (_tmp20 = (ValaCCodeExpression*) ccomma, (_tmp20 == NULL) ? NULL : vala_ccode_node_ref (_tmp20)), (rhs == NULL) ? NULL : (rhs = (vala_ccode_node_unref (rhs), NULL)), _tmp21);
+		_tmp27 = NULL;
+		vala_ccode_comma_expression_append_expression (ccomma, _tmp27 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, vala_symbol_get_name ((ValaSymbol*) temp_decl)));
+		(_tmp27 == NULL) ? NULL : (_tmp27 = (vala_ccode_node_unref (_tmp27), NULL));
+		_tmp29 = NULL;
+		_tmp28 = NULL;
+		rhs = (_tmp29 = (_tmp28 = (ValaCCodeExpression*) ccomma, (_tmp28 == NULL) ? NULL : vala_ccode_node_ref (_tmp28)), (rhs == NULL) ? NULL : (rhs = (vala_ccode_node_unref (rhs), NULL)), _tmp29);
 		(ccomma == NULL) ? NULL : (ccomma = (vala_ccode_node_unref (ccomma), NULL));
 		(temp_decl == NULL) ? NULL : (temp_decl = (vala_code_node_unref (temp_decl), NULL));
 	}
@@ -422,60 +460,17 @@ static ValaCCodeExpression* vala_ccode_assignment_module_emit_simple_assignment
 			}
 		}
 	}
-	_tmp22 = NULL;
-	_tmp23 = NULL;
-	codenode = (_tmp23 = (ValaCCodeExpression*) vala_ccode_assignment_new (_tmp22 = VALA_CCODE_EXPRESSION (vala_ccode_base_module_get_ccodenode ((ValaCCodeBaseModule*) self, (ValaCodeNode*) vala_assignment_get_left (assignment))), rhs, cop), (_tmp22 == NULL) ? NULL : (_tmp22 = (vala_ccode_node_unref (_tmp22), NULL)), _tmp23);
-	_tmp24 = FALSE;
-	if (unref_old) {
-		ValaCCodeNode* _tmp25;
-		_tmp25 = NULL;
-		_tmp24 = VALA_IS_CCODE_ELEMENT_ACCESS (_tmp25 = vala_ccode_base_module_get_ccodenode ((ValaCCodeBaseModule*) self, (ValaCodeNode*) vala_assignment_get_left (assignment)));
-		(_tmp25 == NULL) ? NULL : (_tmp25 = (vala_ccode_node_unref (_tmp25), NULL));
-	} else {
-		_tmp24 = FALSE;
-	}
-	if (_tmp24) {
-		ValaCCodeElementAccess* cea;
-		gboolean _tmp26;
-		/* ensure that index expression in element access doesn't get evaluated more than once
-		 except when it's a simple expression*/
-		cea = VALA_CCODE_ELEMENT_ACCESS (vala_ccode_base_module_get_ccodenode ((ValaCCodeBaseModule*) self, (ValaCodeNode*) vala_assignment_get_left (assignment)));
-		_tmp26 = FALSE;
-		if (VALA_IS_CCODE_CONSTANT (vala_ccode_element_access_get_index (cea))) {
-			_tmp26 = TRUE;
-		} else {
-			_tmp26 = VALA_IS_CCODE_IDENTIFIER (vala_ccode_element_access_get_index (cea));
-		}
-		if (!(_tmp26)) {
-			ValaLocalVariable* index_temp_decl;
-			ValaCCodeCommaExpression* ccomma;
-			ValaCCodeAssignment* _tmp28;
-			ValaCCodeExpression* _tmp27;
-			ValaCCodeExpression* _tmp29;
-			ValaCCodeExpression* _tmp31;
-			ValaCCodeExpression* _tmp30;
-			index_temp_decl = vala_ccode_base_module_get_temp_variable ((ValaCCodeBaseModule*) self, ((ValaCCodeBaseModule*) self)->int_type, TRUE, NULL);
-			gee_list_insert ((GeeList*) ((ValaCCodeBaseModule*) self)->temp_vars, 0, index_temp_decl);
-			ccomma = vala_ccode_comma_expression_new ();
-			_tmp28 = NULL;
-			_tmp27 = NULL;
-			vala_ccode_comma_expression_append_expression (ccomma, (ValaCCodeExpression*) (_tmp28 = vala_ccode_assignment_new (_tmp27 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, vala_symbol_get_name ((ValaSymbol*) index_temp_decl)), vala_ccode_element_access_get_index (cea), VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)));
-			(_tmp28 == NULL) ? NULL : (_tmp28 = (vala_ccode_node_unref (_tmp28), NULL));
-			(_tmp27 == NULL) ? NULL : (_tmp27 = (vala_ccode_node_unref (_tmp27), NULL));
-			vala_ccode_comma_expression_append_expression (ccomma, codenode);
-			_tmp29 = NULL;
-			vala_ccode_element_access_set_index (cea, _tmp29 = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, vala_symbol_get_name ((ValaSymbol*) index_temp_decl)));
-			(_tmp29 == NULL) ? NULL : (_tmp29 = (vala_ccode_node_unref (_tmp29), NULL));
-			_tmp31 = NULL;
-			_tmp30 = NULL;
-			codenode = (_tmp31 = (_tmp30 = (ValaCCodeExpression*) ccomma, (_tmp30 == NULL) ? NULL : vala_ccode_node_ref (_tmp30)), (codenode == NULL) ? NULL : (codenode = (vala_ccode_node_unref (codenode), NULL)), _tmp31);
-			(index_temp_decl == NULL) ? NULL : (index_temp_decl = (vala_code_node_unref (index_temp_decl), NULL));
-			(ccomma == NULL) ? NULL : (ccomma = (vala_ccode_node_unref (ccomma), NULL));
-		}
-		(cea == NULL) ? NULL : (cea = (vala_ccode_node_unref (cea), NULL));
+	codenode = (ValaCCodeExpression*) vala_ccode_assignment_new (lhs, rhs, cop);
+	if (outer_ccomma != NULL) {
+		ValaCCodeExpression* _tmp31;
+		ValaCCodeExpression* _tmp30;
+		vala_ccode_comma_expression_append_expression (outer_ccomma, codenode);
+		_tmp31 = NULL;
+		_tmp30 = NULL;
+		codenode = (_tmp31 = (_tmp30 = (ValaCCodeExpression*) outer_ccomma, (_tmp30 == NULL) ? NULL : vala_ccode_node_ref (_tmp30)), (codenode == NULL) ? NULL : (codenode = (vala_ccode_node_unref (codenode), NULL)), _tmp31);
 	}
 	_tmp32 = NULL;
-	return (_tmp32 = codenode, (rhs == NULL) ? NULL : (rhs = (vala_ccode_node_unref (rhs), NULL)), _tmp32);
+	return (_tmp32 = codenode, (rhs == NULL) ? NULL : (rhs = (vala_ccode_node_unref (rhs), NULL)), (lhs == NULL) ? NULL : (lhs = (vala_ccode_node_unref (lhs), NULL)), (outer_ccomma == NULL) ? NULL : (outer_ccomma = (vala_ccode_node_unref (outer_ccomma), NULL)), _tmp32);
 }
 
 
