@@ -1,6 +1,7 @@
 /* valaccodedelegatemodule.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2009  Jürg Billeter
+ * Copyright (C) 2006-2008  Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -32,6 +33,8 @@
 #include <ccode/valaccodeexpression.h>
 #include <vala/valaexpression.h>
 #include <vala/valadatatype.h>
+#include <vala/valaformalparameter.h>
+#include <gee/map.h>
 #include <gobject/valaccodearraymodule.h>
 #include <gobject/valaccodegenerator.h>
 #include <gobject/valaccodemodule.h>
