@@ -144,7 +144,7 @@ static void vala_ccode_member_access_module_real_visit_member_access (ValaCCodeM
 				_tmp11 = (g_free (_tmp11), NULL);
 				_tmp10 = (g_free (_tmp10), NULL);
 				_tmp13 = NULL;
-				vala_code_node_set_ccodenode ((ValaCodeNode*) expr, (ValaCCodeNode*) (_tmp13 = vala_ccode_member_access_new_pointer ((ValaCCodeExpression*) vcast, vala_symbol_get_name ((ValaSymbol*) m))));
+				vala_code_node_set_ccodenode ((ValaCodeNode*) expr, (ValaCCodeNode*) (_tmp13 = vala_ccode_member_access_new_pointer ((ValaCCodeExpression*) vcast, vala_method_get_vfunc_name (m))));
 				(_tmp13 == NULL) ? NULL : (_tmp13 = (vala_ccode_node_unref (_tmp13), NULL));
 				(base_class == NULL) ? NULL : (base_class = (vala_code_node_unref (base_class), NULL));
 				(vcast == NULL) ? NULL : (vcast = (vala_ccode_node_unref (vcast), NULL));
@@ -170,7 +170,7 @@ static void vala_ccode_member_access_module_real_visit_member_access (ValaCCodeM
 					parent_iface_var = (_tmp17 = g_strdup_printf ("%s_%s_parent_iface", _tmp15 = vala_symbol_get_lower_case_cname ((ValaSymbol*) ((ValaCCodeBaseModule*) self)->current_class, NULL), _tmp16 = vala_symbol_get_lower_case_cname ((ValaSymbol*) base_iface, NULL)), _tmp16 = (g_free (_tmp16), NULL), _tmp15 = (g_free (_tmp15), NULL), _tmp17);
 					_tmp19 = NULL;
 					_tmp18 = NULL;
-					vala_code_node_set_ccodenode ((ValaCodeNode*) expr, (ValaCCodeNode*) (_tmp19 = vala_ccode_member_access_new_pointer ((ValaCCodeExpression*) (_tmp18 = vala_ccode_identifier_new (parent_iface_var)), vala_symbol_get_name ((ValaSymbol*) m))));
+					vala_code_node_set_ccodenode ((ValaCodeNode*) expr, (ValaCCodeNode*) (_tmp19 = vala_ccode_member_access_new_pointer ((ValaCCodeExpression*) (_tmp18 = vala_ccode_identifier_new (parent_iface_var)), vala_method_get_vfunc_name (m))));
 					(_tmp19 == NULL) ? NULL : (_tmp19 = (vala_ccode_node_unref (_tmp19), NULL));
 					(_tmp18 == NULL) ? NULL : (_tmp18 = (vala_ccode_node_unref (_tmp18), NULL));
 					(base_iface == NULL) ? NULL : (base_iface = (vala_code_node_unref (base_iface), NULL));
