@@ -17,7 +17,8 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  *
  * Author:
- * 	Jürg Billeter <j@bitron.ch>
+ *	Jürg Billeter <j@bitron.ch>
+ *	Thijs Vermeir <thijsvermeir@gmail.com>
  */
 
 #include <gobject/valagerrormodule.h>
@@ -50,8 +51,9 @@
 #include <gee/iterable.h>
 #include <gee/iterator.h>
 #include <ccode/valaccodegotostatement.h>
-#include <ccode/valaccodebinaryexpression.h>
+#include <vala/valaerrortype.h>
 #include <ccode/valaccodeifstatement.h>
+#include <ccode/valaccodebinaryexpression.h>
 #include <gee/collection.h>
 #include <ccode/valaccodelabel.h>
 #include <vala/valamethod.h>
@@ -60,6 +62,7 @@
 #include <ccode/valaccodevariabledeclarator.h>
 #include <ccode/valaccodedeclarator.h>
 #include <gobject/valaccodebasemodule.h>
+#include <gobject/valaccodedeclarationspace.h>
 
 
 
@@ -77,6 +80,7 @@ static void vala_gerror_module_real_visit_error_domain (ValaCCodeModule* base, V
 static void vala_gerror_module_real_visit_error_code (ValaCCodeModule* base, ValaErrorCode* ecode);
 static void vala_gerror_module_real_visit_throw_statement (ValaCCodeModule* base, ValaThrowStatement* stmt);
 static ValaCCodeStatement* vala_gerror_module_real_return_with_exception (ValaGErrorModule* self, ValaCCodeExpression* error_expr);
+static ValaCCodeStatement* vala_gerror_module_uncaught_error_statement (ValaGErrorModule* self, ValaCCodeExpression* inner_error);
 static void vala_gerror_module_real_add_simple_check (ValaCCodeModule* base, ValaCodeNode* node, ValaCCodeFragment* cfrag);
 static void vala_gerror_module_real_visit_try_statement (ValaCCodeModule* base, ValaTryStatement* stmt);
 static void vala_gerror_module_real_visit_catch_clause (ValaCCodeModule* base, ValaCatchClause* clause);
@@ -131,10 +135,10 @@ static void vala_gerror_module_real_visit_error_domain (ValaCCodeModule* base, V
 	if (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) edomain)) != NULL) {
 		ValaCCodeComment* _tmp2;
 		_tmp2 = NULL;
-		vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_definition, (ValaCCodeNode*) (_tmp2 = vala_ccode_comment_new (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) edomain)))));
+		vala_ccode_declaration_space_add_type_definition (((ValaCCodeBaseModule*) self)->header_declarations, (ValaCCodeNode*) (_tmp2 = vala_ccode_comment_new (vala_source_reference_get_comment (vala_code_node_get_source_reference ((ValaCodeNode*) edomain)))));
 		(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_ccode_node_unref (_tmp2), NULL));
 	}
-	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_definition, (ValaCCodeNode*) ((ValaCCodeBaseModule*) self)->cenum);
+	vala_ccode_declaration_space_add_type_definition (((ValaCCodeBaseModule*) self)->header_declarations, (ValaCCodeNode*) ((ValaCCodeBaseModule*) self)->cenum);
 	vala_code_node_accept_children ((ValaCodeNode*) edomain, (ValaCodeVisitor*) vala_ccode_module_get_codegen ((ValaCCodeModule*) self));
 	_tmp3 = NULL;
 	_tmp4 = NULL;
@@ -143,7 +147,7 @@ static void vala_gerror_module_real_visit_error_domain (ValaCCodeModule* base, V
 	_tmp5 = NULL;
 	_tmp7 = NULL;
 	error_domain_define = (_tmp7 = vala_ccode_macro_replacement_new (_tmp5 = vala_typesymbol_get_upper_case_cname ((ValaTypeSymbol*) edomain, NULL), _tmp6 = g_strconcat (quark_fun_name, " ()", NULL)), _tmp6 = (g_free (_tmp6), NULL), _tmp5 = (g_free (_tmp5), NULL), _tmp7);
-	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_definition, (ValaCCodeNode*) error_domain_define);
+	vala_ccode_declaration_space_add_type_definition (((ValaCCodeBaseModule*) self)->header_declarations, (ValaCCodeNode*) error_domain_define);
 	_tmp8 = NULL;
 	_tmp9 = NULL;
 	cquark_fun = (_tmp9 = vala_ccode_function_new (quark_fun_name, _tmp8 = vala_typesymbol_get_cname (vala_data_type_get_data_type (((ValaCCodeBaseModule*) self)->gquark_type), FALSE)), _tmp8 = (g_free (_tmp8), NULL), _tmp9);
@@ -164,7 +168,7 @@ static void vala_gerror_module_real_visit_error_domain (ValaCCodeModule* base, V
 	vala_ccode_block_add_statement (cquark_block, (ValaCCodeNode*) (_tmp16 = vala_ccode_return_statement_new ((ValaCCodeExpression*) cquark_call)));
 	(_tmp16 == NULL) ? NULL : (_tmp16 = (vala_ccode_node_unref (_tmp16), NULL));
 	_tmp17 = NULL;
-	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->header_type_member_declaration, (ValaCCodeNode*) (_tmp17 = vala_ccode_function_copy (cquark_fun)));
+	vala_ccode_declaration_space_add_type_member_declaration (((ValaCCodeBaseModule*) self)->header_declarations, (ValaCCodeNode*) (_tmp17 = vala_ccode_function_copy (cquark_fun)));
 	(_tmp17 == NULL) ? NULL : (_tmp17 = (vala_ccode_node_unref (_tmp17), NULL));
 	vala_ccode_function_set_block (cquark_fun, cquark_block);
 	vala_ccode_fragment_append (((ValaCCodeBaseModule*) self)->source_type_member_definition, (ValaCCodeNode*) cquark_fun);
@@ -278,10 +282,9 @@ ValaCCodeStatement* vala_gerror_module_return_with_exception (ValaGErrorModule*
 }
 
 
-static void vala_gerror_module_real_add_simple_check (ValaCCodeModule* base, ValaCodeNode* node, ValaCCodeFragment* cfrag) {
-	ValaGErrorModule * self;
-	ValaCCodeExpression* inner_error;
-	ValaCCodeFragment* cprint_frag;
+static ValaCCodeStatement* vala_gerror_module_uncaught_error_statement (ValaGErrorModule* self, ValaCCodeExpression* inner_error) {
+	ValaCCodeBlock* cerror_block;
+	ValaCCodeFragment* free_frag;
 	ValaCCodeIdentifier* _tmp0;
 	ValaCCodeFunctionCall* _tmp1;
 	ValaCCodeFunctionCall* ccritical;
@@ -289,23 +292,21 @@ static void vala_gerror_module_real_add_simple_check (ValaCCodeModule* base, Val
 	ValaCCodeConstant* _tmp3;
 	ValaCCodeConstant* _tmp4;
 	ValaCCodeMemberAccess* _tmp5;
-	ValaCCodeExpressionStatement* _tmp6;
-	ValaCCodeIdentifier* _tmp7;
-	ValaCCodeFunctionCall* _tmp8;
+	ValaCCodeIdentifier* _tmp6;
+	ValaCCodeFunctionCall* _tmp7;
 	ValaCCodeFunctionCall* cclear;
-	ValaCCodeUnaryExpression* _tmp9;
+	ValaCCodeUnaryExpression* _tmp8;
+	ValaCCodeFragment* cprint_frag;
+	ValaCCodeExpressionStatement* _tmp9;
 	ValaCCodeExpressionStatement* _tmp10;
-	ValaCCodeStatement* cerror_handler;
-	ValaCCodeConstant* _tmp30;
-	ValaCCodeBinaryExpression* _tmp31;
-	ValaCCodeBinaryExpression* ccond;
-	ValaCCodeIfStatement* _tmp32;
-	self = (ValaGErrorModule*) base;
-	g_return_if_fail (node != NULL);
-	g_return_if_fail (cfrag != NULL);
-	((ValaCCodeBaseModule*) self)->current_method_inner_error = TRUE;
-	inner_error = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, "inner_error");
-	cprint_frag = vala_ccode_fragment_new ();
+	ValaCCodeStatement* _tmp14;
+	g_return_val_if_fail (self != NULL, NULL);
+	g_return_val_if_fail (inner_error != NULL, NULL);
+	cerror_block = vala_ccode_block_new ();
+	/* free local variables*/
+	free_frag = vala_ccode_fragment_new ();
+	vala_ccode_base_module_append_local_free ((ValaCCodeBaseModule*) self, ((ValaCCodeBaseModule*) self)->current_symbol, free_frag, FALSE);
+	vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) free_frag);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
 	ccritical = (_tmp1 = vala_ccode_function_call_new ((ValaCCodeExpression*) (_tmp0 = vala_ccode_identifier_new ("g_critical"))), (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_ccode_node_unref (_tmp0), NULL)), _tmp1);
@@ -322,25 +323,62 @@ static void vala_gerror_module_real_add_simple_check (ValaCCodeModule* base, Val
 	vala_ccode_function_call_add_argument (ccritical, (ValaCCodeExpression*) (_tmp5 = vala_ccode_member_access_new_pointer (inner_error, "message")));
 	(_tmp5 == NULL) ? NULL : (_tmp5 = (vala_ccode_node_unref (_tmp5), NULL));
 	_tmp6 = NULL;
-	vala_ccode_fragment_append (cprint_frag, (ValaCCodeNode*) (_tmp6 = vala_ccode_expression_statement_new ((ValaCCodeExpression*) ccritical)));
-	(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_ccode_node_unref (_tmp6), NULL));
 	_tmp7 = NULL;
+	cclear = (_tmp7 = vala_ccode_function_call_new ((ValaCCodeExpression*) (_tmp6 = vala_ccode_identifier_new ("g_clear_error"))), (_tmp6 == NULL) ? NULL : (_tmp6 = (vala_ccode_node_unref (_tmp6), NULL)), _tmp7);
 	_tmp8 = NULL;
-	cclear = (_tmp8 = vala_ccode_function_call_new ((ValaCCodeExpression*) (_tmp7 = vala_ccode_identifier_new ("g_clear_error"))), (_tmp7 == NULL) ? NULL : (_tmp7 = (vala_ccode_node_unref (_tmp7), NULL)), _tmp8);
+	vala_ccode_function_call_add_argument (cclear, (ValaCCodeExpression*) (_tmp8 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, inner_error)));
+	(_tmp8 == NULL) ? NULL : (_tmp8 = (vala_ccode_node_unref (_tmp8), NULL));
+	cprint_frag = vala_ccode_fragment_new ();
 	_tmp9 = NULL;
-	vala_ccode_function_call_add_argument (cclear, (ValaCCodeExpression*) (_tmp9 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, inner_error)));
+	vala_ccode_fragment_append (cprint_frag, (ValaCCodeNode*) (_tmp9 = vala_ccode_expression_statement_new ((ValaCCodeExpression*) ccritical)));
 	(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL));
 	_tmp10 = NULL;
 	vala_ccode_fragment_append (cprint_frag, (ValaCCodeNode*) (_tmp10 = vala_ccode_expression_statement_new ((ValaCCodeExpression*) cclear)));
 	(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_ccode_node_unref (_tmp10), NULL));
+	/* print critical message*/
+	vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) cprint_frag);
+	if (VALA_IS_VOID_TYPE (((ValaCCodeBaseModule*) self)->current_return_type)) {
+		ValaCCodeReturnStatement* _tmp11;
+		_tmp11 = NULL;
+		vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) (_tmp11 = vala_ccode_return_statement_new (NULL)));
+		(_tmp11 == NULL) ? NULL : (_tmp11 = (vala_ccode_node_unref (_tmp11), NULL));
+	} else {
+		if (((ValaCCodeBaseModule*) self)->current_return_type != NULL) {
+			ValaCCodeReturnStatement* _tmp13;
+			ValaCCodeExpression* _tmp12;
+			_tmp13 = NULL;
+			_tmp12 = NULL;
+			vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) (_tmp13 = vala_ccode_return_statement_new (_tmp12 = vala_ccode_base_module_default_value_for_type ((ValaCCodeBaseModule*) self, ((ValaCCodeBaseModule*) self)->current_return_type, FALSE))));
+			(_tmp13 == NULL) ? NULL : (_tmp13 = (vala_ccode_node_unref (_tmp13), NULL));
+			(_tmp12 == NULL) ? NULL : (_tmp12 = (vala_ccode_node_unref (_tmp12), NULL));
+		}
+	}
+	_tmp14 = NULL;
+	return (_tmp14 = (ValaCCodeStatement*) cerror_block, (free_frag == NULL) ? NULL : (free_frag = (vala_ccode_node_unref (free_frag), NULL)), (ccritical == NULL) ? NULL : (ccritical = (vala_ccode_node_unref (ccritical), NULL)), (cclear == NULL) ? NULL : (cclear = (vala_ccode_node_unref (cclear), NULL)), (cprint_frag == NULL) ? NULL : (cprint_frag = (vala_ccode_node_unref (cprint_frag), NULL)), _tmp14);
+}
+
+
+static void vala_gerror_module_real_add_simple_check (ValaCCodeModule* base, ValaCodeNode* node, ValaCCodeFragment* cfrag) {
+	ValaGErrorModule * self;
+	ValaCCodeExpression* inner_error;
+	ValaCCodeStatement* cerror_handler;
+	ValaCCodeConstant* _tmp39;
+	ValaCCodeBinaryExpression* _tmp40;
+	ValaCCodeBinaryExpression* ccond;
+	ValaCCodeIfStatement* _tmp41;
+	self = (ValaGErrorModule*) base;
+	g_return_if_fail (node != NULL);
+	g_return_if_fail (cfrag != NULL);
+	((ValaCCodeBaseModule*) self)->current_method_inner_error = TRUE;
+	inner_error = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, "inner_error");
 	cerror_handler = NULL;
 	if (((ValaCCodeBaseModule*) self)->current_try != NULL) {
 		ValaCCodeBlock* cerror_block;
 		ValaCCodeFragment* free_frag;
-		ValaCCodeGotoStatement* _tmp19;
-		char* _tmp18;
-		ValaCCodeStatement* _tmp21;
-		ValaCCodeStatement* _tmp20;
+		ValaCCodeGotoStatement* _tmp17;
+		char* _tmp16;
+		ValaCCodeStatement* _tmp19;
+		ValaCCodeStatement* _tmp18;
 		/* surrounding try found*/
 		cerror_block = vala_ccode_block_new ();
 		/* free local variables*/
@@ -348,12 +386,12 @@ static void vala_gerror_module_real_add_simple_check (ValaCCodeModule* base, Val
 		vala_ccode_base_module_append_error_free ((ValaCCodeBaseModule*) self, ((ValaCCodeBaseModule*) self)->current_symbol, free_frag, ((ValaCCodeBaseModule*) self)->current_try);
 		vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) free_frag);
 		{
-			GeeList* _tmp11;
-			GeeIterator* _tmp12;
+			GeeList* _tmp0;
+			GeeIterator* _tmp1;
 			GeeIterator* _clause_it;
-			_tmp11 = NULL;
-			_tmp12 = NULL;
-			_clause_it = (_tmp12 = gee_iterable_iterator ((GeeIterable*) (_tmp11 = vala_try_statement_get_catch_clauses (((ValaCCodeBaseModule*) self)->current_try))), (_tmp11 == NULL) ? NULL : (_tmp11 = (gee_collection_object_unref (_tmp11), NULL)), _tmp12);
+			_tmp0 = NULL;
+			_tmp1 = NULL;
+			_clause_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_try_statement_get_catch_clauses (((ValaCCodeBaseModule*) self)->current_try))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
 			while (gee_iterator_next (_clause_it)) {
 				ValaCatchClause* clause;
 				ValaCCodeGotoStatement* cgoto_stmt;
@@ -361,27 +399,68 @@ static void vala_gerror_module_real_add_simple_check (ValaCCodeModule* base, Val
 				/* go to catch clause if error domain matches*/
 				cgoto_stmt = vala_ccode_goto_statement_new (vala_catch_clause_get_clabel_name (clause));
 				if (vala_data_type_equals (vala_catch_clause_get_error_type (clause), (ValaDataType*) ((ValaCCodeBaseModule*) self)->gerror_type)) {
-					/* general catch clause*/
+					/* general catch clause, this should be the last one*/
 					vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) cgoto_stmt);
+					(clause == NULL) ? NULL : (clause = (vala_code_node_unref (clause), NULL));
+					(cgoto_stmt == NULL) ? NULL : (cgoto_stmt = (vala_ccode_node_unref (cgoto_stmt), NULL));
+					break;
 				} else {
-					ValaCCodeIdentifier* _tmp15;
-					char* _tmp14;
-					ValaCCodeMemberAccess* _tmp13;
-					ValaCCodeBinaryExpression* _tmp16;
-					ValaCCodeBinaryExpression* ccond;
+					ValaErrorType* _tmp3;
+					ValaDataType* _tmp2;
+					ValaErrorType* catch_type;
 					ValaCCodeBlock* cgoto_block;
-					ValaCCodeIfStatement* _tmp17;
-					_tmp15 = NULL;
-					_tmp14 = NULL;
-					_tmp13 = NULL;
-					_tmp16 = NULL;
-					ccond = (_tmp16 = vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_EQUALITY, (ValaCCodeExpression*) (_tmp13 = vala_ccode_member_access_new_pointer (inner_error, "domain")), (ValaCCodeExpression*) (_tmp15 = vala_ccode_identifier_new (_tmp14 = vala_typesymbol_get_upper_case_cname (vala_data_type_get_data_type (vala_catch_clause_get_error_type (clause)), NULL)))), (_tmp15 == NULL) ? NULL : (_tmp15 = (vala_ccode_node_unref (_tmp15), NULL)), _tmp14 = (g_free (_tmp14), NULL), (_tmp13 == NULL) ? NULL : (_tmp13 = (vala_ccode_node_unref (_tmp13), NULL)), _tmp16);
+					_tmp3 = NULL;
+					_tmp2 = NULL;
+					catch_type = (_tmp3 = (_tmp2 = vala_catch_clause_get_error_type (clause), VALA_IS_ERROR_TYPE (_tmp2) ? ((ValaErrorType*) _tmp2) : NULL), (_tmp3 == NULL) ? NULL : vala_code_node_ref (_tmp3));
 					cgoto_block = vala_ccode_block_new ();
 					vala_ccode_block_add_statement (cgoto_block, (ValaCCodeNode*) cgoto_stmt);
-					_tmp17 = NULL;
-					vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) (_tmp17 = vala_ccode_if_statement_new ((ValaCCodeExpression*) ccond, (ValaCCodeStatement*) cgoto_block, NULL)));
-					(_tmp17 == NULL) ? NULL : (_tmp17 = (vala_ccode_node_unref (_tmp17), NULL));
-					(ccond == NULL) ? NULL : (ccond = (vala_ccode_node_unref (ccond), NULL));
+					if (vala_error_type_get_error_code (catch_type) != NULL) {
+						ValaCCodeIdentifier* _tmp4;
+						ValaCCodeFunctionCall* _tmp5;
+						ValaCCodeFunctionCall* error_match;
+						ValaCCodeIdentifier* _tmp7;
+						char* _tmp6;
+						ValaCCodeIdentifier* _tmp9;
+						char* _tmp8;
+						ValaCCodeIfStatement* _tmp10;
+						/* catch clause specifies a specific error code */
+						_tmp4 = NULL;
+						_tmp5 = NULL;
+						error_match = (_tmp5 = vala_ccode_function_call_new ((ValaCCodeExpression*) (_tmp4 = vala_ccode_identifier_new ("g_error_matches"))), (_tmp4 == NULL) ? NULL : (_tmp4 = (vala_ccode_node_unref (_tmp4), NULL)), _tmp5);
+						vala_ccode_function_call_add_argument (error_match, inner_error);
+						_tmp7 = NULL;
+						_tmp6 = NULL;
+						vala_ccode_function_call_add_argument (error_match, (ValaCCodeExpression*) (_tmp7 = vala_ccode_identifier_new (_tmp6 = vala_typesymbol_get_upper_case_cname (vala_data_type_get_data_type ((ValaDataType*) catch_type), NULL))));
+						(_tmp7 == NULL) ? NULL : (_tmp7 = (vala_ccode_node_unref (_tmp7), NULL));
+						_tmp6 = (g_free (_tmp6), NULL);
+						_tmp9 = NULL;
+						_tmp8 = NULL;
+						vala_ccode_function_call_add_argument (error_match, (ValaCCodeExpression*) (_tmp9 = vala_ccode_identifier_new (_tmp8 = vala_typesymbol_get_cname ((ValaTypeSymbol*) vala_error_type_get_error_code (catch_type), FALSE))));
+						(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL));
+						_tmp8 = (g_free (_tmp8), NULL);
+						_tmp10 = NULL;
+						vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) (_tmp10 = vala_ccode_if_statement_new ((ValaCCodeExpression*) error_match, (ValaCCodeStatement*) cgoto_block, NULL)));
+						(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_ccode_node_unref (_tmp10), NULL));
+						(error_match == NULL) ? NULL : (error_match = (vala_ccode_node_unref (error_match), NULL));
+					} else {
+						ValaCCodeIdentifier* _tmp13;
+						char* _tmp12;
+						ValaCCodeMemberAccess* _tmp11;
+						ValaCCodeBinaryExpression* _tmp14;
+						ValaCCodeBinaryExpression* ccond;
+						ValaCCodeIfStatement* _tmp15;
+						/* catch clause specifies a full error domain */
+						_tmp13 = NULL;
+						_tmp12 = NULL;
+						_tmp11 = NULL;
+						_tmp14 = NULL;
+						ccond = (_tmp14 = vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_EQUALITY, (ValaCCodeExpression*) (_tmp11 = vala_ccode_member_access_new_pointer (inner_error, "domain")), (ValaCCodeExpression*) (_tmp13 = vala_ccode_identifier_new (_tmp12 = vala_typesymbol_get_upper_case_cname (vala_data_type_get_data_type (vala_catch_clause_get_error_type (clause)), NULL)))), (_tmp13 == NULL) ? NULL : (_tmp13 = (vala_ccode_node_unref (_tmp13), NULL)), _tmp12 = (g_free (_tmp12), NULL), (_tmp11 == NULL) ? NULL : (_tmp11 = (vala_ccode_node_unref (_tmp11), NULL)), _tmp14);
+						_tmp15 = NULL;
+						vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) (_tmp15 = vala_ccode_if_statement_new ((ValaCCodeExpression*) ccond, (ValaCCodeStatement*) cgoto_block, NULL)));
+						(_tmp15 == NULL) ? NULL : (_tmp15 = (vala_ccode_node_unref (_tmp15), NULL));
+						(ccond == NULL) ? NULL : (ccond = (vala_ccode_node_unref (ccond), NULL));
+					}
+					(catch_type == NULL) ? NULL : (catch_type = (vala_code_node_unref (catch_type), NULL));
 					(cgoto_block == NULL) ? NULL : (cgoto_block = (vala_ccode_node_unref (cgoto_block), NULL));
 				}
 				(clause == NULL) ? NULL : (clause = (vala_code_node_unref (clause), NULL));
@@ -390,79 +469,114 @@ static void vala_gerror_module_real_add_simple_check (ValaCCodeModule* base, Val
 			(_clause_it == NULL) ? NULL : (_clause_it = (gee_collection_object_unref (_clause_it), NULL));
 		}
 		/* go to finally clause if no catch clause matches*/
+		_tmp17 = NULL;
+		_tmp16 = NULL;
+		vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) (_tmp17 = vala_ccode_goto_statement_new (_tmp16 = g_strdup_printf ("__finally%d", self->priv->current_try_id))));
+		(_tmp17 == NULL) ? NULL : (_tmp17 = (vala_ccode_node_unref (_tmp17), NULL));
+		_tmp16 = (g_free (_tmp16), NULL);
 		_tmp19 = NULL;
 		_tmp18 = NULL;
-		vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) (_tmp19 = vala_ccode_goto_statement_new (_tmp18 = g_strdup_printf ("__finally%d", self->priv->current_try_id))));
-		(_tmp19 == NULL) ? NULL : (_tmp19 = (vala_ccode_node_unref (_tmp19), NULL));
-		_tmp18 = (g_free (_tmp18), NULL);
-		_tmp21 = NULL;
-		_tmp20 = NULL;
-		cerror_handler = (_tmp21 = (_tmp20 = (ValaCCodeStatement*) cerror_block, (_tmp20 == NULL) ? NULL : vala_ccode_node_ref (_tmp20)), (cerror_handler == NULL) ? NULL : (cerror_handler = (vala_ccode_node_unref (cerror_handler), NULL)), _tmp21);
+		cerror_handler = (_tmp19 = (_tmp18 = (ValaCCodeStatement*) cerror_block, (_tmp18 == NULL) ? NULL : vala_ccode_node_ref (_tmp18)), (cerror_handler == NULL) ? NULL : (cerror_handler = (vala_ccode_node_unref (cerror_handler), NULL)), _tmp19);
 		(cerror_block == NULL) ? NULL : (cerror_block = (vala_ccode_node_unref (cerror_block), NULL));
 		(free_frag == NULL) ? NULL : (free_frag = (vala_ccode_node_unref (free_frag), NULL));
 	} else {
-		gboolean _tmp22;
-		_tmp22 = FALSE;
+		gboolean _tmp20;
+		_tmp20 = FALSE;
 		if (((ValaCCodeBaseModule*) self)->current_method != NULL) {
-			GeeList* _tmp23;
-			_tmp23 = NULL;
-			_tmp22 = gee_collection_get_size ((GeeCollection*) (_tmp23 = vala_code_node_get_error_types ((ValaCodeNode*) ((ValaCCodeBaseModule*) self)->current_method))) > 0;
-			(_tmp23 == NULL) ? NULL : (_tmp23 = (gee_collection_object_unref (_tmp23), NULL));
+			GeeList* _tmp21;
+			_tmp21 = NULL;
+			_tmp20 = gee_collection_get_size ((GeeCollection*) (_tmp21 = vala_code_node_get_error_types ((ValaCodeNode*) ((ValaCCodeBaseModule*) self)->current_method))) > 0;
+			(_tmp21 == NULL) ? NULL : (_tmp21 = (gee_collection_object_unref (_tmp21), NULL));
 		} else {
-			_tmp22 = FALSE;
+			_tmp20 = FALSE;
 		}
-		if (_tmp22) {
-			ValaCCodeStatement* _tmp24;
-			/* current method can fail, propagate error
-			 TODO ensure one of the error domains matches*/
-			_tmp24 = NULL;
-			cerror_handler = (_tmp24 = vala_gerror_module_return_with_exception (self, inner_error), (cerror_handler == NULL) ? NULL : (cerror_handler = (vala_ccode_node_unref (cerror_handler), NULL)), _tmp24);
-		} else {
-			ValaCCodeBlock* cerror_block;
-			ValaCCodeFragment* free_frag;
-			ValaCCodeStatement* _tmp29;
-			ValaCCodeStatement* _tmp28;
-			/* unhandled error*/
-			cerror_block = vala_ccode_block_new ();
-			/* free local variables*/
-			free_frag = vala_ccode_fragment_new ();
-			vala_ccode_base_module_append_local_free ((ValaCCodeBaseModule*) self, ((ValaCCodeBaseModule*) self)->current_symbol, free_frag, FALSE);
-			vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) free_frag);
-			/* print critical message*/
-			vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) cprint_frag);
-			if (VALA_IS_VOID_TYPE (((ValaCCodeBaseModule*) self)->current_return_type)) {
-				ValaCCodeReturnStatement* _tmp25;
-				_tmp25 = NULL;
-				vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) (_tmp25 = vala_ccode_return_statement_new (NULL)));
-				(_tmp25 == NULL) ? NULL : (_tmp25 = (vala_ccode_node_unref (_tmp25), NULL));
-			} else {
-				if (((ValaCCodeBaseModule*) self)->current_return_type != NULL) {
-					ValaCCodeReturnStatement* _tmp27;
-					ValaCCodeExpression* _tmp26;
+		if (_tmp20) {
+			ValaCCodeBinaryExpression* ccond;
+			/* current method can fail, propagate error*/
+			ccond = NULL;
+			{
+				GeeList* _tmp22;
+				GeeIterator* _tmp23;
+				GeeIterator* _error_type_it;
+				_tmp22 = NULL;
+				_tmp23 = NULL;
+				_error_type_it = (_tmp23 = gee_iterable_iterator ((GeeIterable*) (_tmp22 = vala_code_node_get_error_types ((ValaCodeNode*) ((ValaCCodeBaseModule*) self)->current_method))), (_tmp22 == NULL) ? NULL : (_tmp22 = (gee_collection_object_unref (_tmp22), NULL)), _tmp23);
+				while (gee_iterator_next (_error_type_it)) {
+					ValaDataType* error_type;
+					ValaCCodeIdentifier* _tmp27;
+					char* _tmp26;
+					ValaCCodeMemberAccess* _tmp25;
+					ValaCCodeBinaryExpression* _tmp28;
+					ValaCCodeBinaryExpression* domain_check;
+					error_type = (ValaDataType*) gee_iterator_get (_error_type_it);
+					/* If GLib.Error is allowed we propagate everything*/
+					if (vala_data_type_equals (error_type, (ValaDataType*) ((ValaCCodeBaseModule*) self)->gerror_type)) {
+						ValaCCodeBinaryExpression* _tmp24;
+						_tmp24 = NULL;
+						ccond = (_tmp24 = NULL, (ccond == NULL) ? NULL : (ccond = (vala_ccode_node_unref (ccond), NULL)), _tmp24);
+						(error_type == NULL) ? NULL : (error_type = (vala_code_node_unref (error_type), NULL));
+						break;
+					}
+					/* Check the allowed error domains to propagate*/
 					_tmp27 = NULL;
 					_tmp26 = NULL;
-					vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) (_tmp27 = vala_ccode_return_statement_new (_tmp26 = vala_ccode_base_module_default_value_for_type ((ValaCCodeBaseModule*) self, ((ValaCCodeBaseModule*) self)->current_return_type, FALSE))));
-					(_tmp27 == NULL) ? NULL : (_tmp27 = (vala_ccode_node_unref (_tmp27), NULL));
-					(_tmp26 == NULL) ? NULL : (_tmp26 = (vala_ccode_node_unref (_tmp26), NULL));
+					_tmp25 = NULL;
+					_tmp28 = NULL;
+					domain_check = (_tmp28 = vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_EQUALITY, (ValaCCodeExpression*) (_tmp25 = vala_ccode_member_access_new_pointer (inner_error, "domain")), (ValaCCodeExpression*) (_tmp27 = vala_ccode_identifier_new (_tmp26 = vala_typesymbol_get_upper_case_cname (vala_data_type_get_data_type (error_type), NULL)))), (_tmp27 == NULL) ? NULL : (_tmp27 = (vala_ccode_node_unref (_tmp27), NULL)), _tmp26 = (g_free (_tmp26), NULL), (_tmp25 == NULL) ? NULL : (_tmp25 = (vala_ccode_node_unref (_tmp25), NULL)), _tmp28);
+					if (ccond == NULL) {
+						ValaCCodeBinaryExpression* _tmp30;
+						ValaCCodeBinaryExpression* _tmp29;
+						_tmp30 = NULL;
+						_tmp29 = NULL;
+						ccond = (_tmp30 = (_tmp29 = domain_check, (_tmp29 == NULL) ? NULL : vala_ccode_node_ref (_tmp29)), (ccond == NULL) ? NULL : (ccond = (vala_ccode_node_unref (ccond), NULL)), _tmp30);
+					} else {
+						ValaCCodeBinaryExpression* _tmp31;
+						_tmp31 = NULL;
+						ccond = (_tmp31 = vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_OR, (ValaCCodeExpression*) ccond, (ValaCCodeExpression*) domain_check), (ccond == NULL) ? NULL : (ccond = (vala_ccode_node_unref (ccond), NULL)), _tmp31);
+					}
+					(error_type == NULL) ? NULL : (error_type = (vala_code_node_unref (error_type), NULL));
+					(domain_check == NULL) ? NULL : (domain_check = (vala_ccode_node_unref (domain_check), NULL));
 				}
+				(_error_type_it == NULL) ? NULL : (_error_type_it = (gee_collection_object_unref (_error_type_it), NULL));
 			}
-			_tmp29 = NULL;
-			_tmp28 = NULL;
-			cerror_handler = (_tmp29 = (_tmp28 = (ValaCCodeStatement*) cerror_block, (_tmp28 == NULL) ? NULL : vala_ccode_node_ref (_tmp28)), (cerror_handler == NULL) ? NULL : (cerror_handler = (vala_ccode_node_unref (cerror_handler), NULL)), _tmp29);
-			(cerror_block == NULL) ? NULL : (cerror_block = (vala_ccode_node_unref (cerror_block), NULL));
-			(free_frag == NULL) ? NULL : (free_frag = (vala_ccode_node_unref (free_frag), NULL));
+			if (ccond == NULL) {
+				ValaCCodeStatement* _tmp32;
+				_tmp32 = NULL;
+				cerror_handler = (_tmp32 = vala_gerror_module_return_with_exception (self, inner_error), (cerror_handler == NULL) ? NULL : (cerror_handler = (vala_ccode_node_unref (cerror_handler), NULL)), _tmp32);
+			} else {
+				ValaCCodeBlock* cerror_block;
+				ValaCCodeIfStatement* _tmp35;
+				ValaCCodeStatement* _tmp34;
+				ValaCCodeStatement* _tmp33;
+				ValaCCodeStatement* _tmp37;
+				ValaCCodeStatement* _tmp36;
+				cerror_block = vala_ccode_block_new ();
+				_tmp35 = NULL;
+				_tmp34 = NULL;
+				_tmp33 = NULL;
+				vala_ccode_block_add_statement (cerror_block, (ValaCCodeNode*) (_tmp35 = vala_ccode_if_statement_new ((ValaCCodeExpression*) ccond, _tmp33 = vala_gerror_module_return_with_exception (self, inner_error), _tmp34 = vala_gerror_module_uncaught_error_statement (self, inner_error))));
+				(_tmp35 == NULL) ? NULL : (_tmp35 = (vala_ccode_node_unref (_tmp35), NULL));
+				(_tmp34 == NULL) ? NULL : (_tmp34 = (vala_ccode_node_unref (_tmp34), NULL));
+				(_tmp33 == NULL) ? NULL : (_tmp33 = (vala_ccode_node_unref (_tmp33), NULL));
+				_tmp37 = NULL;
+				_tmp36 = NULL;
+				cerror_handler = (_tmp37 = (_tmp36 = (ValaCCodeStatement*) cerror_block, (_tmp36 == NULL) ? NULL : vala_ccode_node_ref (_tmp36)), (cerror_handler == NULL) ? NULL : (cerror_handler = (vala_ccode_node_unref (cerror_handler), NULL)), _tmp37);
+				(cerror_block == NULL) ? NULL : (cerror_block = (vala_ccode_node_unref (cerror_block), NULL));
+			}
+			(ccond == NULL) ? NULL : (ccond = (vala_ccode_node_unref (ccond), NULL));
+		} else {
+			ValaCCodeStatement* _tmp38;
+			_tmp38 = NULL;
+			cerror_handler = (_tmp38 = vala_gerror_module_uncaught_error_statement (self, inner_error), (cerror_handler == NULL) ? NULL : (cerror_handler = (vala_ccode_node_unref (cerror_handler), NULL)), _tmp38);
 		}
 	}
-	_tmp30 = NULL;
-	_tmp31 = NULL;
-	ccond = (_tmp31 = vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_INEQUALITY, inner_error, (ValaCCodeExpression*) (_tmp30 = vala_ccode_constant_new ("NULL"))), (_tmp30 == NULL) ? NULL : (_tmp30 = (vala_ccode_node_unref (_tmp30), NULL)), _tmp31);
-	_tmp32 = NULL;
-	vala_ccode_fragment_append (cfrag, (ValaCCodeNode*) (_tmp32 = vala_ccode_if_statement_new ((ValaCCodeExpression*) ccond, cerror_handler, NULL)));
-	(_tmp32 == NULL) ? NULL : (_tmp32 = (vala_ccode_node_unref (_tmp32), NULL));
+	_tmp39 = NULL;
+	_tmp40 = NULL;
+	ccond = (_tmp40 = vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_INEQUALITY, inner_error, (ValaCCodeExpression*) (_tmp39 = vala_ccode_constant_new ("NULL"))), (_tmp39 == NULL) ? NULL : (_tmp39 = (vala_ccode_node_unref (_tmp39), NULL)), _tmp40);
+	_tmp41 = NULL;
+	vala_ccode_fragment_append (cfrag, (ValaCCodeNode*) (_tmp41 = vala_ccode_if_statement_new ((ValaCCodeExpression*) ccond, cerror_handler, NULL)));
+	(_tmp41 == NULL) ? NULL : (_tmp41 = (vala_ccode_node_unref (_tmp41), NULL));
 	(inner_error == NULL) ? NULL : (inner_error = (vala_ccode_node_unref (inner_error), NULL));
-	(cprint_frag == NULL) ? NULL : (cprint_frag = (vala_ccode_node_unref (cprint_frag), NULL));
-	(ccritical == NULL) ? NULL : (ccritical = (vala_ccode_node_unref (ccritical), NULL));
-	(cclear == NULL) ? NULL : (cclear = (vala_ccode_node_unref (cclear), NULL));
 	(cerror_handler == NULL) ? NULL : (cerror_handler = (vala_ccode_node_unref (cerror_handler), NULL));
 	(ccond == NULL) ? NULL : (ccond = (vala_ccode_node_unref (ccond), NULL));
 }
