@@ -47,7 +47,7 @@ ValaArrayMoveMethod* vala_array_move_method_construct (GType object_type, ValaSo
 	ValaVoidType* _tmp0;
 	g_return_val_if_fail (source_reference != NULL, NULL);
 	_tmp0 = NULL;
-	self = (ValaArrayMoveMethod*) vala_method_construct (object_type, "move", (ValaDataType*) (_tmp0 = vala_void_type_new ()), source_reference);
+	self = (ValaArrayMoveMethod*) vala_method_construct (object_type, "move", (ValaDataType*) (_tmp0 = vala_void_type_new (NULL)), source_reference);
 	(_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL));
 	vala_symbol_set_external ((ValaSymbol*) self, TRUE);
 	return self;
