@@ -58,9 +58,13 @@ struct _ValaBlockClass {
 ValaBlock* vala_block_construct (GType object_type, ValaSourceReference* source_reference);
 ValaBlock* vala_block_new (ValaSourceReference* source_reference);
 void vala_block_add_statement (ValaBlock* self, ValaStatement* stmt);
+void vala_block_insert_statement (ValaBlock* self, gint index, ValaStatement* stmt);
 GeeList* vala_block_get_statements (ValaBlock* self);
 void vala_block_add_local_variable (ValaBlock* self, ValaLocalVariable* local);
+void vala_block_remove_local_variable (ValaBlock* self, ValaLocalVariable* local);
 GeeList* vala_block_get_local_variables (ValaBlock* self);
+void vala_block_insert_before (ValaBlock* self, ValaStatement* stmt, ValaStatement* new_stmt);
+void vala_block_replace_statement (ValaBlock* self, ValaStatement* old_stmt, ValaStatement* new_stmt);
 gboolean vala_block_get_contains_jump_statement (ValaBlock* self);
 void vala_block_set_contains_jump_statement (ValaBlock* self, gboolean value);
 GType vala_block_get_type (void);
