@@ -76,7 +76,7 @@ struct _ValaCodeContextPrivate {
 enum  {
 	VALA_CODE_CONTEXT_DUMMY_PROPERTY
 };
-static GeeList* vala_code_context_context_stack = NULL;
+static GStaticPrivate vala_code_context_context_stack_key = {0};
 static ValaSourceFile* vala_code_context_find_cycle_head (ValaCodeContext* self, ValaSourceFile* file);
 static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file, GeeList* chain);
 static gpointer vala_code_context_parent_class = NULL;
@@ -125,7 +125,9 @@ ValaCodeContext* vala_code_context_new (void) {
  * Return the topmost context from the context stack.
  */
 ValaCodeContext* vala_code_context_get (void) {
-	return (ValaCodeContext*) gee_list_get (vala_code_context_context_stack, gee_collection_get_size ((GeeCollection*) vala_code_context_context_stack) - 1);
+	GeeList* context_stack;
+	context_stack = g_static_private_get (&vala_code_context_context_stack_key);
+	return (ValaCodeContext*) gee_list_get (context_stack, gee_collection_get_size ((GeeCollection*) context_stack) - 1);
 }
 
 
@@ -133,13 +135,14 @@ ValaCodeContext* vala_code_context_get (void) {
  * Push the specified context to the context stack.
  */
 void vala_code_context_push (ValaCodeContext* context) {
+	GeeList* context_stack;
 	g_return_if_fail (context != NULL);
-	if (vala_code_context_context_stack == NULL) {
-		GeeList* _tmp0;
-		_tmp0 = NULL;
-		vala_code_context_context_stack = (_tmp0 = (GeeList*) gee_array_list_new (VALA_TYPE_CODE_CONTEXT, (GBoxedCopyFunc) vala_code_context_ref, vala_code_context_unref, g_direct_equal), (vala_code_context_context_stack == NULL) ? NULL : (vala_code_context_context_stack = (gee_collection_object_unref (vala_code_context_context_stack), NULL)), _tmp0);
+	context_stack = g_static_private_get (&vala_code_context_context_stack_key);
+	if (context_stack == NULL) {
+		context_stack = gee_array_list_new (VALA_TYPE_CODE_CONTEXT, (GBoxedCopyFunc) vala_code_context_ref, vala_code_context_unref, g_direct_equal);
+		g_static_private_set (&vala_code_context_context_stack_key, context_stack, NULL);
 	}
-	gee_collection_add ((GeeCollection*) vala_code_context_context_stack, context);
+	gee_collection_add ((GeeCollection*) context_stack, context);
 }
 
 
@@ -147,7 +150,9 @@ void vala_code_context_push (ValaCodeContext* context) {
  * Remove the topmost context from the context stack.
  */
 void vala_code_context_pop (void) {
-	gee_list_remove_at (vala_code_context_context_stack, gee_collection_get_size ((GeeCollection*) vala_code_context_context_stack) - 1);
+	GeeList* context_stack;
+	context_stack = g_static_private_get (&vala_code_context_context_stack_key);
+	gee_list_remove_at (context_stack, gee_collection_get_size ((GeeCollection*) context_stack) - 1);
 }
 
 
@@ -1049,9 +1054,11 @@ void vala_value_set_code_context (GValue* value, gpointer v_object) {
 
 
 static void vala_code_context_class_init (ValaCodeContextClass * klass) {
+	GStaticPrivate _tmp0 = {0};
 	vala_code_context_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_CONTEXT_CLASS (klass)->finalize = vala_code_context_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCodeContextPrivate));
+	vala_code_context_context_stack_key = (g_static_private_init (&_tmp0), _tmp0);
 }
 
 
