@@ -47,6 +47,8 @@ typedef struct _ValaSourceFile ValaSourceFile;
 typedef struct _ValaSourceFileClass ValaSourceFileClass;
 typedef struct _ValaCodeContext ValaCodeContext;
 typedef struct _ValaCodeContextClass ValaCodeContextClass;
+typedef struct _ValaReport ValaReport;
+typedef struct _ValaReportClass ValaReportClass;
 typedef struct _ValaNamespace ValaNamespace;
 typedef struct _ValaNamespaceClass ValaNamespaceClass;
 typedef struct _ValaSymbol ValaSymbol;
@@ -57,86 +59,94 @@ typedef struct _ValaSemanticAnalyzer ValaSemanticAnalyzer;
 typedef struct _ValaSemanticAnalyzerClass ValaSemanticAnalyzerClass;
 typedef struct _ValaCodeVisitor ValaCodeVisitor;
 typedef struct _ValaCodeVisitorClass ValaCodeVisitorClass;
-typedef struct _ValaClass ValaClass;
-typedef struct _ValaClassClass ValaClassClass;
-typedef struct _ValaMethod ValaMethod;
-typedef struct _ValaMethodClass ValaMethodClass;
-typedef struct _ValaBlock ValaBlock;
-typedef struct _ValaBlockClass ValaBlockClass;
-typedef struct _ValaStatement ValaStatement;
-typedef struct _ValaStatementIface ValaStatementIface;
-typedef struct _ValaLocalVariable ValaLocalVariable;
-typedef struct _ValaLocalVariableClass ValaLocalVariableClass;
-typedef struct _ValaMember ValaMember;
-typedef struct _ValaMemberClass ValaMemberClass;
-typedef struct _ValaFormalParameter ValaFormalParameter;
-typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
-typedef struct _ValaBasicBlock ValaBasicBlock;
-typedef struct _ValaBasicBlockClass ValaBasicBlockClass;
-typedef struct _ValaConstructor ValaConstructor;
-typedef struct _ValaConstructorClass ValaConstructorClass;
-typedef struct _ValaDestructor ValaDestructor;
-typedef struct _ValaDestructorClass ValaDestructorClass;
-typedef struct _ValaTypeSymbol ValaTypeSymbol;
-typedef struct _ValaTypeSymbolClass ValaTypeSymbolClass;
-typedef struct _ValaObjectTypeSymbol ValaObjectTypeSymbol;
-typedef struct _ValaObjectTypeSymbolClass ValaObjectTypeSymbolClass;
 typedef struct _ValaTypeParameter ValaTypeParameter;
 typedef struct _ValaTypeParameterClass ValaTypeParameterClass;
-typedef struct _ValaConstant ValaConstant;
-typedef struct _ValaConstantClass ValaConstantClass;
+typedef struct _ValaTypeSymbol ValaTypeSymbol;
+typedef struct _ValaTypeSymbolClass ValaTypeSymbolClass;
+typedef struct _ValaMember ValaMember;
+typedef struct _ValaMemberClass ValaMemberClass;
 typedef struct _ValaField ValaField;
 typedef struct _ValaFieldClass ValaFieldClass;
-typedef struct _ValaProperty ValaProperty;
-typedef struct _ValaPropertyClass ValaPropertyClass;
-typedef struct _ValaPropertyAccessor ValaPropertyAccessor;
-typedef struct _ValaPropertyAccessorClass ValaPropertyAccessorClass;
-typedef struct _ValaSignal ValaSignal;
-typedef struct _ValaSignalClass ValaSignalClass;
-typedef struct _ValaDelegate ValaDelegate;
-typedef struct _ValaDelegateClass ValaDelegateClass;
-typedef struct _ValaStruct ValaStruct;
-typedef struct _ValaStructClass ValaStructClass;
-typedef struct _ValaEnum ValaEnum;
-typedef struct _ValaEnumClass ValaEnumClass;
-typedef struct _ValaEnumValue ValaEnumValue;
-typedef struct _ValaEnumValueClass ValaEnumValueClass;
 typedef struct _ValaStringLiteral ValaStringLiteral;
 typedef struct _ValaStringLiteralClass ValaStringLiteralClass;
 typedef struct _ValaLiteral ValaLiteral;
 typedef struct _ValaLiteralClass ValaLiteralClass;
+typedef struct _ValaConstant ValaConstant;
+typedef struct _ValaConstantClass ValaConstantClass;
+typedef struct _ValaCreationMethod ValaCreationMethod;
+typedef struct _ValaCreationMethodClass ValaCreationMethodClass;
+typedef struct _ValaMethod ValaMethod;
+typedef struct _ValaMethodClass ValaMethodClass;
+typedef struct _ValaSignal ValaSignal;
+typedef struct _ValaSignalClass ValaSignalClass;
+typedef struct _ValaFormalParameter ValaFormalParameter;
+typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
+typedef struct _ValaDelegate ValaDelegate;
+typedef struct _ValaDelegateClass ValaDelegateClass;
+typedef struct _ValaLocalVariable ValaLocalVariable;
+typedef struct _ValaLocalVariableClass ValaLocalVariableClass;
+typedef struct _ValaBlock ValaBlock;
+typedef struct _ValaBlockClass ValaBlockClass;
+typedef struct _ValaStatement ValaStatement;
+typedef struct _ValaStatementIface ValaStatementIface;
+typedef struct _ValaBasicBlock ValaBasicBlock;
+typedef struct _ValaBasicBlockClass ValaBasicBlockClass;
 typedef struct _ValaBooleanLiteral ValaBooleanLiteral;
 typedef struct _ValaBooleanLiteralClass ValaBooleanLiteralClass;
 typedef struct _ValaRealLiteral ValaRealLiteral;
 typedef struct _ValaRealLiteralClass ValaRealLiteralClass;
 typedef struct _ValaIntegerLiteral ValaIntegerLiteral;
 typedef struct _ValaIntegerLiteralClass ValaIntegerLiteralClass;
-typedef struct _ValaCreationMethod ValaCreationMethod;
-typedef struct _ValaCreationMethodClass ValaCreationMethodClass;
-typedef struct _ValaNullLiteral ValaNullLiteral;
-typedef struct _ValaNullLiteralClass ValaNullLiteralClass;
+typedef struct _ValaEnumValue ValaEnumValue;
+typedef struct _ValaEnumValueClass ValaEnumValueClass;
 typedef struct _ValaMemberAccess ValaMemberAccess;
 typedef struct _ValaMemberAccessClass ValaMemberAccessClass;
-typedef struct _ValaUsingDirective ValaUsingDirective;
-typedef struct _ValaUsingDirectiveClass ValaUsingDirectiveClass;
-typedef struct _ValaPointerIndirection ValaPointerIndirection;
-typedef struct _ValaPointerIndirectionClass ValaPointerIndirectionClass;
-typedef struct _ValaBaseAccess ValaBaseAccess;
-typedef struct _ValaBaseAccessClass ValaBaseAccessClass;
+typedef struct _ValaNullLiteral ValaNullLiteral;
+typedef struct _ValaNullLiteralClass ValaNullLiteralClass;
+typedef struct _ValaInterface ValaInterface;
+typedef struct _ValaInterfaceClass ValaInterfaceClass;
+typedef struct _ValaObjectTypeSymbol ValaObjectTypeSymbol;
+typedef struct _ValaObjectTypeSymbolClass ValaObjectTypeSymbolClass;
+typedef struct _ValaProperty ValaProperty;
+typedef struct _ValaPropertyClass ValaPropertyClass;
+typedef struct _ValaPropertyAccessor ValaPropertyAccessor;
+typedef struct _ValaPropertyAccessorClass ValaPropertyAccessorClass;
+typedef struct _ValaClass ValaClass;
+typedef struct _ValaClassClass ValaClassClass;
+typedef struct _ValaConstructor ValaConstructor;
+typedef struct _ValaConstructorClass ValaConstructorClass;
+typedef struct _ValaDestructor ValaDestructor;
+typedef struct _ValaDestructorClass ValaDestructorClass;
+typedef struct _ValaStruct ValaStruct;
+typedef struct _ValaStructClass ValaStructClass;
+typedef struct _ValaEnum ValaEnum;
+typedef struct _ValaEnumClass ValaEnumClass;
+typedef struct _ValaErrorCode ValaErrorCode;
+typedef struct _ValaErrorCodeClass ValaErrorCodeClass;
+typedef struct _ValaErrorDomain ValaErrorDomain;
+typedef struct _ValaErrorDomainClass ValaErrorDomainClass;
+typedef struct _ValaReturnStatement ValaReturnStatement;
+typedef struct _ValaReturnStatementClass ValaReturnStatementClass;
+typedef struct _ValaAssignment ValaAssignment;
+typedef struct _ValaAssignmentClass ValaAssignmentClass;
+typedef struct _ValaElementAccess ValaElementAccess;
+typedef struct _ValaElementAccessClass ValaElementAccessClass;
 typedef struct _ValaMethodCall ValaMethodCall;
 typedef struct _ValaMethodCallClass ValaMethodCallClass;
 typedef struct _ValaObjectCreationExpression ValaObjectCreationExpression;
 typedef struct _ValaObjectCreationExpressionClass ValaObjectCreationExpressionClass;
 typedef struct _ValaMemberInitializer ValaMemberInitializer;
 typedef struct _ValaMemberInitializerClass ValaMemberInitializerClass;
-typedef struct _ValaErrorCode ValaErrorCode;
-typedef struct _ValaErrorCodeClass ValaErrorCodeClass;
-typedef struct _ValaErrorDomain ValaErrorDomain;
-typedef struct _ValaErrorDomainClass ValaErrorDomainClass;
+typedef struct _ValaUsingDirective ValaUsingDirective;
+typedef struct _ValaUsingDirectiveClass ValaUsingDirectiveClass;
+typedef struct _ValaPointerIndirection ValaPointerIndirection;
+typedef struct _ValaPointerIndirectionClass ValaPointerIndirectionClass;
+typedef struct _ValaBaseAccess ValaBaseAccess;
+typedef struct _ValaBaseAccessClass ValaBaseAccessClass;
+typedef struct _ValaExpressionStatement ValaExpressionStatement;
+typedef struct _ValaExpressionStatementClass ValaExpressionStatementClass;
 typedef struct _ValaUnaryExpression ValaUnaryExpression;
 typedef struct _ValaUnaryExpressionClass ValaUnaryExpressionClass;
-typedef struct _ValaParenthesizedExpression ValaParenthesizedExpression;
-typedef struct _ValaParenthesizedExpressionClass ValaParenthesizedExpressionClass;
 typedef struct _ValaBinaryExpression ValaBinaryExpression;
 typedef struct _ValaBinaryExpressionClass ValaBinaryExpressionClass;
 typedef struct _ValaWhileStatement ValaWhileStatement;
@@ -149,20 +159,10 @@ typedef struct _ValaDoStatement ValaDoStatement;
 typedef struct _ValaDoStatementClass ValaDoStatementClass;
 typedef struct _ValaDeclarationStatement ValaDeclarationStatement;
 typedef struct _ValaDeclarationStatementClass ValaDeclarationStatementClass;
-typedef struct _ValaExpressionStatement ValaExpressionStatement;
-typedef struct _ValaExpressionStatementClass ValaExpressionStatementClass;
-typedef struct _ValaAssignment ValaAssignment;
-typedef struct _ValaAssignmentClass ValaAssignmentClass;
-typedef struct _ValaElementAccess ValaElementAccess;
-typedef struct _ValaElementAccessClass ValaElementAccessClass;
 typedef struct _ValaForStatement ValaForStatement;
 typedef struct _ValaForStatementClass ValaForStatementClass;
 typedef struct _ValaYieldStatement ValaYieldStatement;
 typedef struct _ValaYieldStatementClass ValaYieldStatementClass;
-typedef struct _ValaReturnStatement ValaReturnStatement;
-typedef struct _ValaReturnStatementClass ValaReturnStatementClass;
-typedef struct _ValaInterface ValaInterface;
-typedef struct _ValaInterfaceClass ValaInterfaceClass;
 typedef struct _ValaLambdaExpression ValaLambdaExpression;
 typedef struct _ValaLambdaExpressionClass ValaLambdaExpressionClass;
 typedef struct _ValaEmptyStatement ValaEmptyStatement;
@@ -270,11 +270,11 @@ char* vala_code_node_to_string (ValaCodeNode* self);
 void vala_code_node_get_defined_variables (ValaCodeNode* self, GeeCollection* collection);
 void vala_code_node_get_used_variables (ValaCodeNode* self, GeeCollection* collection);
 char* vala_code_node_get_temp_name (ValaCodeNode* self);
-const char* vala_code_node_get_type_name (ValaCodeNode* self);
 ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
 ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
+const char* vala_code_node_get_type_name (ValaCodeNode* self);
 ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self);
 void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value);
 gboolean vala_code_node_get_checked (ValaCodeNode* self);
