@@ -1,6 +1,7 @@
 /* valacodevisitor.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2009  Jürg Billeter
+ * Copyright (C) 2006-2008  Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,57 +24,56 @@
 
 #include <vala/valacodevisitor.h>
 #include <vala/valasourcefile.h>
-#include <vala/valanamespace.h>
-#include <vala/valaclass.h>
+#include <vala/valatypeparameter.h>
 #include <vala/valadatatype.h>
 #include <vala/valamember.h>
 #include <vala/valafield.h>
 #include <vala/valastringliteral.h>
 #include <vala/valaexpression.h>
-#include <vala/valalocalvariable.h>
+#include <vala/valaconstant.h>
+#include <vala/valacreationmethod.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valabooleanliteral.h>
 #include <vala/valarealliteral.h>
 #include <vala/valaintegerliteral.h>
 #include <vala/valaenumvalue.h>
-#include <vala/valacreationmethod.h>
-#include <vala/valablock.h>
-#include <vala/valanullliteral.h>
-#include <vala/valapropertyaccessor.h>
 #include <vala/valamemberaccess.h>
+#include <vala/valalocalvariable.h>
+#include <vala/valadelegate.h>
+#include <vala/valanullliteral.h>
+#include <vala/valasignal.h>
+#include <vala/valainterface.h>
+#include <vala/valaenum.h>
+#include <vala/valamethod.h>
+#include <vala/valaproperty.h>
+#include <vala/valaclass.h>
+#include <vala/valastruct.h>
+#include <vala/valaerrorcode.h>
+#include <vala/valaerrordomain.h>
+#include <vala/valareturnstatement.h>
+#include <vala/valaassignment.h>
+#include <vala/valaelementaccess.h>
+#include <vala/valamethodcall.h>
+#include <vala/valaobjectcreationexpression.h>
 #include <vala/valaconstructor.h>
+#include <vala/valablock.h>
 #include <vala/valadestructor.h>
 #include <vala/valausingdirective.h>
 #include <vala/valapointerindirection.h>
 #include <vala/valabaseaccess.h>
-#include <vala/valamethodcall.h>
-#include <vala/valaobjectcreationexpression.h>
-#include <vala/valaerrorcode.h>
-#include <vala/valasignal.h>
-#include <vala/valaerrordomain.h>
-#include <vala/valamethod.h>
+#include <vala/valaexpressionstatement.h>
 #include <vala/valaunaryexpression.h>
-#include <vala/valaparenthesizedexpression.h>
 #include <vala/valabinaryexpression.h>
 #include <vala/valawhilestatement.h>
 #include <vala/valabreakstatement.h>
 #include <vala/valaifstatement.h>
 #include <vala/valadostatement.h>
 #include <vala/valadeclarationstatement.h>
-#include <vala/valaexpressionstatement.h>
-#include <vala/valaassignment.h>
-#include <vala/valaelementaccess.h>
 #include <vala/valaforstatement.h>
 #include <vala/valayieldstatement.h>
-#include <vala/valareturnstatement.h>
-#include <vala/valaproperty.h>
-#include <vala/valainterface.h>
-#include <vala/valaenum.h>
-#include <vala/valadelegate.h>
 #include <vala/valalambdaexpression.h>
-#include <vala/valaconstant.h>
-#include <vala/valastruct.h>
-#include <vala/valatypeparameter.h>
+#include <vala/valapropertyaccessor.h>
+#include <vala/valanamespace.h>
 #include <vala/valaemptystatement.h>
 #include <vala/valaarraycreationexpression.h>
 #include <vala/valainitializerlist.h>
@@ -159,7 +159,6 @@ static void vala_code_visitor_real_visit_integer_literal (ValaCodeVisitor* self,
 static void vala_code_visitor_real_visit_real_literal (ValaCodeVisitor* self, ValaRealLiteral* lit);
 static void vala_code_visitor_real_visit_string_literal (ValaCodeVisitor* self, ValaStringLiteral* lit);
 static void vala_code_visitor_real_visit_null_literal (ValaCodeVisitor* self, ValaNullLiteral* lit);
-static void vala_code_visitor_real_visit_parenthesized_expression (ValaCodeVisitor* self, ValaParenthesizedExpression* expr);
 static void vala_code_visitor_real_visit_member_access (ValaCodeVisitor* self, ValaMemberAccess* expr);
 static void vala_code_visitor_real_visit_method_call (ValaCodeVisitor* self, ValaMethodCall* expr);
 static void vala_code_visitor_real_visit_element_access (ValaCodeVisitor* self, ValaElementAccess* expr);
@@ -1064,22 +1063,6 @@ void vala_code_visitor_visit_null_literal (ValaCodeVisitor* self, ValaNullLitera
 }
 
 
-/**
- * Visit operation called for parenthesized expressions.
- *
- * @param expr a parenthesized expression
- */
-static void vala_code_visitor_real_visit_parenthesized_expression (ValaCodeVisitor* self, ValaParenthesizedExpression* expr) {
-	g_return_if_fail (self != NULL);
-	g_return_if_fail (expr != NULL);
-}
-
-
-void vala_code_visitor_visit_parenthesized_expression (ValaCodeVisitor* self, ValaParenthesizedExpression* expr) {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_parenthesized_expression (self, expr);
-}
-
-
 /**
  * Visit operation called for member access expressions.
  *
@@ -1535,7 +1518,6 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_real_literal = vala_code_visitor_real_visit_real_literal;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_string_literal = vala_code_visitor_real_visit_string_literal;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_null_literal = vala_code_visitor_real_visit_null_literal;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_parenthesized_expression = vala_code_visitor_real_visit_parenthesized_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_member_access = vala_code_visitor_real_visit_member_access;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_method_call = vala_code_visitor_real_visit_method_call;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_element_access = vala_code_visitor_real_visit_element_access;
