@@ -44,9 +44,9 @@ static ValaStatementIface* vala_continue_statement_vala_statement_parent_iface =
  */
 ValaContinueStatement* vala_continue_statement_construct (GType object_type, ValaSourceReference* source) {
 	ValaContinueStatement* self;
-	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = ((ValaContinueStatement*) (g_type_create_instance (object_type)));
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	g_return_val_if_fail (source != NULL, NULL);
+	self = (ValaContinueStatement*) g_type_create_instance (object_type);
+	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
 }
 
@@ -58,8 +58,8 @@ ValaContinueStatement* vala_continue_statement_new (ValaSourceReference* source)
 
 static void vala_continue_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaContinueStatement * self;
-	self = VALA_CONTINUE_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = (ValaContinueStatement*) base;
+	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_continue_statement (visitor, self);
 }
 
