@@ -30,7 +30,6 @@
 #include <vala/valadatatype.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaformalparameter.h>
-#include <vala/valablock.h>
 #include <vala/valasymbol.h>
 #include <vala/valatypesymbol.h>
 #include <vala/valastruct.h>
@@ -43,7 +42,7 @@
 
 
 struct _ValaCreationMethodPrivate {
-	char* _type_name;
+	char* _class_name;
 	gint _n_construction_params;
 	char* _custom_return_type_cname;
 	gboolean _chain_up;
@@ -71,21 +70,21 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source_reference reference to source code
  * @return                 newly created method
  */
-ValaCreationMethod* vala_creation_method_construct (GType object_type, const char* type_name, const char* name, ValaSourceReference* source_reference) {
+ValaCreationMethod* vala_creation_method_construct (GType object_type, const char* class_name, const char* name, ValaSourceReference* source_reference) {
 	ValaCreationMethod* self;
 	ValaVoidType* _tmp0;
 	_tmp0 = NULL;
 	self = (ValaCreationMethod*) vala_method_construct (object_type, name, (ValaDataType*) (_tmp0 = vala_void_type_new (NULL)), source_reference);
 	(_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL));
-	vala_creation_method_set_type_name (self, type_name);
+	vala_creation_method_set_class_name (self, class_name);
 	vala_method_set_carray_length_parameter_position ((ValaMethod*) self, (double) (-3));
 	vala_method_set_cdelegate_target_parameter_position ((ValaMethod*) self, (double) (-3));
 	return self;
 }
 
 
-ValaCreationMethod* vala_creation_method_new (const char* type_name, const char* name, ValaSourceReference* source_reference) {
-	return vala_creation_method_construct (VALA_TYPE_CREATION_METHOD, type_name, name, source_reference);
+ValaCreationMethod* vala_creation_method_new (const char* class_name, const char* name, ValaSourceReference* source_reference) {
+	return vala_creation_method_construct (VALA_TYPE_CREATION_METHOD, class_name, name, source_reference);
 }
 
 
@@ -252,18 +251,18 @@ static gboolean vala_creation_method_real_check (ValaCodeNode* base, ValaSemanti
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_method_process_attributes ((ValaMethod*) self);
 	_tmp1 = FALSE;
-	if (self->priv->_type_name != NULL) {
-		_tmp1 = _vala_strcmp0 (self->priv->_type_name, vala_symbol_get_name (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) != 0;
+	if (self->priv->_class_name != NULL) {
+		_tmp1 = _vala_strcmp0 (self->priv->_class_name, vala_symbol_get_name (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) != 0;
 	} else {
 		_tmp1 = FALSE;
 	}
 	if (_tmp1) {
 		char* _tmp3;
 		char* _tmp2;
-		/* type_name is null for constructors generated by GIdlParser*/
+		/* class_name is null for constructors generated by GIdlParser*/
 		_tmp3 = NULL;
 		_tmp2 = NULL;
-		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp3 = g_strdup_printf ("missing return type in method `%s.%s´", _tmp2 = vala_symbol_get_full_name (vala_semantic_analyzer_get_current_symbol (analyzer)), self->priv->_type_name));
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp3 = g_strdup_printf ("missing return type in method `%s.%s´", _tmp2 = vala_symbol_get_full_name (vala_semantic_analyzer_get_current_symbol (analyzer)), self->priv->_class_name));
 		_tmp3 = (g_free (_tmp3), NULL);
 		_tmp2 = (g_free (_tmp2), NULL);
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
@@ -385,19 +384,19 @@ static gboolean vala_creation_method_real_check (ValaCodeNode* base, ValaSemanti
 }
 
 
-const char* vala_creation_method_get_type_name (ValaCreationMethod* self) {
+const char* vala_creation_method_get_class_name (ValaCreationMethod* self) {
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_type_name;
+	return self->priv->_class_name;
 }
 
 
-void vala_creation_method_set_type_name (ValaCreationMethod* self, const char* value) {
+void vala_creation_method_set_class_name (ValaCreationMethod* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_type_name = (g_free (self->priv->_type_name), NULL), _tmp2);
+	self->priv->_class_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_class_name = (g_free (self->priv->_class_name), NULL), _tmp2);
 }
 
 
@@ -461,7 +460,7 @@ static void vala_creation_method_instance_init (ValaCreationMethod * self) {
 static void vala_creation_method_finalize (ValaCodeNode* obj) {
 	ValaCreationMethod * self;
 	self = VALA_CREATION_METHOD (obj);
-	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
+	self->priv->_class_name = (g_free (self->priv->_class_name), NULL);
 	self->priv->_custom_return_type_cname = (g_free (self->priv->_custom_return_type_cname), NULL);
 	VALA_CODE_NODE_CLASS (vala_creation_method_parent_class)->finalize (obj);
 }
