@@ -209,7 +209,7 @@ char* vala_data_type_get_const_cname (ValaDataType* self) {
 		ValaTypeSymbol* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		t = (_tmp1 = (_tmp0 = vala_array_type_get_element_type ((VALA_ARRAY_TYPE (self)))->priv->_data_type, (_tmp0 == NULL) ? NULL : vala_code_node_ref (_tmp0)), (t == NULL) ? NULL : (t = (vala_code_node_unref (t), NULL)), _tmp1);
+		t = (_tmp1 = (_tmp0 = vala_array_type_get_element_type (VALA_ARRAY_TYPE (self))->priv->_data_type, (_tmp0 == NULL) ? NULL : vala_code_node_ref (_tmp0)), (t == NULL) ? NULL : (t = (vala_code_node_unref (t), NULL)), _tmp1);
 	} else {
 		ValaTypeSymbol* _tmp3;
 		ValaTypeSymbol* _tmp2;
@@ -337,7 +337,7 @@ static char* vala_data_type_real_to_qualified_string (ValaDataType* self, ValaSc
 		gboolean first;
 		char* _tmp18;
 		_tmp13 = NULL;
-		s = (_tmp13 = g_strconcat (s, ("<"), NULL), s = (g_free (s), NULL), _tmp13);
+		s = (_tmp13 = g_strconcat (s, "<", NULL), s = (g_free (s), NULL), _tmp13);
 		first = TRUE;
 		{
 			GeeIterator* _type_arg_it;
@@ -350,30 +350,30 @@ static char* vala_data_type_real_to_qualified_string (ValaDataType* self, ValaSc
 				if (!first) {
 					char* _tmp14;
 					_tmp14 = NULL;
-					s = (_tmp14 = g_strconcat (s, (","), NULL), s = (g_free (s), NULL), _tmp14);
+					s = (_tmp14 = g_strconcat (s, ",", NULL), s = (g_free (s), NULL), _tmp14);
 				} else {
 					first = FALSE;
 				}
 				if (!type_arg->priv->_value_owned) {
 					char* _tmp15;
 					_tmp15 = NULL;
-					s = (_tmp15 = g_strconcat (s, ("weak "), NULL), s = (g_free (s), NULL), _tmp15);
+					s = (_tmp15 = g_strconcat (s, "weak ", NULL), s = (g_free (s), NULL), _tmp15);
 				}
 				_tmp17 = NULL;
 				_tmp16 = NULL;
-				s = (_tmp17 = g_strconcat (s, _tmp16 = (vala_data_type_to_qualified_string (type_arg, scope)), NULL), s = (g_free (s), NULL), _tmp17);
+				s = (_tmp17 = g_strconcat (s, _tmp16 = vala_data_type_to_qualified_string (type_arg, scope), NULL), s = (g_free (s), NULL), _tmp17);
 				_tmp16 = (g_free (_tmp16), NULL);
 				(type_arg == NULL) ? NULL : (type_arg = (vala_code_node_unref (type_arg), NULL));
 			}
 			(_type_arg_it == NULL) ? NULL : (_type_arg_it = (gee_collection_object_unref (_type_arg_it), NULL));
 		}
 		_tmp18 = NULL;
-		s = (_tmp18 = g_strconcat (s, (">"), NULL), s = (g_free (s), NULL), _tmp18);
+		s = (_tmp18 = g_strconcat (s, ">", NULL), s = (g_free (s), NULL), _tmp18);
 	}
 	if (self->priv->_nullable) {
 		char* _tmp19;
 		_tmp19 = NULL;
-		s = (_tmp19 = g_strconcat (s, ("?"), NULL), s = (g_free (s), NULL), _tmp19);
+		s = (_tmp19 = g_strconcat (s, "?", NULL), s = (g_free (s), NULL), _tmp19);
 	}
 	_tmp20 = NULL;
 	return (_tmp20 = s, (type_args == NULL) ? NULL : (type_args = (gee_collection_object_unref (type_args), NULL)), _tmp20);
@@ -546,7 +546,7 @@ static gboolean vala_data_type_real_compatible (ValaDataType* self, ValaDataType
 		_tmp0 = FALSE;
 	}
 	if (_tmp0) {
-		return vala_delegate_type_get_delegate_symbol ((VALA_DELEGATE_TYPE (target_type))) == vala_delegate_type_get_delegate_symbol ((VALA_DELEGATE_TYPE (self)));
+		return vala_delegate_type_get_delegate_symbol (VALA_DELEGATE_TYPE (target_type)) == vala_delegate_type_get_delegate_symbol (VALA_DELEGATE_TYPE (self));
 	}
 	if (VALA_IS_POINTER_TYPE (target_type)) {
 		gboolean _tmp2;
@@ -564,11 +564,11 @@ static gboolean vala_data_type_real_compatible (ValaDataType* self, ValaDataType
 				} else {
 					_tmp4 = VALA_IS_DELEGATE_TYPE (self);
 				}
-				_tmp3 = (_tmp4);
+				_tmp3 = _tmp4;
 			} else {
 				_tmp3 = FALSE;
 			}
-			_tmp2 = (_tmp3);
+			_tmp2 = _tmp3;
 		}
 		/* any reference or array type or pointer type can be cast to a generic pointer */
 		if (_tmp2) {
@@ -591,7 +591,7 @@ static gboolean vala_data_type_real_compatible (ValaDataType* self, ValaDataType
 		_tmp10 = FALSE;
 	}
 	if (_tmp10) {
-		_tmp9 = vala_struct_is_integer_type ((VALA_STRUCT (target_type->priv->_data_type)));
+		_tmp9 = vala_struct_is_integer_type (VALA_STRUCT (target_type->priv->_data_type));
 	} else {
 		_tmp9 = FALSE;
 	}
@@ -637,7 +637,7 @@ static gboolean vala_data_type_real_compatible (ValaDataType* self, ValaDataType
 		} else {
 			_tmp19 = FALSE;
 		}
-		if ((_tmp19)) {
+		if (_tmp19) {
 			_tmp18 = TRUE;
 		} else {
 			gboolean _tmp20;
@@ -647,7 +647,7 @@ static gboolean vala_data_type_real_compatible (ValaDataType* self, ValaDataType
 			} else {
 				_tmp20 = FALSE;
 			}
-			_tmp18 = (_tmp20);
+			_tmp18 = _tmp20;
 		}
 		if (_tmp18) {
 			if (vala_struct_get_rank (expr_struct) <= vala_struct_get_rank (expect_struct)) {
@@ -741,7 +741,7 @@ static gboolean vala_data_type_real_is_reference_type_or_type_parameter (ValaDat
 	} else {
 		_tmp1 = FALSE;
 	}
-	if ((_tmp1)) {
+	if (_tmp1) {
 		_tmp0 = TRUE;
 	} else {
 		_tmp0 = self->priv->_type_parameter != NULL;
@@ -902,7 +902,7 @@ static char* vala_data_type_real_get_type_signature (ValaDataType* self) {
 					if (s != NULL) {
 						char* _tmp2;
 						_tmp2 = NULL;
-						element_sig = (_tmp2 = g_strconcat (element_sig, (s), NULL), element_sig = (g_free (element_sig), NULL), _tmp2);
+						element_sig = (_tmp2 = g_strconcat (element_sig, s, NULL), element_sig = (g_free (element_sig), NULL), _tmp2);
 					}
 					(type_arg == NULL) ? NULL : (type_arg = (vala_code_node_unref (type_arg), NULL));
 					s = (g_free (s), NULL);
