@@ -99,12 +99,11 @@ gboolean vala_data_type_is_real_struct_type (ValaDataType* self);
 char* vala_data_type_get_type_id (ValaDataType* self);
 char* vala_data_type_get_type_signature (ValaDataType* self);
 gboolean vala_data_type_is_disposable (ValaDataType* self);
+ValaDataType* vala_data_type_get_actual_type (ValaDataType* self, ValaDataType* derived_instance_type, ValaCodeNode* node_reference);
 gboolean vala_data_type_get_value_owned (ValaDataType* self);
 void vala_data_type_set_value_owned (ValaDataType* self, gboolean value);
 gboolean vala_data_type_get_nullable (ValaDataType* self);
 void vala_data_type_set_nullable (ValaDataType* self, gboolean value);
-gboolean vala_data_type_get_is_type_argument (ValaDataType* self);
-void vala_data_type_set_is_type_argument (ValaDataType* self, gboolean value);
 ValaTypeSymbol* vala_data_type_get_data_type (ValaDataType* self);
 void vala_data_type_set_data_type (ValaDataType* self, ValaTypeSymbol* value);
 ValaTypeParameter* vala_data_type_get_type_parameter (ValaDataType* self);
