@@ -37,7 +37,7 @@ struct _ValaDynamicMethodPrivate {
 enum  {
 	VALA_DYNAMIC_METHOD_DUMMY_PROPERTY
 };
-static gint vala_dynamic_method_dynamic_method_id;
+static gint vala_dynamic_method_dynamic_method_id = 0;
 static GeeList* vala_dynamic_method_real_get_cheader_filenames (ValaSymbol* base);
 static char* vala_dynamic_method_real_get_default_cname (ValaMethod* base);
 static gboolean vala_dynamic_method_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
