@@ -34,6 +34,7 @@ struct _ValaDynamicSignalPrivate {
 enum  {
 	VALA_DYNAMIC_SIGNAL_DUMMY_PROPERTY
 };
+static gboolean vala_dynamic_signal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 static gpointer vala_dynamic_signal_parent_class = NULL;
 static void vala_dynamic_signal_finalize (ValaCodeNode* obj);
 
@@ -44,8 +45,7 @@ ValaDynamicSignal* vala_dynamic_signal_construct (GType object_type, ValaDataTyp
 	g_return_val_if_fail (dynamic_type != NULL, NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (return_type != NULL, NULL);
-	self = ((ValaDynamicSignal*) (g_type_create_instance (object_type)));
-	self = ((ValaDynamicSignal*) (vala_signal_construct (object_type, name, return_type, source_reference)));
+	self = (ValaDynamicSignal*) vala_signal_construct (object_type, name, return_type, source_reference);
 	vala_dynamic_signal_set_dynamic_type (self, dynamic_type);
 	return self;
 }
@@ -56,6 +56,14 @@ ValaDynamicSignal* vala_dynamic_signal_new (ValaDataType* dynamic_type, const ch
 }
 
 
+static gboolean vala_dynamic_signal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
+	ValaDynamicSignal * self;
+	self = (ValaDynamicSignal*) base;
+	g_return_val_if_fail (analyzer != NULL, FALSE);
+	return TRUE;
+}
+
+
 ValaDataType* vala_dynamic_signal_get_dynamic_type (ValaDynamicSignal* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_dynamic_type;
@@ -68,7 +76,7 @@ void vala_dynamic_signal_set_dynamic_type (ValaDynamicSignal* self, ValaDataType
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_dynamic_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_dynamic_type == NULL ? NULL : (self->priv->_dynamic_type = (vala_code_node_unref (self->priv->_dynamic_type), NULL))), _tmp2);
+	self->priv->_dynamic_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_dynamic_type == NULL) ? NULL : (self->priv->_dynamic_type = (vala_code_node_unref (self->priv->_dynamic_type), NULL)), _tmp2);
 }
 
 
@@ -84,7 +92,7 @@ void vala_dynamic_signal_set_handler (ValaDynamicSignal* self, ValaExpression* v
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_handler = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_handler == NULL ? NULL : (self->priv->_handler = (vala_code_node_unref (self->priv->_handler), NULL))), _tmp2);
+	self->priv->_handler = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_handler == NULL) ? NULL : (self->priv->_handler = (vala_code_node_unref (self->priv->_handler), NULL)), _tmp2);
 }
 
 
@@ -92,6 +100,7 @@ static void vala_dynamic_signal_class_init (ValaDynamicSignalClass * klass) {
 	vala_dynamic_signal_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_NODE_CLASS (klass)->finalize = vala_dynamic_signal_finalize;
 	g_type_class_add_private (klass, sizeof (ValaDynamicSignalPrivate));
+	VALA_CODE_NODE_CLASS (klass)->check = vala_dynamic_signal_real_check;
 }
 
 
@@ -103,8 +112,8 @@ static void vala_dynamic_signal_instance_init (ValaDynamicSignal * self) {
 static void vala_dynamic_signal_finalize (ValaCodeNode* obj) {
 	ValaDynamicSignal * self;
 	self = VALA_DYNAMIC_SIGNAL (obj);
-	(self->priv->_dynamic_type == NULL ? NULL : (self->priv->_dynamic_type = (vala_code_node_unref (self->priv->_dynamic_type), NULL)));
-	(self->priv->_handler == NULL ? NULL : (self->priv->_handler = (vala_code_node_unref (self->priv->_handler), NULL)));
+	(self->priv->_dynamic_type == NULL) ? NULL : (self->priv->_dynamic_type = (vala_code_node_unref (self->priv->_dynamic_type), NULL));
+	(self->priv->_handler == NULL) ? NULL : (self->priv->_handler = (vala_code_node_unref (self->priv->_handler), NULL));
 	VALA_CODE_NODE_CLASS (vala_dynamic_signal_parent_class)->finalize (obj);
 }
 
