@@ -1,6 +1,6 @@
 /* valaenumvalue.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,6 +27,8 @@
 #include <vala/valaattribute.h>
 #include <vala/valaenum.h>
 #include <vala/valasemanticanalyzer.h>
+#include <vala/valamemberaccess.h>
+#include <vala/valasourcefile.h>
 
 
 
@@ -207,7 +209,7 @@ char* vala_enum_value_get_default_cname (ValaEnumValue* self) {
 	_tmp1 = NULL;
 	_tmp2 = NULL;
 	_tmp3 = NULL;
-	return (_tmp3 = (_tmp2 = g_strdup_printf ("%s%s", _tmp1 = vala_enum_get_cprefix (en), vala_symbol_get_name ((ValaSymbol*) self)), _tmp1 = (g_free (_tmp1), NULL), _tmp2), (en == NULL) ? NULL : (en = (vala_code_node_unref (en), NULL)), _tmp3);
+	return (_tmp3 = (_tmp2 = g_strdup_printf ("%s%s", _tmp1 = vala_symbol_get_cprefix ((ValaSymbol*) en), vala_symbol_get_name ((ValaSymbol*) self)), _tmp1 = (g_free (_tmp1), NULL), _tmp2), (en == NULL) ? NULL : (en = (vala_code_node_unref (en), NULL)), _tmp3);
 }
 
 
@@ -237,7 +239,25 @@ static gboolean vala_enum_value_real_check (ValaCodeNode* base, ValaSemanticAnal
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_enum_value_process_attributes (self);
 	if (self->priv->_value != NULL) {
+		gboolean _tmp1;
+		gboolean _tmp2;
 		vala_code_node_check ((ValaCodeNode*) self->priv->_value, analyzer);
+		_tmp1 = FALSE;
+		_tmp2 = FALSE;
+		if (!vala_symbol_is_internal_symbol (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) {
+			_tmp2 = VALA_IS_MEMBER_ACCESS (self->priv->_value);
+		} else {
+			_tmp2 = FALSE;
+		}
+		if (_tmp2) {
+			_tmp1 = vala_expression_get_symbol_reference (self->priv->_value) != NULL;
+		} else {
+			_tmp1 = FALSE;
+		}
+		/* ensure to include dependency in header file as well if necessary*/
+		if (_tmp1) {
+			vala_source_file_add_symbol_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), vala_expression_get_symbol_reference (self->priv->_value), VALA_SOURCE_FILE_DEPENDENCY_TYPE_HEADER_SHALLOW);
+		}
 	}
 	return !vala_code_node_get_error ((ValaCodeNode*) self);
 }
