@@ -1,6 +1,6 @@
 /* valaexpression.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -264,26 +264,22 @@ ValaStatement* vala_expression_get_parent_statement (ValaExpression* self) {
 	local = (_tmp5 = (_tmp4 = vala_code_node_get_parent_node ((ValaCodeNode*) self), VALA_IS_LOCAL_VARIABLE (_tmp4) ? ((ValaLocalVariable*) _tmp4) : NULL), (_tmp5 == NULL) ? NULL : vala_code_node_ref (_tmp5));
 	if (stmt != NULL) {
 		ValaStatement* _tmp6;
-		ValaStatement* _tmp7;
-		ValaStatement* _tmp8;
 		_tmp6 = NULL;
-		_tmp7 = NULL;
-		_tmp8 = NULL;
-		return (_tmp8 = (_tmp7 = _tmp6 = stmt, (_tmp6 == NULL) ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL)), _tmp7), (expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL)), (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp8);
+		return (_tmp6 = VALA_STATEMENT (vala_code_node_get_parent_node ((ValaCodeNode*) self)), (expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL)), (stmt == NULL) ? NULL : (stmt = (vala_code_node_unref (stmt), NULL)), (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp6);
 	} else {
 		if (expr != NULL) {
-			ValaStatement* _tmp9;
-			_tmp9 = NULL;
-			return (_tmp9 = vala_expression_get_parent_statement (expr), (expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL)), (stmt == NULL) ? NULL : (stmt = (vala_code_node_unref (stmt), NULL)), (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp9);
+			ValaStatement* _tmp7;
+			_tmp7 = NULL;
+			return (_tmp7 = vala_expression_get_parent_statement (expr), (expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL)), (stmt == NULL) ? NULL : (stmt = (vala_code_node_unref (stmt), NULL)), (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp7);
 		} else {
 			if (local != NULL) {
-				ValaStatement* _tmp10;
-				_tmp10 = NULL;
-				return (_tmp10 = VALA_STATEMENT (vala_code_node_get_parent_node ((ValaCodeNode*) local)), (expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL)), (stmt == NULL) ? NULL : (stmt = (vala_code_node_unref (stmt), NULL)), (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp10);
+				ValaStatement* _tmp8;
+				_tmp8 = NULL;
+				return (_tmp8 = VALA_STATEMENT (vala_code_node_get_parent_node ((ValaCodeNode*) local)), (expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL)), (stmt == NULL) ? NULL : (stmt = (vala_code_node_unref (stmt), NULL)), (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp8);
 			} else {
-				ValaStatement* _tmp11;
-				_tmp11 = NULL;
-				return (_tmp11 = NULL, (expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL)), (stmt == NULL) ? NULL : (stmt = (vala_code_node_unref (stmt), NULL)), (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp11);
+				ValaStatement* _tmp9;
+				_tmp9 = NULL;
+				return (_tmp9 = NULL, (expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL)), (stmt == NULL) ? NULL : (stmt = (vala_code_node_unref (stmt), NULL)), (local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL)), _tmp9);
 			}
 		}
 	}
