@@ -394,6 +394,8 @@ static gboolean vala_field_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 	gboolean _tmp7;
 	gboolean field_in_header;
 	gboolean _tmp11;
+	gboolean _tmp12;
+	gboolean _tmp18;
 	self = (ValaField*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -461,6 +463,36 @@ static gboolean vala_field_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 		}
 		(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
 	}
+	_tmp11 = FALSE;
+	_tmp12 = FALSE;
+	if (!vala_symbol_get_external_package ((ValaSymbol*) self)) {
+		_tmp12 = !vala_member_get_hides ((ValaMember*) self);
+	} else {
+		_tmp12 = FALSE;
+	}
+	if (_tmp12) {
+		ValaSymbol* _tmp13;
+		_tmp13 = NULL;
+		_tmp11 = (_tmp13 = vala_member_get_hidden_member ((ValaMember*) self)) != NULL;
+		(_tmp13 == NULL) ? NULL : (_tmp13 = (vala_code_node_unref (_tmp13), NULL));
+	} else {
+		_tmp11 = FALSE;
+	}
+	if (_tmp11) {
+		char* _tmp17;
+		char* _tmp16;
+		ValaSymbol* _tmp15;
+		char* _tmp14;
+		_tmp17 = NULL;
+		_tmp16 = NULL;
+		_tmp15 = NULL;
+		_tmp14 = NULL;
+		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp17 = g_strdup_printf ("%s hides inherited field `%s'. Use the `new' keyword if hiding was intentional", _tmp14 = vala_symbol_get_full_name ((ValaSymbol*) self), _tmp16 = vala_symbol_get_full_name (_tmp15 = vala_member_get_hidden_member ((ValaMember*) self))));
+		_tmp17 = (g_free (_tmp17), NULL);
+		_tmp16 = (g_free (_tmp16), NULL);
+		(_tmp15 == NULL) ? NULL : (_tmp15 = (vala_code_node_unref (_tmp15), NULL));
+		_tmp14 = (g_free (_tmp14), NULL);
+	}
 	if (field_in_header) {
 		if (VALA_IS_VALUE_TYPE (vala_field_get_field_type (self))) {
 			vala_source_file_add_type_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), vala_field_get_field_type (self), VALA_SOURCE_FILE_DEPENDENCY_TYPE_HEADER_FULL);
@@ -472,7 +504,7 @@ static gboolean vala_field_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 	}
 	vala_semantic_analyzer_set_current_source_file (analyzer, old_source_file);
 	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
-	return (_tmp11 = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp11);
+	return (_tmp18 = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp18);
 }
 
 
@@ -562,13 +594,13 @@ void vala_field_set_array_null_terminated (ValaField* self, gboolean value) {
 
 gboolean vala_field_get_has_array_length_cname (ValaField* self) {
 	g_return_val_if_fail (self != NULL, FALSE);
-	return (self->priv->array_length_cname != NULL);
+	return self->priv->array_length_cname != NULL;
 }
 
 
 gboolean vala_field_get_has_array_length_cexpr (ValaField* self) {
 	g_return_val_if_fail (self != NULL, FALSE);
-	return (self->priv->array_length_cexpr != NULL);
+	return self->priv->array_length_cexpr != NULL;
 }
 
 
