@@ -196,8 +196,8 @@ static void vala_for_statement_real_replace_expression (ValaCodeNode* base, Vala
 			ValaExpression* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = (ValaExpression*) gee_list_get ((GeeList*) self->priv->initializer, i)) == old_node, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
-				gee_list_set ((GeeList*) self->priv->initializer, i, new_node);
+			if ((_tmp1 = (_tmp0 = (ValaExpression*) gee_list_get (self->priv->initializer, i)) == old_node, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
+				gee_list_set (self->priv->initializer, i, new_node);
 				return;
 			}
 		}
@@ -209,8 +209,8 @@ static void vala_for_statement_real_replace_expression (ValaCodeNode* base, Vala
 			ValaExpression* _tmp2;
 			gboolean _tmp3;
 			_tmp2 = NULL;
-			if ((_tmp3 = (_tmp2 = (ValaExpression*) gee_list_get ((GeeList*) self->priv->iterator, i)) == old_node, (_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL)), _tmp3)) {
-				gee_list_set ((GeeList*) self->priv->iterator, i, new_node);
+			if ((_tmp3 = (_tmp2 = (ValaExpression*) gee_list_get (self->priv->iterator, i)) == old_node, (_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL)), _tmp3)) {
+				gee_list_set (self->priv->iterator, i, new_node);
 				return;
 			}
 		}
