@@ -101,7 +101,7 @@ static gboolean vala_genie_scanner_is_ident_char (ValaGenieScanner* self, gchar
 	} else {
 		_tmp0 = c == '_';
 	}
-	return (_tmp0);
+	return _tmp0;
 }
 
 
@@ -846,10 +846,10 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 		return VALA_GENIE_TOKEN_TYPE_DEDENT;
 	}
 	_tmp1 = FALSE;
-	if ((self->priv->_indent_spaces == 0)) {
+	if (self->priv->_indent_spaces == 0) {
 		_tmp1 = TRUE;
 	} else {
-		_tmp1 = (self->priv->last_token != VALA_GENIE_TOKEN_TYPE_EOL);
+		_tmp1 = self->priv->last_token != VALA_GENIE_TOKEN_TYPE_EOL;
 	}
 	if (_tmp1) {
 		/* scrub whitespace (excluding newlines) and comments */
@@ -873,7 +873,7 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 		if (!_tmp2) {
 			break;
 		}
-		self->priv->current = self->priv->current + (2);
+		self->priv->current = self->priv->current + 2;
 		self->priv->line++;
 		vala_genie_scanner_skip_space_tabs (self);
 	}
@@ -925,7 +925,7 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 		} else {
 			if (self->priv->current_indent_level < self->priv->indent_level) {
 				self->priv->indent_level--;
-				self->priv->pending_dedents = (self->priv->indent_level - self->priv->current_indent_level);
+				self->priv->pending_dedents = self->priv->indent_level - self->priv->current_indent_level;
 				(*token_end).pos = self->priv->current;
 				(*token_end).line = self->priv->line;
 				(*token_end).column = self->priv->column;
@@ -980,9 +980,9 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 				gint len;
 				len = 0;
 				if (self->priv->current[1] == '@') {
-					(*token_begin).pos = (*token_begin).pos + (2);
+					(*token_begin).pos = (*token_begin).pos + 2;
 					/* @@ is not part of the identifier*/
-					self->priv->current = self->priv->current + (2);
+					self->priv->current = self->priv->current + 2;
 				} else {
 					self->priv->current++;
 					len = 1;
@@ -1117,7 +1117,7 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 										} else {
 											_tmp24 = self->priv->current[0] == '-';
 										}
-										_tmp23 = (_tmp24);
+										_tmp23 = _tmp24;
 									} else {
 										_tmp23 = FALSE;
 									}
@@ -1273,7 +1273,7 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 								}
 								if (_tmp34) {
 									type = VALA_GENIE_TOKEN_TYPE_ELLIPSIS;
-									self->priv->current = self->priv->current + (2);
+									self->priv->current = self->priv->current + 2;
 								}
 							}
 							break;
@@ -1624,9 +1624,9 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 										break;
 									} else {
 										gunichar u;
-										u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
+										u = g_utf8_get_char_validated ((const char*) self->priv->current, (glong) (self->priv->end - self->priv->current));
 										if (u != ((gunichar) (-1))) {
-											self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
+											self->priv->current = self->priv->current + g_unichar_to_utf8 (u, NULL);
 											token_length_in_chars++;
 										} else {
 											ValaSourceReference* _tmp45;
@@ -1659,10 +1659,10 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 						default:
 						{
 							gunichar u;
-							u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
+							u = g_utf8_get_char_validated ((const char*) self->priv->current, (glong) (self->priv->end - self->priv->current));
 							if (u != ((gunichar) (-1))) {
 								ValaSourceReference* _tmp49;
-								self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
+								self->priv->current = self->priv->current + g_unichar_to_utf8 (u, NULL);
 								_tmp49 = NULL;
 								vala_report_error (_tmp49 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, unexpected character");
 								(_tmp49 == NULL) ? NULL : (_tmp49 = (vala_source_reference_unref (_tmp49), NULL));
@@ -1685,7 +1685,7 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 	if (token_length_in_chars < 0) {
 		self->priv->column = self->priv->column + ((gint) (self->priv->current - begin));
 	} else {
-		self->priv->column = self->priv->column + (token_length_in_chars);
+		self->priv->column = self->priv->column + token_length_in_chars;
 	}
 	(*token_end).pos = self->priv->current;
 	(*token_end).line = self->priv->line;
@@ -1739,8 +1739,8 @@ static gint vala_genie_scanner_count_tabs (ValaGenieScanner* self) {
 	/* ignore comments and whitspace and other lines that contain no code */
 	vala_genie_scanner_space (self);
 	_tmp2 = FALSE;
-	if ((self->priv->current < self->priv->end)) {
-		_tmp2 = (self->priv->current[0] == '\n');
+	if (self->priv->current < self->priv->end) {
+		_tmp2 = self->priv->current[0] == '\n';
 	} else {
 		_tmp2 = FALSE;
 	}
@@ -1846,7 +1846,7 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 		} else {
 			_tmp2 = FALSE;
 		}
-		_tmp0 = (_tmp2);
+		_tmp0 = _tmp2;
 	}
 	if (_tmp0) {
 		return FALSE;
@@ -1855,7 +1855,7 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 		gchar* begin;
 		char* _tmp5;
 		/* single-line comment*/
-		self->priv->current = self->priv->current + (2);
+		self->priv->current = self->priv->current + 2;
 		begin = self->priv->current;
 		while (TRUE) {
 			gboolean _tmp4;
@@ -1871,7 +1871,7 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 			self->priv->current++;
 		}
 		_tmp5 = NULL;
-		vala_genie_scanner_push_comment (self, _tmp5 = g_strndup (((const char*) begin), (gsize) ((glong) (self->priv->current - begin))), self->priv->line == 1);
+		vala_genie_scanner_push_comment (self, _tmp5 = g_strndup ((const char*) begin, (gsize) ((glong) (self->priv->current - begin))), self->priv->line == 1);
 		_tmp5 = (g_free (_tmp5), NULL);
 		if (self->priv->current[0] == '\n') {
 			self->priv->current++;
@@ -1884,7 +1884,7 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 		gint begin_line;
 		char* _tmp10;
 		/* delimited comment*/
-		self->priv->current = self->priv->current + (2);
+		self->priv->current = self->priv->current + 2;
 		begin = self->priv->current;
 		begin_line = self->priv->line;
 		while (TRUE) {
@@ -1898,7 +1898,7 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 				} else {
 					_tmp7 = self->priv->current[1] != '/';
 				}
-				_tmp6 = (_tmp7);
+				_tmp6 = _tmp7;
 			} else {
 				_tmp6 = FALSE;
 			}
@@ -1920,10 +1920,10 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 			return TRUE;
 		}
 		_tmp10 = NULL;
-		vala_genie_scanner_push_comment (self, _tmp10 = g_strndup (((const char*) begin), (gsize) ((glong) (self->priv->current - begin))), begin_line == 1);
+		vala_genie_scanner_push_comment (self, _tmp10 = g_strndup ((const char*) begin, (gsize) ((glong) (self->priv->current - begin))), begin_line == 1);
 		_tmp10 = (g_free (_tmp10), NULL);
-		self->priv->current = self->priv->current + (2);
-		self->priv->column = self->priv->column + (2);
+		self->priv->current = self->priv->current + 2;
+		self->priv->column = self->priv->column + 2;
 	}
 	return TRUE;
 }
