@@ -28,7 +28,7 @@
 #include <vala/valaintegertype.h>
 #include <vala/valasymbol.h>
 #include <vala/valascope.h>
-#include <vala/valatypesymbol.h>
+#include <vala/valastruct.h>
 
 
 
@@ -207,7 +207,7 @@ static gboolean vala_integer_literal_real_check (ValaCodeNode* base, ValaSemanti
 	ValaIntegerLiteral * self;
 	ValaIntegerType* _tmp4;
 	char* _tmp3;
-	ValaTypeSymbol* _tmp2;
+	ValaStruct* _tmp2;
 	char* _tmp1;
 	self = (ValaIntegerLiteral*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
@@ -219,7 +219,7 @@ static gboolean vala_integer_literal_real_check (ValaCodeNode* base, ValaSemanti
 	_tmp3 = NULL;
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp4 = vala_integer_type_new (_tmp2 = VALA_TYPESYMBOL (vala_scope_lookup (vala_symbol_get_scope (analyzer->root_symbol), _tmp1 = vala_integer_literal_get_type_name (self))), self->priv->_value, _tmp3 = vala_integer_literal_get_type_name (self))));
+	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp4 = vala_integer_type_new (_tmp2 = VALA_STRUCT (vala_scope_lookup (vala_symbol_get_scope (analyzer->root_symbol), _tmp1 = vala_integer_literal_get_type_name (self))), self->priv->_value, _tmp3 = vala_integer_literal_get_type_name (self))));
 	(_tmp4 == NULL) ? NULL : (_tmp4 = (vala_code_node_unref (_tmp4), NULL));
 	_tmp3 = (g_free (_tmp3), NULL);
 	(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL));
