@@ -187,8 +187,8 @@ static gboolean vala_local_variable_real_check (ValaCodeNode* base, ValaSemantic
 			gboolean _tmp5;
 			gboolean _tmp7;
 			_tmp5 = FALSE;
-			if (!(VALA_IS_MEMBER_ACCESS (vala_local_variable_get_initializer (self)))) {
-				_tmp5 = !(VALA_IS_LAMBDA_EXPRESSION (vala_local_variable_get_initializer (self)));
+			if (!VALA_IS_MEMBER_ACCESS (vala_local_variable_get_initializer (self))) {
+				_tmp5 = !VALA_IS_LAMBDA_EXPRESSION (vala_local_variable_get_initializer (self));
 			} else {
 				_tmp5 = FALSE;
 			}
@@ -259,7 +259,7 @@ static gboolean vala_local_variable_real_check (ValaCodeNode* base, ValaSemantic
 		if (vala_data_type_is_disposable (vala_expression_get_value_type (vala_local_variable_get_initializer (self)))) {
 			gboolean _tmp20;
 			_tmp20 = FALSE;
-			if (!(VALA_IS_POINTER_TYPE (vala_local_variable_get_variable_type (self)))) {
+			if (!VALA_IS_POINTER_TYPE (vala_local_variable_get_variable_type (self))) {
 				_tmp20 = !vala_data_type_get_value_owned (vala_local_variable_get_variable_type (self));
 			} else {
 				_tmp20 = FALSE;
