@@ -845,7 +845,13 @@ static gboolean vala_member_access_real_check (ValaCodeNode* base, ValaSemanticA
 				_tmp81 = NULL;
 				_tmp80 = NULL;
 				m = (_tmp81 = (_tmp80 = vala_method_get_base_method (m), (_tmp80 == NULL) ? NULL : vala_code_node_ref (_tmp80)), (m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL)), _tmp81);
-				vala_expression_set_symbol_reference ((ValaExpression*) self, (ValaSymbol*) m);
+				if (vala_method_get_signal_reference (m) != NULL) {
+					/* method is class/default handler for a signal
+					 let signal deal with member access*/
+					vala_expression_set_symbol_reference ((ValaExpression*) self, (ValaSymbol*) vala_method_get_signal_reference (m));
+				} else {
+					vala_expression_set_symbol_reference ((ValaExpression*) self, (ValaSymbol*) m);
+				}
 				_tmp83 = NULL;
 				_tmp82 = NULL;
 				member = (_tmp83 = (_tmp82 = vala_expression_get_symbol_reference ((ValaExpression*) self), (_tmp82 == NULL) ? NULL : vala_code_node_ref (_tmp82)), (member == NULL) ? NULL : (member = (vala_code_node_unref (member), NULL)), _tmp83);
