@@ -24,6 +24,8 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaexpression.h>
+#include <vala/valasemanticanalyzer.h>
+#include <vala/valanulltype.h>
 
 
 
@@ -34,6 +36,7 @@ enum  {
 static void vala_null_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_null_literal_real_to_string (ValaCodeNode* base);
 static gboolean vala_null_literal_real_is_pure (ValaExpression* base);
+static gboolean vala_null_literal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 static gpointer vala_null_literal_parent_class = NULL;
 
 
@@ -46,8 +49,8 @@ static gpointer vala_null_literal_parent_class = NULL;
  */
 ValaNullLiteral* vala_null_literal_construct (GType object_type, ValaSourceReference* source) {
 	ValaNullLiteral* self;
-	self = ((ValaNullLiteral*) (g_type_create_instance (object_type)));
-	vala_code_node_set_source_reference (((ValaCodeNode*) (self)), source);
+	self = (ValaNullLiteral*) g_type_create_instance (object_type);
+	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
 }
 
@@ -59,32 +62,49 @@ ValaNullLiteral* vala_null_literal_new (ValaSourceReference* source) {
 
 static void vala_null_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaNullLiteral * self;
-	self = ((ValaNullLiteral*) (base));
+	self = (ValaNullLiteral*) base;
 	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_null_literal (visitor, self);
-	vala_code_visitor_visit_expression (visitor, ((ValaExpression*) (self)));
+	vala_code_visitor_visit_expression (visitor, (ValaExpression*) self);
 }
 
 
 static char* vala_null_literal_real_to_string (ValaCodeNode* base) {
 	ValaNullLiteral * self;
-	self = ((ValaNullLiteral*) (base));
+	self = (ValaNullLiteral*) base;
 	return g_strdup ("null");
 }
 
 
 static gboolean vala_null_literal_real_is_pure (ValaExpression* base) {
 	ValaNullLiteral * self;
-	self = ((ValaNullLiteral*) (base));
+	self = (ValaNullLiteral*) base;
 	return TRUE;
 }
 
 
+static gboolean vala_null_literal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
+	ValaNullLiteral * self;
+	ValaNullType* _tmp1;
+	self = (ValaNullLiteral*) base;
+	g_return_val_if_fail (analyzer != NULL, FALSE);
+	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
+		return !vala_code_node_get_error ((ValaCodeNode*) self);
+	}
+	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
+	_tmp1 = NULL;
+	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp1 = vala_null_type_new (vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+	(_tmp1 == NULL) ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL));
+	return !vala_code_node_get_error ((ValaCodeNode*) self);
+}
+
+
 static void vala_null_literal_class_init (ValaNullLiteralClass * klass) {
 	vala_null_literal_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_null_literal_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_null_literal_real_to_string;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_null_literal_real_is_pure;
+	VALA_CODE_NODE_CLASS (klass)->check = vala_null_literal_real_check;
 }
 
 
