@@ -1,6 +1,6 @@
 /* valaproperty.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -300,7 +300,7 @@ gboolean vala_property_equals (ValaProperty* self, ValaProperty* prop2) {
 	} else {
 		_tmp2 = FALSE;
 	}
-	if ((_tmp2)) {
+	if (_tmp2) {
 		_tmp1 = TRUE;
 	} else {
 		gboolean _tmp3;
@@ -310,7 +310,7 @@ gboolean vala_property_equals (ValaProperty* self, ValaProperty* prop2) {
 		} else {
 			_tmp3 = FALSE;
 		}
-		_tmp1 = (_tmp3);
+		_tmp1 = _tmp3;
 	}
 	if (_tmp1) {
 		return FALSE;
@@ -322,7 +322,7 @@ gboolean vala_property_equals (ValaProperty* self, ValaProperty* prop2) {
 	} else {
 		_tmp6 = FALSE;
 	}
-	if ((_tmp6)) {
+	if (_tmp6) {
 		_tmp5 = TRUE;
 	} else {
 		gboolean _tmp7;
@@ -332,7 +332,7 @@ gboolean vala_property_equals (ValaProperty* self, ValaProperty* prop2) {
 		} else {
 			_tmp7 = FALSE;
 		}
-		_tmp5 = (_tmp7);
+		_tmp5 = _tmp7;
 	}
 	if (_tmp5) {
 		return FALSE;
@@ -366,20 +366,19 @@ static void vala_property_find_base_properties (ValaProperty* self) {
 		return;
 	}
 	if (VALA_IS_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) {
-		/* VAPI classes don't specify overridden properties */
-		if (!vala_symbol_get_external_package (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) {
-			gboolean _tmp0;
-			vala_property_find_base_interface_property (self, VALA_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self)));
-			_tmp0 = FALSE;
-			if (self->priv->_is_virtual) {
-				_tmp0 = TRUE;
-			} else {
-				_tmp0 = self->priv->_overrides;
-			}
-			if (_tmp0) {
-				vala_property_find_base_class_property (self, VALA_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self)));
-			}
+		gboolean _tmp0;
+		vala_property_find_base_interface_property (self, VALA_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self)));
+		_tmp0 = FALSE;
+		if (self->priv->_is_virtual) {
+			_tmp0 = TRUE;
 		} else {
+			_tmp0 = self->priv->_overrides;
+		}
+		if (_tmp0) {
+			vala_property_find_base_class_property (self, VALA_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self)));
+		}
+	} else {
+		if (VALA_IS_INTERFACE (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) {
 			gboolean _tmp1;
 			_tmp1 = FALSE;
 			if (self->priv->_is_virtual) {
@@ -388,24 +387,11 @@ static void vala_property_find_base_properties (ValaProperty* self) {
 				_tmp1 = self->priv->_is_abstract;
 			}
 			if (_tmp1) {
-				self->priv->_base_property = self;
-			}
-		}
-	} else {
-		if (VALA_IS_INTERFACE (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) {
-			gboolean _tmp2;
-			_tmp2 = FALSE;
-			if (self->priv->_is_virtual) {
-				_tmp2 = TRUE;
-			} else {
-				_tmp2 = self->priv->_is_abstract;
-			}
-			if (_tmp2) {
-				ValaProperty* _tmp4;
 				ValaProperty* _tmp3;
-				_tmp4 = NULL;
+				ValaProperty* _tmp2;
 				_tmp3 = NULL;
-				self->priv->_base_interface_property = (_tmp4 = (_tmp3 = self, (_tmp3 == NULL) ? NULL : vala_code_node_ref (_tmp3)), (self->priv->_base_interface_property == NULL) ? NULL : (self->priv->_base_interface_property = (vala_code_node_unref (self->priv->_base_interface_property), NULL)), _tmp4);
+				_tmp2 = NULL;
+				self->priv->_base_interface_property = (_tmp3 = (_tmp2 = self, (_tmp2 == NULL) ? NULL : vala_code_node_ref (_tmp2)), (self->priv->_base_interface_property == NULL) ? NULL : (self->priv->_base_interface_property = (vala_code_node_unref (self->priv->_base_interface_property), NULL)), _tmp3);
 			}
 		}
 	}
@@ -535,8 +521,11 @@ static gboolean vala_property_real_check (ValaCodeNode* base, ValaSemanticAnalyz
 	ValaSymbol* old_symbol;
 	gboolean _tmp7;
 	gboolean _tmp10;
-	gboolean _tmp13;
-	gboolean _tmp17;
+	gboolean _tmp11;
+	gboolean _tmp12;
+	gboolean _tmp18;
+	gboolean _tmp21;
+	gboolean _tmp25;
 	self = (ValaProperty*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -607,46 +596,82 @@ static gboolean vala_property_real_check (ValaCodeNode* base, ValaSemanticAnalyz
 		_tmp8 = (g_free (_tmp8), NULL);
 	}
 	_tmp10 = FALSE;
-	if (vala_property_get_set_accessor (self) != NULL) {
-		_tmp10 = vala_property_accessor_get_construction (vala_property_get_set_accessor (self));
+	_tmp11 = FALSE;
+	_tmp12 = FALSE;
+	if (!vala_symbol_get_external_package ((ValaSymbol*) self)) {
+		_tmp12 = !self->priv->_overrides;
+	} else {
+		_tmp12 = FALSE;
+	}
+	if (_tmp12) {
+		_tmp11 = !vala_member_get_hides ((ValaMember*) self);
+	} else {
+		_tmp11 = FALSE;
+	}
+	if (_tmp11) {
+		ValaSymbol* _tmp13;
+		_tmp13 = NULL;
+		_tmp10 = (_tmp13 = vala_member_get_hidden_member ((ValaMember*) self)) != NULL;
+		(_tmp13 == NULL) ? NULL : (_tmp13 = (vala_code_node_unref (_tmp13), NULL));
 	} else {
 		_tmp10 = FALSE;
 	}
-	/* construct properties must be public */
 	if (_tmp10) {
-		if (vala_symbol_get_access ((ValaSymbol*) self) != VALA_SYMBOL_ACCESSIBILITY_PUBLIC) {
-			char* _tmp12;
-			char* _tmp11;
-			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-			_tmp12 = NULL;
-			_tmp11 = NULL;
-			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp12 = g_strdup_printf ("%s: construct properties must be public", _tmp11 = vala_symbol_get_full_name ((ValaSymbol*) self)));
-			_tmp12 = (g_free (_tmp12), NULL);
-			_tmp11 = (g_free (_tmp11), NULL);
-		}
-	}
-	_tmp13 = FALSE;
-	if (self->priv->_default_expression != NULL) {
-		_tmp13 = !(vala_data_type_compatible (vala_expression_get_value_type (self->priv->_default_expression), vala_property_get_property_type (self)));
-	} else {
-		_tmp13 = FALSE;
-	}
-	if (_tmp13) {
+		char* _tmp17;
 		char* _tmp16;
-		char* _tmp15;
+		ValaSymbol* _tmp15;
 		char* _tmp14;
-		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		_tmp17 = NULL;
 		_tmp16 = NULL;
 		_tmp15 = NULL;
 		_tmp14 = NULL;
-		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self->priv->_default_expression), _tmp16 = g_strdup_printf ("Expected initializer of type `%s' but got `%s'", _tmp14 = vala_code_node_to_string ((ValaCodeNode*) vala_property_get_property_type (self)), _tmp15 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (self->priv->_default_expression))));
+		vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp17 = g_strdup_printf ("%s hides inherited property `%s'. Use the `new' keyword if hiding was intentional", _tmp14 = vala_symbol_get_full_name ((ValaSymbol*) self), _tmp16 = vala_symbol_get_full_name (_tmp15 = vala_member_get_hidden_member ((ValaMember*) self))));
+		_tmp17 = (g_free (_tmp17), NULL);
 		_tmp16 = (g_free (_tmp16), NULL);
-		_tmp15 = (g_free (_tmp15), NULL);
+		(_tmp15 == NULL) ? NULL : (_tmp15 = (vala_code_node_unref (_tmp15), NULL));
 		_tmp14 = (g_free (_tmp14), NULL);
 	}
+	_tmp18 = FALSE;
+	if (vala_property_get_set_accessor (self) != NULL) {
+		_tmp18 = vala_property_accessor_get_construction (vala_property_get_set_accessor (self));
+	} else {
+		_tmp18 = FALSE;
+	}
+	/* construct properties must be public */
+	if (_tmp18) {
+		if (vala_symbol_get_access ((ValaSymbol*) self) != VALA_SYMBOL_ACCESSIBILITY_PUBLIC) {
+			char* _tmp20;
+			char* _tmp19;
+			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			_tmp20 = NULL;
+			_tmp19 = NULL;
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp20 = g_strdup_printf ("%s: construct properties must be public", _tmp19 = vala_symbol_get_full_name ((ValaSymbol*) self)));
+			_tmp20 = (g_free (_tmp20), NULL);
+			_tmp19 = (g_free (_tmp19), NULL);
+		}
+	}
+	_tmp21 = FALSE;
+	if (self->priv->_default_expression != NULL) {
+		_tmp21 = !vala_data_type_compatible (vala_expression_get_value_type (self->priv->_default_expression), vala_property_get_property_type (self));
+	} else {
+		_tmp21 = FALSE;
+	}
+	if (_tmp21) {
+		char* _tmp24;
+		char* _tmp23;
+		char* _tmp22;
+		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		_tmp24 = NULL;
+		_tmp23 = NULL;
+		_tmp22 = NULL;
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self->priv->_default_expression), _tmp24 = g_strdup_printf ("Expected initializer of type `%s' but got `%s'", _tmp22 = vala_code_node_to_string ((ValaCodeNode*) vala_property_get_property_type (self)), _tmp23 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (self->priv->_default_expression))));
+		_tmp24 = (g_free (_tmp24), NULL);
+		_tmp23 = (g_free (_tmp23), NULL);
+		_tmp22 = (g_free (_tmp22), NULL);
+	}
 	vala_semantic_analyzer_set_current_source_file (analyzer, old_source_file);
 	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
-	return (_tmp17 = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp17);
+	return (_tmp25 = !vala_code_node_get_error ((ValaCodeNode*) self), (old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL)), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), _tmp25);
 }
 
 
