@@ -77,7 +77,6 @@
 #include <vala/valaobjectcreationexpression.h>
 #include <vala/valastringliteral.h>
 #include <vala/valamemberinitializer.h>
-#include <vala/valanamespace.h>
 
 
 
@@ -222,38 +221,35 @@ void vala_semantic_analyzer_analyze (ValaSemanticAnalyzer* self, ValaCodeContext
 	glib_ns = vala_scope_lookup (vala_symbol_get_scope (self->root_symbol), "GLib");
 	if (glib_ns != NULL) {
 		ValaClass* _tmp32;
-		ValaTypeSymbol* _tmp33;
-		ValaDataType* _tmp35;
-		ValaStruct* _tmp34;
-		ValaDataType* _tmp37;
-		ValaClass* _tmp36;
-		ValaDataType* _tmp39;
-		ValaClass* _tmp38;
-		ValaDataType* _tmp41;
-		ValaClass* _tmp40;
-		ValaClass* _tmp42;
+		ValaDataType* _tmp34;
+		ValaStruct* _tmp33;
+		ValaDataType* _tmp36;
+		ValaClass* _tmp35;
+		ValaDataType* _tmp38;
+		ValaClass* _tmp37;
+		ValaDataType* _tmp40;
+		ValaClass* _tmp39;
+		ValaClass* _tmp41;
 		_tmp32 = NULL;
 		self->object_type = (_tmp32 = VALA_CLASS (vala_scope_lookup (vala_symbol_get_scope (glib_ns), "Object")), (self->object_type == NULL) ? NULL : (self->object_type = (vala_code_node_unref (self->object_type), NULL)), _tmp32);
-		_tmp33 = NULL;
-		self->initially_unowned_type = (_tmp33 = VALA_TYPESYMBOL (vala_scope_lookup (vala_symbol_get_scope (glib_ns), "InitiallyUnowned")), (self->initially_unowned_type == NULL) ? NULL : (self->initially_unowned_type = (vala_code_node_unref (self->initially_unowned_type), NULL)), _tmp33);
-		_tmp35 = NULL;
 		_tmp34 = NULL;
-		self->type_type = (_tmp35 = (ValaDataType*) vala_integer_type_new (_tmp34 = VALA_STRUCT (vala_scope_lookup (vala_symbol_get_scope (glib_ns), "Type")), NULL, NULL), (self->type_type == NULL) ? NULL : (self->type_type = (vala_code_node_unref (self->type_type), NULL)), _tmp35);
-		(_tmp34 == NULL) ? NULL : (_tmp34 = (vala_code_node_unref (_tmp34), NULL));
-		_tmp37 = NULL;
+		_tmp33 = NULL;
+		self->type_type = (_tmp34 = (ValaDataType*) vala_integer_type_new (_tmp33 = VALA_STRUCT (vala_scope_lookup (vala_symbol_get_scope (glib_ns), "Type")), NULL, NULL), (self->type_type == NULL) ? NULL : (self->type_type = (vala_code_node_unref (self->type_type), NULL)), _tmp34);
+		(_tmp33 == NULL) ? NULL : (_tmp33 = (vala_code_node_unref (_tmp33), NULL));
 		_tmp36 = NULL;
-		self->glist_type = (_tmp37 = (ValaDataType*) vala_object_type_new ((ValaObjectTypeSymbol*) (_tmp36 = VALA_CLASS (vala_scope_lookup (vala_symbol_get_scope (glib_ns), "List")))), (self->glist_type == NULL) ? NULL : (self->glist_type = (vala_code_node_unref (self->glist_type), NULL)), _tmp37);
-		(_tmp36 == NULL) ? NULL : (_tmp36 = (vala_code_node_unref (_tmp36), NULL));
-		_tmp39 = NULL;
+		_tmp35 = NULL;
+		self->glist_type = (_tmp36 = (ValaDataType*) vala_object_type_new ((ValaObjectTypeSymbol*) (_tmp35 = VALA_CLASS (vala_scope_lookup (vala_symbol_get_scope (glib_ns), "List")))), (self->glist_type == NULL) ? NULL : (self->glist_type = (vala_code_node_unref (self->glist_type), NULL)), _tmp36);
+		(_tmp35 == NULL) ? NULL : (_tmp35 = (vala_code_node_unref (_tmp35), NULL));
 		_tmp38 = NULL;
-		self->gslist_type = (_tmp39 = (ValaDataType*) vala_object_type_new ((ValaObjectTypeSymbol*) (_tmp38 = VALA_CLASS (vala_scope_lookup (vala_symbol_get_scope (glib_ns), "SList")))), (self->gslist_type == NULL) ? NULL : (self->gslist_type = (vala_code_node_unref (self->gslist_type), NULL)), _tmp39);
-		(_tmp38 == NULL) ? NULL : (_tmp38 = (vala_code_node_unref (_tmp38), NULL));
-		_tmp41 = NULL;
+		_tmp37 = NULL;
+		self->gslist_type = (_tmp38 = (ValaDataType*) vala_object_type_new ((ValaObjectTypeSymbol*) (_tmp37 = VALA_CLASS (vala_scope_lookup (vala_symbol_get_scope (glib_ns), "SList")))), (self->gslist_type == NULL) ? NULL : (self->gslist_type = (vala_code_node_unref (self->gslist_type), NULL)), _tmp38);
+		(_tmp37 == NULL) ? NULL : (_tmp37 = (vala_code_node_unref (_tmp37), NULL));
 		_tmp40 = NULL;
-		self->garray_type = (_tmp41 = (ValaDataType*) vala_object_type_new ((ValaObjectTypeSymbol*) (_tmp40 = VALA_CLASS (vala_scope_lookup (vala_symbol_get_scope (glib_ns), "Array")))), (self->garray_type == NULL) ? NULL : (self->garray_type = (vala_code_node_unref (self->garray_type), NULL)), _tmp41);
-		(_tmp40 == NULL) ? NULL : (_tmp40 = (vala_code_node_unref (_tmp40), NULL));
-		_tmp42 = NULL;
-		self->gerror_type = (_tmp42 = VALA_CLASS (vala_scope_lookup (vala_symbol_get_scope (glib_ns), "Error")), (self->gerror_type == NULL) ? NULL : (self->gerror_type = (vala_code_node_unref (self->gerror_type), NULL)), _tmp42);
+		_tmp39 = NULL;
+		self->garray_type = (_tmp40 = (ValaDataType*) vala_object_type_new ((ValaObjectTypeSymbol*) (_tmp39 = VALA_CLASS (vala_scope_lookup (vala_symbol_get_scope (glib_ns), "Array")))), (self->garray_type == NULL) ? NULL : (self->garray_type = (vala_code_node_unref (self->garray_type), NULL)), _tmp40);
+		(_tmp39 == NULL) ? NULL : (_tmp39 = (vala_code_node_unref (_tmp39), NULL));
+		_tmp41 = NULL;
+		self->gerror_type = (_tmp41 = VALA_CLASS (vala_scope_lookup (vala_symbol_get_scope (glib_ns), "Error")), (self->gerror_type == NULL) ? NULL : (self->gerror_type = (vala_code_node_unref (self->gerror_type), NULL)), _tmp41);
 	}
 	vala_semantic_analyzer_set_current_symbol (self, self->root_symbol);
 	vala_code_node_check ((ValaCodeNode*) vala_code_context_get_root (context), self);
@@ -300,7 +296,7 @@ gboolean vala_semantic_analyzer_is_type_accessible (ValaSemanticAnalyzer* self,
 			} else {
 				_tmp3 = FALSE;
 			}
-			if ((_tmp3)) {
+			if (_tmp3) {
 				_tmp2 = TRUE;
 			} else {
 				gboolean _tmp4;
@@ -310,7 +306,7 @@ gboolean vala_semantic_analyzer_is_type_accessible (ValaSemanticAnalyzer* self,
 				} else {
 					_tmp4 = FALSE;
 				}
-				_tmp2 = (_tmp4);
+				_tmp2 = _tmp4;
 			}
 			if (_tmp2) {
 				gboolean _tmp5;
@@ -675,12 +671,12 @@ gboolean vala_semantic_analyzer_check_arguments (ValaSemanticAnalyzer* self, Val
 	if (VALA_IS_METHOD_TYPE (mtype)) {
 		ValaAttribute* _tmp1;
 		_tmp1 = NULL;
-		_tmp0 = (_tmp1 = vala_code_node_get_attribute ((ValaCodeNode*) vala_method_type_get_method_symbol ((VALA_METHOD_TYPE (mtype))), "Diagnostics")) != NULL;
+		_tmp0 = (_tmp1 = vala_code_node_get_attribute ((ValaCodeNode*) vala_method_type_get_method_symbol (VALA_METHOD_TYPE (mtype)), "Diagnostics")) != NULL;
 		(_tmp1 == NULL) ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL));
 	} else {
 		_tmp0 = FALSE;
 	}
-	diag = (_tmp0);
+	diag = _tmp0;
 	ellipsis = FALSE;
 	i = 0;
 	{
@@ -804,7 +800,7 @@ gboolean vala_semantic_analyzer_check_arguments (ValaSemanticAnalyzer* self, Val
 			} else {
 				if (vala_expression_get_value_type (arg) == NULL) {
 					/* disallow untyped arguments except for type inference of callbacks*/
-					if (!(VALA_IS_METHOD (vala_expression_get_symbol_reference (arg)))) {
+					if (!VALA_IS_METHOD (vala_expression_get_symbol_reference (arg))) {
 						char* _tmp18;
 						gboolean _tmp19;
 						vala_code_node_set_error ((ValaCodeNode*) expr, TRUE);
@@ -908,10 +904,10 @@ static gboolean vala_semantic_analyzer_check_argument (ValaSemanticAnalyzer* sel
 		if (vala_expression_get_value_type (arg) == NULL) {
 			gboolean _tmp1;
 			_tmp1 = FALSE;
-			if (!(VALA_IS_DELEGATE_TYPE (vala_expression_get_target_type (arg)))) {
+			if (!VALA_IS_DELEGATE_TYPE (vala_expression_get_target_type (arg))) {
 				_tmp1 = TRUE;
 			} else {
-				_tmp1 = !(VALA_IS_METHOD (vala_expression_get_symbol_reference (arg)));
+				_tmp1 = !VALA_IS_METHOD (vala_expression_get_symbol_reference (arg));
 			}
 			/* disallow untyped arguments except for type inference of callbacks*/
 			if (_tmp1) {
@@ -939,7 +935,7 @@ static gboolean vala_semantic_analyzer_check_argument (ValaSemanticAnalyzer* sel
 				} else {
 					_tmp6 = FALSE;
 				}
-				_tmp4 = !(_tmp6);
+				_tmp4 = !_tmp6;
 			} else {
 				_tmp4 = FALSE;
 			}
@@ -1021,7 +1017,7 @@ static gboolean vala_semantic_analyzer_check_argument (ValaSemanticAnalyzer* sel
 							if (vala_data_type_is_disposable (vala_expression_get_target_type (arg))) {
 								gboolean _tmp20;
 								_tmp20 = FALSE;
-								if (!(VALA_IS_POINTER_TYPE (vala_expression_get_value_type (arg)))) {
+								if (!VALA_IS_POINTER_TYPE (vala_expression_get_value_type (arg))) {
 									_tmp20 = !vala_data_type_get_value_owned (vala_expression_get_value_type (arg));
 								} else {
 									_tmp20 = FALSE;
@@ -1045,7 +1041,7 @@ static gboolean vala_semantic_analyzer_check_argument (ValaSemanticAnalyzer* sel
 								if (vala_data_type_is_disposable (vala_expression_get_target_type (arg))) {
 									gboolean _tmp24;
 									_tmp24 = FALSE;
-									if (!(VALA_IS_POINTER_TYPE (vala_expression_get_value_type (arg)))) {
+									if (!VALA_IS_POINTER_TYPE (vala_expression_get_value_type (arg))) {
 										_tmp24 = !vala_data_type_get_value_owned (vala_expression_get_value_type (arg));
 									} else {
 										_tmp24 = FALSE;
@@ -1464,7 +1460,7 @@ void vala_semantic_analyzer_visit_member_initializer (ValaSemanticAnalyzer* self
 	} else {
 		_tmp1 = VALA_IS_PROPERTY (vala_member_initializer_get_symbol_reference (init));
 	}
-	if (!(_tmp1)) {
+	if (!_tmp1) {
 		char* _tmp3;
 		char* _tmp2;
 		vala_code_node_set_error ((ValaCodeNode*) init, TRUE);
@@ -1565,10 +1561,10 @@ ValaDataType* vala_semantic_analyzer_get_arithmetic_result_type (ValaSemanticAna
 	g_return_val_if_fail (left_type != NULL, NULL);
 	g_return_val_if_fail (right_type != NULL, NULL);
 	_tmp0 = FALSE;
-	if (!(VALA_IS_STRUCT (vala_data_type_get_data_type (left_type)))) {
+	if (!VALA_IS_STRUCT (vala_data_type_get_data_type (left_type))) {
 		_tmp0 = TRUE;
 	} else {
-		_tmp0 = !(VALA_IS_STRUCT (vala_data_type_get_data_type (right_type)));
+		_tmp0 = !VALA_IS_STRUCT (vala_data_type_get_data_type (right_type));
 	}
 	if (_tmp0) {
 		/* at least one operand not struct*/
@@ -1585,7 +1581,7 @@ ValaDataType* vala_semantic_analyzer_get_arithmetic_result_type (ValaSemanticAna
 	} else {
 		_tmp5 = FALSE;
 	}
-	if ((_tmp5)) {
+	if (_tmp5) {
 		_tmp4 = TRUE;
 	} else {
 		gboolean _tmp6;
@@ -1595,7 +1591,7 @@ ValaDataType* vala_semantic_analyzer_get_arithmetic_result_type (ValaSemanticAna
 		} else {
 			_tmp6 = FALSE;
 		}
-		_tmp4 = (_tmp6);
+		_tmp4 = _tmp6;
 	}
 	if (_tmp4) {
 		ValaDataType* _tmp7;
@@ -1778,7 +1774,6 @@ static void vala_semantic_analyzer_finalize (ValaCodeVisitor* obj) {
 	(self->double_type == NULL) ? NULL : (self->double_type = (vala_code_node_unref (self->double_type), NULL));
 	(self->type_type == NULL) ? NULL : (self->type_type = (vala_code_node_unref (self->type_type), NULL));
 	(self->object_type == NULL) ? NULL : (self->object_type = (vala_code_node_unref (self->object_type), NULL));
-	(self->initially_unowned_type == NULL) ? NULL : (self->initially_unowned_type = (vala_code_node_unref (self->initially_unowned_type), NULL));
 	(self->glist_type == NULL) ? NULL : (self->glist_type = (vala_code_node_unref (self->glist_type), NULL));
 	(self->gslist_type == NULL) ? NULL : (self->gslist_type = (vala_code_node_unref (self->gslist_type), NULL));
 	(self->garray_type == NULL) ? NULL : (self->garray_type = (vala_code_node_unref (self->garray_type), NULL));
