@@ -52,8 +52,8 @@
 
 
 
-static char* string_substring (const char* self, glong offset, glong len);
 static glong string_get_length (const char* self);
+static char* string_substring (const char* self, glong offset, glong len);
 struct _ValaSourceFilePrivate {
 	char* _filename;
 	char* _comment;
@@ -97,6 +97,12 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
+static glong string_get_length (const char* self) {
+	g_return_val_if_fail (self != NULL, 0L);
+	return g_utf8_strlen (self, -1);
+}
+
+
 static char* string_substring (const char* self, glong offset, glong len) {
 	glong string_length;
 	const char* start;
@@ -117,12 +123,6 @@ static char* string_substring (const char* self, glong offset, glong len) {
 }
 
 
-static glong string_get_length (const char* self) {
-	g_return_val_if_fail (self != NULL, 0L);
-	return g_utf8_strlen (self, -1);
-}
-
-
 /**
  * Creates a new source file.
  *
@@ -210,7 +210,7 @@ static gboolean vala_source_file_same_symbol (ValaSourceFile* self, ValaSymbol*
 	if (_tmp5) {
 		if (vala_source_file_same_symbol (self, (ValaSymbol*) vala_unresolved_symbol_get_inner (unresolved_symbol1), (ValaSymbol*) vala_unresolved_symbol_get_inner (unresolved_symbol2))) {
 			gboolean _tmp6;
-			return (_tmp6 = (_vala_strcmp0 (vala_symbol_get_name ((ValaSymbol*) unresolved_symbol1), vala_symbol_get_name ((ValaSymbol*) unresolved_symbol2)) == 0), (unresolved_symbol1 == NULL) ? NULL : (unresolved_symbol1 = (vala_code_node_unref (unresolved_symbol1), NULL)), (unresolved_symbol2 == NULL) ? NULL : (unresolved_symbol2 = (vala_code_node_unref (unresolved_symbol2), NULL)), _tmp6);
+			return (_tmp6 = _vala_strcmp0 (vala_symbol_get_name ((ValaSymbol*) unresolved_symbol1), vala_symbol_get_name ((ValaSymbol*) unresolved_symbol2)) == 0, (unresolved_symbol1 == NULL) ? NULL : (unresolved_symbol1 = (vala_code_node_unref (unresolved_symbol1), NULL)), (unresolved_symbol2 == NULL) ? NULL : (unresolved_symbol2 = (vala_code_node_unref (unresolved_symbol2), NULL)), _tmp6);
 		}
 	}
 	return (_tmp7 = FALSE, (unresolved_symbol1 == NULL) ? NULL : (unresolved_symbol1 = (vala_code_node_unref (unresolved_symbol1), NULL)), (unresolved_symbol2 == NULL) ? NULL : (unresolved_symbol2 = (vala_code_node_unref (unresolved_symbol2), NULL)), _tmp7);
@@ -824,7 +824,7 @@ static void vala_source_file_read_source_lines (ValaSourceFile* self, const char
 	_tmp1 = NULL;
 	lines = (_tmp2 = _tmp1 = g_strsplit (cont, "\n", 0), lines_length1 = _vala_array_length (_tmp1), lines_size = lines_length1, _tmp2);
 	idx = 0;
-	for (idx = 0; lines[idx] != NULL; (idx = idx + 1)) {
+	for (idx = 0; lines[idx] != NULL; idx = idx + 1) {
 		gee_collection_add ((GeeCollection*) self->priv->source_array, lines[idx]);
 	}
 	lines = (_vala_array_free (lines, lines_length1, (GDestroyNotify) g_free), NULL);
