@@ -1,6 +1,6 @@
 /* valasourcefilecycle.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -39,22 +39,37 @@ G_BEGIN_DECLS
 #define VALA_SOURCE_FILE_CYCLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SOURCE_FILE_CYCLE, ValaSourceFileCycleClass))
 
 typedef struct _ValaSourceFileCyclePrivate ValaSourceFileCyclePrivate;
+typedef struct _ValaParamSpecSourceFileCycle ValaParamSpecSourceFileCycle;
 
 /**
  * Represents a dependency cycle of source files.
  */
 struct _ValaSourceFileCycle {
-	GObject parent_instance;
+	GTypeInstance parent_instance;
+	volatile int ref_count;
 	ValaSourceFileCyclePrivate * priv;
 	GeeList* files;
 	ValaSourceFile* head;
 };
+
 struct _ValaSourceFileCycleClass {
-	GObjectClass parent_class;
+	GTypeClass parent_class;
+	void (*finalize) (ValaSourceFileCycle *self);
 };
 
+struct _ValaParamSpecSourceFileCycle {
+	GParamSpec parent_instance;
+};
+
+
+ValaSourceFileCycle* vala_source_file_cycle_construct (GType object_type);
 ValaSourceFileCycle* vala_source_file_cycle_new (void);
+GParamSpec* vala_param_spec_source_file_cycle (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+gpointer vala_value_get_source_file_cycle (const GValue* value);
+void vala_value_set_source_file_cycle (GValue* value, gpointer v_object);
 GType vala_source_file_cycle_get_type (void);
+gpointer vala_source_file_cycle_ref (gpointer instance);
+void vala_source_file_cycle_unref (gpointer instance);
 
 
 G_END_DECLS
