@@ -40,21 +40,30 @@ G_BEGIN_DECLS
 #define VALA_SOURCE_REFERENCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))
 
 typedef struct _ValaSourceReferencePrivate ValaSourceReferencePrivate;
+typedef struct _ValaParamSpecSourceReference ValaParamSpecSourceReference;
 
 /**
  * Represents a reference to a location in a source file.
  */
 struct _ValaSourceReference {
-	GObject parent_instance;
+	GTypeInstance parent_instance;
+	volatile int ref_count;
 	ValaSourceReferencePrivate * priv;
 };
 
 struct _ValaSourceReferenceClass {
-	GObjectClass parent_class;
+	GTypeClass parent_class;
+	void (*finalize) (ValaSourceReference *self);
+};
+
+struct _ValaParamSpecSourceReference {
+	GParamSpec parent_instance;
 };
 
 
+ValaSourceReference* vala_source_reference_construct (GType object_type, ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column);
 ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column);
+ValaSourceReference* vala_source_reference_construct_with_comment (GType object_type, ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column, const char* _comment);
 ValaSourceReference* vala_source_reference_new_with_comment (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column, const char* _comment);
 char* vala_source_reference_to_string (ValaSourceReference* self);
 ValaSourceFile* vala_source_reference_get_file (ValaSourceReference* self);
@@ -67,9 +76,14 @@ gint vala_source_reference_get_last_line (ValaSourceReference* self);
 void vala_source_reference_set_last_line (ValaSourceReference* self, gint value);
 gint vala_source_reference_get_last_column (ValaSourceReference* self);
 void vala_source_reference_set_last_column (ValaSourceReference* self, gint value);
-char* vala_source_reference_get_comment (ValaSourceReference* self);
+const char* vala_source_reference_get_comment (ValaSourceReference* self);
 void vala_source_reference_set_comment (ValaSourceReference* self, const char* value);
+GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+gpointer vala_value_get_source_reference (const GValue* value);
+void vala_value_set_source_reference (GValue* value, gpointer v_object);
 GType vala_source_reference_get_type (void);
+gpointer vala_source_reference_ref (gpointer instance);
+void vala_source_reference_unref (gpointer instance);
 
 
 G_END_DECLS
