@@ -24,10 +24,17 @@
 #include <gee/arraylist.h>
 #include <gee/collection.h>
 #include <gee/readonlylist.h>
+#include <gee/iterable.h>
+#include <gee/iterator.h>
+#include <stdlib.h>
+#include <string.h>
 #include <vala/valaexpression.h>
-#include <vala/valasourcereference.h>
 #include <vala/valaswitchsection.h>
+#include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valasemanticanalyzer.h>
+#include <vala/valadatatype.h>
+#include <vala/valareport.h>
 
 
 
@@ -42,7 +49,9 @@ enum  {
 	VALA_SWITCH_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_switch_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_switch_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_switch_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
+static gboolean vala_switch_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 static gpointer vala_switch_statement_parent_class = NULL;
 static ValaStatementIface* vala_switch_statement_vala_statement_parent_iface = NULL;
 static void vala_switch_statement_finalize (ValaCodeNode* obj);
@@ -60,8 +69,8 @@ ValaSwitchStatement* vala_switch_statement_construct (GType object_type, ValaExp
 	ValaSwitchStatement* self;
 	g_return_val_if_fail (expression != NULL, NULL);
 	g_return_val_if_fail (source_reference != NULL, NULL);
-	self = ((ValaSwitchStatement*) (g_type_create_instance (object_type)));
-	vala_code_node_set_source_reference (((ValaCodeNode*) (self)), source_reference);
+	self = (ValaSwitchStatement*) g_type_create_instance (object_type);
+	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	vala_switch_statement_set_expression (self, expression);
 	return self;
 }
@@ -80,8 +89,8 @@ ValaSwitchStatement* vala_switch_statement_new (ValaExpression* expression, Vala
 void vala_switch_statement_add_section (ValaSwitchStatement* self, ValaSwitchSection* section) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (section != NULL);
-	vala_code_node_set_parent_node (((ValaCodeNode*) (section)), ((ValaCodeNode*) (self)));
-	gee_collection_add (((GeeCollection*) (self->priv->sections)), section);
+	vala_code_node_set_parent_node ((ValaCodeNode*) section, (ValaCodeNode*) self);
+	gee_collection_add ((GeeCollection*) self->priv->sections, section);
 }
 
 
@@ -92,36 +101,41 @@ void vala_switch_statement_add_section (ValaSwitchStatement* self, ValaSwitchSec
  */
 GeeList* vala_switch_statement_get_sections (ValaSwitchStatement* self) {
 	g_return_val_if_fail (self != NULL, NULL);
-	return ((GeeList*) (gee_read_only_list_new (VALA_TYPE_SWITCH_SECTION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->sections)));
+	return (GeeList*) gee_read_only_list_new (VALA_TYPE_SWITCH_SECTION, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->sections);
 }
 
 
 static void vala_switch_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSwitchStatement * self;
-	self = ((ValaSwitchStatement*) (base));
+	self = (ValaSwitchStatement*) base;
 	g_return_if_fail (visitor != NULL);
-	vala_code_node_accept (((ValaCodeNode*) (vala_switch_statement_get_expression (self))), visitor);
+	vala_code_visitor_visit_switch_statement (visitor, self);
+}
+
+
+static void vala_switch_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
+	ValaSwitchStatement * self;
+	self = (ValaSwitchStatement*) base;
+	g_return_if_fail (visitor != NULL);
+	vala_code_node_accept ((ValaCodeNode*) vala_switch_statement_get_expression (self), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_switch_statement_get_expression (self));
 	{
-		GeeList* section_collection;
-		int section_it;
-		section_collection = self->priv->sections;
-		for (section_it = 0; section_it < gee_collection_get_size (GEE_COLLECTION (section_collection)); section_it = section_it + 1) {
+		GeeIterator* _section_it;
+		_section_it = gee_iterable_iterator ((GeeIterable*) self->priv->sections);
+		while (gee_iterator_next (_section_it)) {
 			ValaSwitchSection* section;
-			section = ((ValaSwitchSection*) (gee_list_get (GEE_LIST (section_collection), section_it)));
-			{
-				vala_code_node_accept (((ValaCodeNode*) (section)), visitor);
-				(section == NULL ? NULL : (section = (vala_code_node_unref (section), NULL)));
-			}
+			section = (ValaSwitchSection*) gee_iterator_get (_section_it);
+			vala_code_node_accept ((ValaCodeNode*) section, visitor);
+			(section == NULL) ? NULL : (section = (vala_code_node_unref (section), NULL));
 		}
+		(_section_it == NULL) ? NULL : (_section_it = (gee_collection_object_unref (_section_it), NULL));
 	}
-	vala_code_visitor_visit_switch_statement (visitor, self);
 }
 
 
 static void vala_switch_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaSwitchStatement * self;
-	self = ((ValaSwitchStatement*) (base));
+	self = (ValaSwitchStatement*) base;
 	g_return_if_fail (old_node != NULL);
 	g_return_if_fail (new_node != NULL);
 	if (vala_switch_statement_get_expression (self) == old_node) {
@@ -130,6 +144,45 @@ static void vala_switch_statement_real_replace_expression (ValaCodeNode* base, V
 }
 
 
+static gboolean vala_switch_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
+	ValaSwitchStatement * self;
+	gboolean _tmp2;
+	self = (ValaSwitchStatement*) base;
+	g_return_val_if_fail (analyzer != NULL, FALSE);
+	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
+		return !vala_code_node_get_error ((ValaCodeNode*) self);
+	}
+	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
+	if (!vala_code_node_check ((ValaCodeNode*) vala_switch_statement_get_expression (self), analyzer)) {
+		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		return FALSE;
+	}
+	_tmp2 = FALSE;
+	if (!vala_data_type_compatible (vala_expression_get_value_type (vala_switch_statement_get_expression (self)), analyzer->uint64_type)) {
+		_tmp2 = !vala_data_type_compatible (vala_expression_get_value_type (vala_switch_statement_get_expression (self)), analyzer->string_type);
+	} else {
+		_tmp2 = FALSE;
+	}
+	if (_tmp2) {
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_switch_statement_get_expression (self)), "Integer or string expression expected");
+		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+		return FALSE;
+	}
+	{
+		GeeIterator* _section_it;
+		_section_it = gee_iterable_iterator ((GeeIterable*) self->priv->sections);
+		while (gee_iterator_next (_section_it)) {
+			ValaSwitchSection* section;
+			section = (ValaSwitchSection*) gee_iterator_get (_section_it);
+			vala_code_node_check ((ValaCodeNode*) section, analyzer);
+			(section == NULL) ? NULL : (section = (vala_code_node_unref (section), NULL));
+		}
+		(_section_it == NULL) ? NULL : (_section_it = (gee_collection_object_unref (_section_it), NULL));
+	}
+	return !vala_code_node_get_error ((ValaCodeNode*) self);
+}
+
+
 ValaExpression* vala_switch_statement_get_expression (ValaSwitchStatement* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_expression;
@@ -142,8 +195,8 @@ void vala_switch_statement_set_expression (ValaSwitchStatement* self, ValaExpres
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL))), _tmp2);
-	vala_code_node_set_parent_node (((ValaCodeNode*) (self->priv->_expression)), ((ValaCodeNode*) (self)));
+	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)), _tmp2);
+	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_expression, (ValaCodeNode*) self);
 }
 
 
@@ -152,7 +205,9 @@ static void vala_switch_statement_class_init (ValaSwitchStatementClass * klass)
 	VALA_CODE_NODE_CLASS (klass)->finalize = vala_switch_statement_finalize;
 	g_type_class_add_private (klass, sizeof (ValaSwitchStatementPrivate));
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_switch_statement_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_switch_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_switch_statement_real_replace_expression;
+	VALA_CODE_NODE_CLASS (klass)->check = vala_switch_statement_real_check;
 }
 
 
@@ -163,15 +218,15 @@ static void vala_switch_statement_vala_statement_interface_init (ValaStatementIf
 
 static void vala_switch_statement_instance_init (ValaSwitchStatement * self) {
 	self->priv = VALA_SWITCH_STATEMENT_GET_PRIVATE (self);
-	self->priv->sections = ((GeeList*) (gee_array_list_new (VALA_TYPE_SWITCH_SECTION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal)));
+	self->priv->sections = (GeeList*) gee_array_list_new (VALA_TYPE_SWITCH_SECTION, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
 }
 
 
 static void vala_switch_statement_finalize (ValaCodeNode* obj) {
 	ValaSwitchStatement * self;
 	self = VALA_SWITCH_STATEMENT (obj);
-	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)));
-	(self->priv->sections == NULL ? NULL : (self->priv->sections = (gee_collection_object_unref (self->priv->sections), NULL)));
+	(self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL));
+	(self->priv->sections == NULL) ? NULL : (self->priv->sections = (gee_collection_object_unref (self->priv->sections), NULL));
 	VALA_CODE_NODE_CLASS (vala_switch_statement_parent_class)->finalize (obj);
 }
 
