@@ -69,6 +69,7 @@ typedef enum  {
 
 
 gboolean vala_symbol_is_internal_symbol (ValaSymbol* self);
+gboolean vala_symbol_is_library_internal_symbol (ValaSymbol* self);
 ValaSymbol* vala_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
 ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_reference);
 char* vala_symbol_get_full_name (ValaSymbol* self);
@@ -78,7 +79,7 @@ char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self);
 GeeList* vala_symbol_get_cheader_filenames (ValaSymbol* self);
 char* vala_symbol_camel_case_to_lower_case (const char* camel_case);
 char* vala_symbol_lower_case_to_camel_case (const char* lower_case);
-ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self);
+ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self, gboolean is_internal);
 ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self);
 ValaScope* vala_symbol_get_owner (ValaSymbol* self);
 void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value);
