@@ -106,7 +106,6 @@ static void vala_symbol_resolver_real_visit_throw_statement (ValaCodeVisitor* ba
 static void vala_symbol_resolver_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt);
 static void vala_symbol_resolver_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause);
 static void vala_symbol_resolver_real_visit_array_creation_expression (ValaCodeVisitor* base, ValaArrayCreationExpression* e);
-static void vala_symbol_resolver_real_visit_parenthesized_expression (ValaCodeVisitor* base, ValaParenthesizedExpression* expr);
 static void vala_symbol_resolver_real_visit_member_access (ValaCodeVisitor* base, ValaMemberAccess* expr);
 static void vala_symbol_resolver_real_visit_method_call (ValaCodeVisitor* base, ValaMethodCall* expr);
 static void vala_symbol_resolver_real_visit_element_access (ValaCodeVisitor* base, ValaElementAccess* expr);
@@ -237,8 +236,8 @@ static void vala_symbol_resolver_real_visit_struct (ValaCodeVisitor* base, ValaS
 	ValaSymbolResolver * self;
 	ValaScope* _tmp1;
 	ValaScope* _tmp0;
-	ValaScope* _tmp8;
 	ValaScope* _tmp7;
+	ValaScope* _tmp6;
 	self = (ValaSymbolResolver*) base;
 	g_return_if_fail (st != NULL);
 	_tmp1 = NULL;
@@ -246,34 +245,32 @@ static void vala_symbol_resolver_real_visit_struct (ValaCodeVisitor* base, ValaS
 	self->priv->current_scope = (_tmp1 = (_tmp0 = vala_symbol_get_scope ((ValaSymbol*) st), (_tmp0 == NULL) ? NULL : vala_scope_ref (_tmp0)), (self->priv->current_scope == NULL) ? NULL : (self->priv->current_scope = (vala_scope_unref (self->priv->current_scope), NULL)), _tmp1);
 	vala_code_node_accept_children ((ValaCodeNode*) st, (ValaCodeVisitor*) self);
 	if (vala_struct_get_base_type (st) != NULL) {
-		ValaStruct* _tmp3;
-		ValaTypeSymbol* _tmp2;
+		ValaStruct* _tmp2;
 		ValaStruct* base_type;
-		_tmp3 = NULL;
 		_tmp2 = NULL;
-		base_type = (_tmp3 = (_tmp2 = vala_data_type_get_data_type (vala_struct_get_base_type (st)), VALA_IS_STRUCT (_tmp2) ? ((ValaStruct*) _tmp2) : NULL), (_tmp3 == NULL) ? NULL : vala_code_node_ref (_tmp3));
+		base_type = (_tmp2 = vala_struct_get_base_struct (st), (_tmp2 == NULL) ? NULL : vala_code_node_ref (_tmp2));
 		if (base_type != NULL) {
 			if (vala_typesymbol_is_subtype_of ((ValaTypeSymbol*) base_type, (ValaTypeSymbol*) st)) {
-				char* _tmp6;
 				char* _tmp5;
 				char* _tmp4;
+				char* _tmp3;
 				vala_code_node_set_error ((ValaCodeNode*) st, TRUE);
-				_tmp6 = NULL;
 				_tmp5 = NULL;
 				_tmp4 = NULL;
-				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) base_type), _tmp6 = g_strdup_printf ("Base struct cycle (`%s' and `%s')", _tmp4 = vala_symbol_get_full_name ((ValaSymbol*) st), _tmp5 = vala_symbol_get_full_name ((ValaSymbol*) base_type)));
-				_tmp6 = (g_free (_tmp6), NULL);
+				_tmp3 = NULL;
+				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) base_type), _tmp5 = g_strdup_printf ("Base struct cycle (`%s' and `%s')", _tmp3 = vala_symbol_get_full_name ((ValaSymbol*) st), _tmp4 = vala_symbol_get_full_name ((ValaSymbol*) base_type)));
 				_tmp5 = (g_free (_tmp5), NULL);
 				_tmp4 = (g_free (_tmp4), NULL);
+				_tmp3 = (g_free (_tmp3), NULL);
 				(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
 				return;
 			}
 		}
 		(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
 	}
-	_tmp8 = NULL;
 	_tmp7 = NULL;
-	self->priv->current_scope = (_tmp8 = (_tmp7 = vala_scope_get_parent_scope (self->priv->current_scope), (_tmp7 == NULL) ? NULL : vala_scope_ref (_tmp7)), (self->priv->current_scope == NULL) ? NULL : (self->priv->current_scope = (vala_scope_unref (self->priv->current_scope), NULL)), _tmp8);
+	_tmp6 = NULL;
+	self->priv->current_scope = (_tmp7 = (_tmp6 = vala_scope_get_parent_scope (self->priv->current_scope), (_tmp6 == NULL) ? NULL : vala_scope_ref (_tmp6)), (self->priv->current_scope == NULL) ? NULL : (self->priv->current_scope = (vala_scope_unref (self->priv->current_scope), NULL)), _tmp7);
 }
 
 
@@ -577,7 +574,7 @@ static ValaSymbol* vala_symbol_resolver_resolve_symbol (ValaSymbolResolver* self
 					_tmp4 = VALA_IS_TYPEPARAMETER (sym);
 				}
 				/* only look for types and type containers*/
-				if (!(_tmp4)) {
+				if (!_tmp4) {
 					ValaSymbol* _tmp6;
 					_tmp6 = NULL;
 					sym = (_tmp6 = NULL, (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp6);
@@ -621,7 +618,7 @@ static ValaSymbol* vala_symbol_resolver_resolve_symbol (ValaSymbolResolver* self
 							_tmp10 = VALA_IS_TYPEPARAMETER (sym);
 						}
 						/* only look for types and type containers*/
-						if (!(_tmp10)) {
+						if (!_tmp10) {
 							ValaSymbol* _tmp12;
 							_tmp12 = NULL;
 							local_sym = (_tmp12 = NULL, (local_sym == NULL) ? NULL : (local_sym = (vala_code_node_unref (local_sym), NULL)), _tmp12);
@@ -850,7 +847,7 @@ static void vala_symbol_resolver_real_visit_data_type (ValaCodeVisitor* base, Va
 	self = (ValaSymbolResolver*) base;
 	g_return_if_fail (data_type != NULL);
 	vala_code_node_accept_children ((ValaCodeNode*) data_type, (ValaCodeVisitor*) self);
-	if (!(VALA_IS_UNRESOLVED_TYPE (data_type))) {
+	if (!VALA_IS_UNRESOLVED_TYPE (data_type)) {
 		return;
 	}
 	_tmp0 = NULL;
@@ -1009,14 +1006,6 @@ static void vala_symbol_resolver_real_visit_array_creation_expression (ValaCodeV
 }
 
 
-static void vala_symbol_resolver_real_visit_parenthesized_expression (ValaCodeVisitor* base, ValaParenthesizedExpression* expr) {
-	ValaSymbolResolver * self;
-	self = (ValaSymbolResolver*) base;
-	g_return_if_fail (expr != NULL);
-	vala_code_node_accept_children ((ValaCodeNode*) expr, (ValaCodeVisitor*) self);
-}
-
-
 static void vala_symbol_resolver_real_visit_member_access (ValaCodeVisitor* base, ValaMemberAccess* expr) {
 	ValaSymbolResolver * self;
 	self = (ValaSymbolResolver*) base;
@@ -1146,7 +1135,6 @@ static void vala_symbol_resolver_class_init (ValaSymbolResolverClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_try_statement = vala_symbol_resolver_real_visit_try_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_catch_clause = vala_symbol_resolver_real_visit_catch_clause;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_array_creation_expression = vala_symbol_resolver_real_visit_array_creation_expression;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_parenthesized_expression = vala_symbol_resolver_real_visit_parenthesized_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_member_access = vala_symbol_resolver_real_visit_member_access;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_method_call = vala_symbol_resolver_real_visit_method_call;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_element_access = vala_symbol_resolver_real_visit_element_access;
