@@ -1,6 +1,6 @@
 /* valathrowstatement.vala
  *
- * Copyright (C) 2007-2008  Jürg Billeter
+ * Copyright (C) 2007-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -112,7 +112,7 @@ static gboolean vala_throw_statement_real_check (ValaCodeNode* base, ValaSemanti
 	ValaThrowStatement * self;
 	ValaErrorType* _tmp1;
 	ValaDataType* error_type;
-	gboolean _tmp5;
+	gboolean _tmp7;
 	self = (ValaThrowStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -124,15 +124,23 @@ static gboolean vala_throw_statement_real_check (ValaCodeNode* base, ValaSemanti
 	(_tmp1 == NULL) ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL));
 	vala_data_type_set_value_owned (vala_expression_get_target_type (vala_throw_statement_get_error_expression (self)), TRUE);
 	if (vala_throw_statement_get_error_expression (self) != NULL) {
-		vala_code_node_check ((ValaCodeNode*) vala_throw_statement_get_error_expression (self), analyzer);
-		if (!(VALA_IS_ERROR_TYPE (vala_expression_get_value_type (vala_throw_statement_get_error_expression (self))))) {
-			char* _tmp3;
-			char* _tmp2;
-			_tmp3 = NULL;
-			_tmp2 = NULL;
-			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_throw_statement_get_error_expression (self)), _tmp3 = g_strdup_printf ("`%s' is not an error type", _tmp2 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_throw_statement_get_error_expression (self)))));
-			_tmp3 = (g_free (_tmp3), NULL);
-			_tmp2 = (g_free (_tmp2), NULL);
+		if (!vala_code_node_check ((ValaCodeNode*) vala_throw_statement_get_error_expression (self), analyzer)) {
+			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			return FALSE;
+		}
+		if (vala_expression_get_value_type (vala_throw_statement_get_error_expression (self)) == NULL) {
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_throw_statement_get_error_expression (self)), "invalid error expression");
+			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			return FALSE;
+		}
+		if (!VALA_IS_ERROR_TYPE (vala_expression_get_value_type (vala_throw_statement_get_error_expression (self)))) {
+			char* _tmp5;
+			char* _tmp4;
+			_tmp5 = NULL;
+			_tmp4 = NULL;
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_throw_statement_get_error_expression (self)), _tmp5 = g_strdup_printf ("`%s' is not an error type", _tmp4 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_throw_statement_get_error_expression (self)))));
+			_tmp5 = (g_free (_tmp5), NULL);
+			_tmp4 = (g_free (_tmp4), NULL);
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 			return FALSE;
 		}
@@ -140,7 +148,7 @@ static gboolean vala_throw_statement_real_check (ValaCodeNode* base, ValaSemanti
 	error_type = vala_data_type_copy (vala_expression_get_value_type (vala_throw_statement_get_error_expression (self)));
 	vala_code_node_set_source_reference ((ValaCodeNode*) error_type, vala_code_node_get_source_reference ((ValaCodeNode*) self));
 	vala_code_node_add_error_type ((ValaCodeNode*) self, error_type);
-	return (_tmp5 = !vala_code_node_get_error ((ValaCodeNode*) self), (error_type == NULL) ? NULL : (error_type = (vala_code_node_unref (error_type), NULL)), _tmp5);
+	return (_tmp7 = !vala_code_node_get_error ((ValaCodeNode*) self), (error_type == NULL) ? NULL : (error_type = (vala_code_node_unref (error_type), NULL)), _tmp7);
 }
 
 
