@@ -29,7 +29,6 @@
 #include <vala/valareport.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodenode.h>
-#include <gee/map.h>
 #include <vala/valastruct.h>
 #include <vala/valadatatype.h>
 #include <vala/valavoidtype.h>
@@ -61,14 +60,16 @@
 #include <vala/valainterface.h>
 #include <vala/valaconstant.h>
 #include <glib/gstdio.h>
+#include <gee/map.h>
 #include "vapigen/valamarkupreader.h"
 
 
 
 
-static glong string_get_length (const char* self);
 static char* string_substring (const char* self, glong offset, glong len);
+static glong string_get_length (const char* self);
 struct _ValaGirParserPrivate {
+	char* _package_name;
 	ValaMarkupReader* reader;
 	ValaCodeContext* context;
 	ValaNamespace* glib_ns;
@@ -76,6 +77,9 @@ struct _ValaGirParserPrivate {
 	ValaSourceLocation begin;
 	ValaSourceLocation end;
 	ValaMarkupTokenType current_token;
+	char** cheader_filenames;
+	gint cheader_filenames_length1;
+	gint cheader_filenames_size;
 	GeeHashMap* attributes_map;
 };
 
@@ -90,6 +94,9 @@ static void vala_gir_parser_end_element (ValaGirParser* self, const char* name);
 static ValaSourceReference* vala_gir_parser_get_current_src (ValaGirParser* self);
 static void vala_gir_parser_parse_repository (ValaGirParser* self);
 static void vala_gir_parser_parse_include (ValaGirParser* self);
+static void vala_gir_parser_parse_package (ValaGirParser* self);
+static void _vala_array_add1 (char*** array, int* length, int* size, char* value);
+static void vala_gir_parser_parse_c_include (ValaGirParser* self);
 static void _g_list_free_vala_code_node_unref (GList* self);
 static ValaNamespace* vala_gir_parser_parse_namespace (ValaGirParser* self);
 static ValaStruct* vala_gir_parser_parse_alias (ValaGirParser* self);
@@ -114,6 +121,7 @@ static ValaStruct* vala_gir_parser_parse_boxed (ValaGirParser* self);
 static ValaStruct* vala_gir_parser_parse_union (ValaGirParser* self);
 static ValaConstant* vala_gir_parser_parse_constant (ValaGirParser* self);
 static char* vala_gir_parser_get_attribute (ValaGirParser* self, const char* node, const char* key);
+static void vala_gir_parser_set_package_name (ValaGirParser* self, const char* value);
 static gpointer vala_gir_parser_parent_class = NULL;
 static void vala_gir_parser_finalize (ValaCodeVisitor* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
@@ -122,12 +130,6 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-static glong string_get_length (const char* self) {
-	g_return_val_if_fail (self != NULL, 0L);
-	return g_utf8_strlen (self, -1);
-}
-
-
 static char* string_substring (const char* self, glong offset, glong len) {
 	glong string_length;
 	const char* start;
@@ -148,6 +150,12 @@ static char* string_substring (const char* self, glong offset, glong len) {
 }
 
 
+static glong string_get_length (const char* self) {
+	g_return_val_if_fail (self != NULL, 0L);
+	return g_utf8_strlen (self, -1);
+}
+
+
 /**
  * Parses all .gir source files in the specified code
  * context and builds a code tree.
@@ -366,15 +374,23 @@ static void vala_gir_parser_parse_repository (ValaGirParser* self) {
 			if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "include") == 0) {
 				vala_gir_parser_parse_include (self);
 			} else {
-				char* _tmp1;
-				ValaSourceReference* _tmp0;
-				/* error*/
-				_tmp1 = NULL;
-				_tmp0 = NULL;
-				vala_report_error (_tmp0 = vala_gir_parser_get_current_src (self), _tmp1 = g_strdup_printf ("unknown child element `%s' in `repository'", vala_markup_reader_get_name (self->priv->reader)));
-				_tmp1 = (g_free (_tmp1), NULL);
-				(_tmp0 == NULL) ? NULL : (_tmp0 = (vala_source_reference_unref (_tmp0), NULL));
-				break;
+				if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "package") == 0) {
+					vala_gir_parser_parse_package (self);
+				} else {
+					if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "c:include") == 0) {
+						vala_gir_parser_parse_c_include (self);
+					} else {
+						char* _tmp1;
+						ValaSourceReference* _tmp0;
+						/* error*/
+						_tmp1 = NULL;
+						_tmp0 = NULL;
+						vala_report_error (_tmp0 = vala_gir_parser_get_current_src (self), _tmp1 = g_strdup_printf ("unknown child element `%s' in `repository'", vala_markup_reader_get_name (self->priv->reader)));
+						_tmp1 = (g_free (_tmp1), NULL);
+						(_tmp0 == NULL) ? NULL : (_tmp0 = (vala_source_reference_unref (_tmp0), NULL));
+						break;
+					}
+				}
 			}
 		}
 	}
@@ -390,6 +406,37 @@ static void vala_gir_parser_parse_include (ValaGirParser* self) {
 }
 
 
+static void vala_gir_parser_parse_package (ValaGirParser* self) {
+	char* _tmp0;
+	g_return_if_fail (self != NULL);
+	vala_gir_parser_start_element (self, "package");
+	_tmp0 = NULL;
+	vala_gir_parser_set_package_name (self, _tmp0 = vala_markup_reader_get_attribute (self->priv->reader, "name"));
+	_tmp0 = (g_free (_tmp0), NULL);
+	vala_gir_parser_next (self);
+	vala_gir_parser_end_element (self, "package");
+}
+
+
+static void _vala_array_add1 (char*** array, int* length, int* size, char* value) {
+	if ((*length) == (*size)) {
+		*size = (*size) ? (2 * (*size)) : 4;
+		*array = g_renew (char*, *array, (*size) + 1);
+	}
+	(*array)[(*length)++] = value;
+	(*array)[*length] = NULL;
+}
+
+
+static void vala_gir_parser_parse_c_include (ValaGirParser* self) {
+	g_return_if_fail (self != NULL);
+	vala_gir_parser_start_element (self, "c:include");
+	_vala_array_add1 (&self->priv->cheader_filenames, &self->priv->cheader_filenames_length1, &self->priv->cheader_filenames_size, vala_markup_reader_get_attribute (self->priv->reader, "name"));
+	vala_gir_parser_next (self);
+	vala_gir_parser_end_element (self, "c:include");
+}
+
+
 static void _g_list_free_vala_code_node_unref (GList* self) {
 	g_list_foreach (self, (GFunc) vala_code_node_unref, NULL);
 	g_list_free (self);
@@ -403,8 +450,7 @@ static ValaNamespace* vala_gir_parser_parse_namespace (ValaGirParser* self) {
 	char* namespace_name;
 	ValaSymbol* _tmp2;
 	ValaNamespace* ns;
-	char* cheader;
-	ValaNamespace* _tmp20;
+	ValaNamespace* _tmp21;
 	g_return_val_if_fail (self != NULL, NULL);
 	vala_gir_parser_start_element (self, "namespace");
 	new_namespace = FALSE;
@@ -429,79 +475,90 @@ static ValaNamespace* vala_gir_parser_parse_namespace (ValaGirParser* self) {
 			(_tmp5 == NULL) ? NULL : (_tmp5 = (vala_source_reference_unref (_tmp5), NULL));
 		}
 	}
-	cheader = vala_gir_parser_get_attribute (self, vala_symbol_get_name ((ValaSymbol*) ns), "c:header-filename");
-	if (cheader != NULL) {
-		vala_namespace_set_cheader_filename (ns, cheader);
+	{
+		char** c_header_collection;
+		int c_header_collection_length1;
+		int c_header_it;
+		c_header_collection = self->priv->cheader_filenames;
+		c_header_collection_length1 = self->priv->cheader_filenames_length1;
+		for (c_header_it = 0; c_header_it < self->priv->cheader_filenames_length1; c_header_it = c_header_it + 1) {
+			const char* _tmp6;
+			char* c_header;
+			_tmp6 = NULL;
+			c_header = (_tmp6 = c_header_collection[c_header_it], (_tmp6 == NULL) ? NULL : g_strdup (_tmp6));
+			{
+				vala_namespace_add_cheader_filename (ns, c_header);
+				c_header = (g_free (c_header), NULL);
+			}
+		}
 	}
 	vala_gir_parser_next (self);
 	while (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
 		ValaSymbol* sym;
 		sym = NULL;
 		if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "alias") == 0) {
-			ValaSymbol* _tmp6;
-			_tmp6 = NULL;
-			sym = (_tmp6 = (ValaSymbol*) vala_gir_parser_parse_alias (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp6);
+			ValaSymbol* _tmp7;
+			_tmp7 = NULL;
+			sym = (_tmp7 = (ValaSymbol*) vala_gir_parser_parse_alias (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp7);
 		} else {
 			if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "enumeration") == 0) {
-				ValaSymbol* _tmp7;
-				_tmp7 = NULL;
-				sym = (_tmp7 = (ValaSymbol*) vala_gir_parser_parse_enumeration (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp7);
+				ValaSymbol* _tmp8;
+				_tmp8 = NULL;
+				sym = (_tmp8 = (ValaSymbol*) vala_gir_parser_parse_enumeration (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp8);
 			} else {
 				if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "bitfield") == 0) {
-					ValaSymbol* _tmp8;
-					_tmp8 = NULL;
-					sym = (_tmp8 = (ValaSymbol*) vala_gir_parser_parse_bitfield (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp8);
+					ValaSymbol* _tmp9;
+					_tmp9 = NULL;
+					sym = (_tmp9 = (ValaSymbol*) vala_gir_parser_parse_bitfield (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp9);
 				} else {
 					if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "function") == 0) {
-						ValaSymbol* _tmp9;
-						_tmp9 = NULL;
-						sym = (_tmp9 = (ValaSymbol*) vala_gir_parser_parse_method (self, "function"), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp9);
+						ValaSymbol* _tmp10;
+						_tmp10 = NULL;
+						sym = (_tmp10 = (ValaSymbol*) vala_gir_parser_parse_method (self, "function"), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp10);
 					} else {
 						if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "callback") == 0) {
-							ValaSymbol* _tmp10;
-							_tmp10 = NULL;
-							sym = (_tmp10 = (ValaSymbol*) vala_gir_parser_parse_callback (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp10);
+							ValaSymbol* _tmp11;
+							_tmp11 = NULL;
+							sym = (_tmp11 = (ValaSymbol*) vala_gir_parser_parse_callback (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp11);
 						} else {
 							if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "record") == 0) {
-								ValaSymbol* _tmp11;
-								_tmp11 = NULL;
-								sym = (_tmp11 = (ValaSymbol*) vala_gir_parser_parse_record (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp11);
+								ValaSymbol* _tmp12;
+								_tmp12 = NULL;
+								sym = (_tmp12 = (ValaSymbol*) vala_gir_parser_parse_record (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp12);
 							} else {
 								if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "class") == 0) {
-									ValaSymbol* _tmp12;
-									_tmp12 = NULL;
-									sym = (_tmp12 = (ValaSymbol*) vala_gir_parser_parse_class (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp12);
+									ValaSymbol* _tmp13;
+									_tmp13 = NULL;
+									sym = (_tmp13 = (ValaSymbol*) vala_gir_parser_parse_class (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp13);
 								} else {
 									if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "interface") == 0) {
-										ValaSymbol* _tmp13;
-										_tmp13 = NULL;
-										sym = (_tmp13 = (ValaSymbol*) vala_gir_parser_parse_interface (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp13);
+										ValaSymbol* _tmp14;
+										_tmp14 = NULL;
+										sym = (_tmp14 = (ValaSymbol*) vala_gir_parser_parse_interface (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp14);
 									} else {
 										if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "glib:boxed") == 0) {
-											ValaStruct* _tmp14;
-											_tmp14 = NULL;
-											_tmp14 = vala_gir_parser_parse_boxed (self);
-											(_tmp14 == NULL) ? NULL : (_tmp14 = (vala_code_node_unref (_tmp14), NULL));
+											ValaSymbol* _tmp15;
+											_tmp15 = NULL;
+											sym = (_tmp15 = (ValaSymbol*) vala_gir_parser_parse_boxed (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp15);
 										} else {
 											if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "union") == 0) {
-												ValaStruct* _tmp15;
-												_tmp15 = NULL;
-												_tmp15 = vala_gir_parser_parse_union (self);
-												(_tmp15 == NULL) ? NULL : (_tmp15 = (vala_code_node_unref (_tmp15), NULL));
+												ValaSymbol* _tmp16;
+												_tmp16 = NULL;
+												sym = (_tmp16 = (ValaSymbol*) vala_gir_parser_parse_union (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp16);
 											} else {
 												if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "constant") == 0) {
-													ValaSymbol* _tmp16;
-													_tmp16 = NULL;
-													sym = (_tmp16 = (ValaSymbol*) vala_gir_parser_parse_constant (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp16);
-												} else {
-													char* _tmp18;
-													ValaSourceReference* _tmp17;
-													/* error*/
-													_tmp18 = NULL;
+													ValaSymbol* _tmp17;
 													_tmp17 = NULL;
-													vala_report_error (_tmp17 = vala_gir_parser_get_current_src (self), _tmp18 = g_strdup_printf ("unknown child element `%s' in `namespace'", vala_markup_reader_get_name (self->priv->reader)));
-													_tmp18 = (g_free (_tmp18), NULL);
-													(_tmp17 == NULL) ? NULL : (_tmp17 = (vala_source_reference_unref (_tmp17), NULL));
+													sym = (_tmp17 = (ValaSymbol*) vala_gir_parser_parse_constant (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp17);
+												} else {
+													char* _tmp19;
+													ValaSourceReference* _tmp18;
+													/* error*/
+													_tmp19 = NULL;
+													_tmp18 = NULL;
+													vala_report_error (_tmp18 = vala_gir_parser_get_current_src (self), _tmp19 = g_strdup_printf ("unknown child element `%s' in `namespace'", vala_markup_reader_get_name (self->priv->reader)));
+													_tmp19 = (g_free (_tmp19), NULL);
+													(_tmp18 == NULL) ? NULL : (_tmp18 = (vala_source_reference_unref (_tmp18), NULL));
 													(sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL));
 													break;
 												}
@@ -552,12 +609,12 @@ static ValaNamespace* vala_gir_parser_parse_namespace (ValaGirParser* self) {
 	}
 	vala_gir_parser_end_element (self, "namespace");
 	if (!new_namespace) {
-		ValaNamespace* _tmp19;
-		_tmp19 = NULL;
-		ns = (_tmp19 = NULL, (ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL)), _tmp19);
+		ValaNamespace* _tmp20;
+		_tmp20 = NULL;
+		ns = (_tmp20 = NULL, (ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL)), _tmp20);
 	}
-	_tmp20 = NULL;
-	return (_tmp20 = ns, namespace_name = (g_free (namespace_name), NULL), cheader = (g_free (cheader), NULL), _tmp20);
+	_tmp21 = NULL;
+	return (_tmp21 = ns, namespace_name = (g_free (namespace_name), NULL), _tmp21);
 }
 
 
@@ -591,6 +648,7 @@ static ValaEnum* vala_gir_parser_parse_enumeration (ValaGirParser* self) {
 	char* _tmp0;
 	ValaEnum* _tmp2;
 	ValaEnum* en;
+	char* enum_cname;
 	char* common_prefix;
 	ValaEnum* _tmp12;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -600,6 +658,10 @@ static ValaEnum* vala_gir_parser_parse_enumeration (ValaGirParser* self) {
 	_tmp2 = NULL;
 	en = (_tmp2 = vala_enum_new (_tmp0 = vala_markup_reader_get_attribute (self->priv->reader, "name"), _tmp1 = vala_gir_parser_get_current_src (self)), (_tmp1 == NULL) ? NULL : (_tmp1 = (vala_source_reference_unref (_tmp1), NULL)), _tmp0 = (g_free (_tmp0), NULL), _tmp2);
 	vala_symbol_set_access ((ValaSymbol*) en, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+	enum_cname = vala_markup_reader_get_attribute (self->priv->reader, "c:type");
+	if (enum_cname != NULL) {
+		vala_enum_set_cname (en, enum_cname);
+	}
 	vala_gir_parser_next (self);
 	common_prefix = NULL;
 	while (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
@@ -650,14 +712,14 @@ static ValaEnum* vala_gir_parser_parse_enumeration (ValaGirParser* self) {
 					} else {
 						gboolean _tmp10;
 						_tmp10 = FALSE;
-						if ((g_unichar_isdigit (g_utf8_get_char (g_utf8_offset_to_pointer (cname, strlen (common_prefix)))))) {
+						if (g_unichar_isdigit (g_utf8_get_char (g_utf8_offset_to_pointer (cname, strlen (common_prefix))))) {
 							_tmp10 = (g_utf8_strlen (cname, -1) - g_utf8_strlen (common_prefix, -1)) <= 1;
 						} else {
 							_tmp10 = FALSE;
 						}
 						_tmp9 = _tmp10;
 					}
-					_tmp8 = (_tmp9);
+					_tmp8 = _tmp9;
 				} else {
 					_tmp8 = FALSE;
 				}
@@ -678,7 +740,7 @@ static ValaEnum* vala_gir_parser_parse_enumeration (ValaGirParser* self) {
 	vala_enum_set_cprefix (en, common_prefix);
 	vala_gir_parser_end_element (self, "enumeration");
 	_tmp12 = NULL;
-	return (_tmp12 = en, common_prefix = (g_free (common_prefix), NULL), _tmp12);
+	return (_tmp12 = en, enum_cname = (g_free (enum_cname), NULL), common_prefix = (g_free (common_prefix), NULL), _tmp12);
 }
 
 
@@ -1047,7 +1109,7 @@ static ValaStruct* vala_gir_parser_parse_record (ValaGirParser* self) {
 					if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "method") == 0) {
 						ValaMethod* _tmp6;
 						_tmp6 = NULL;
-						_tmp6 = vala_gir_parser_parse_method (self, "method");
+						vala_struct_add_method (st, _tmp6 = vala_gir_parser_parse_method (self, "method"));
 						(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL));
 					} else {
 						char* _tmp8;
@@ -1074,6 +1136,7 @@ static ValaClass* vala_gir_parser_parse_class (ValaGirParser* self) {
 	char* _tmp0;
 	ValaClass* _tmp2;
 	ValaClass* cl;
+	char* cname;
 	char* parent;
 	GeeArrayList* signals;
 	GeeArrayList* methods;
@@ -1087,6 +1150,10 @@ static ValaClass* vala_gir_parser_parse_class (ValaGirParser* self) {
 	_tmp2 = NULL;
 	cl = (_tmp2 = vala_class_new (_tmp0 = vala_markup_reader_get_attribute (self->priv->reader, "name"), _tmp1 = vala_gir_parser_get_current_src (self)), (_tmp1 == NULL) ? NULL : (_tmp1 = (vala_source_reference_unref (_tmp1), NULL)), _tmp0 = (g_free (_tmp0), NULL), _tmp2);
 	vala_symbol_set_access ((ValaSymbol*) cl, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+	cname = vala_markup_reader_get_attribute (self->priv->reader, "c:type");
+	if (cname != NULL) {
+		vala_class_set_cname (cl, cname);
+	}
 	parent = vala_markup_reader_get_attribute (self->priv->reader, "parent");
 	if (parent != NULL) {
 		ValaDataType* _tmp3;
@@ -1325,7 +1392,7 @@ static ValaClass* vala_gir_parser_parse_class (ValaGirParser* self) {
 	}
 	vala_gir_parser_end_element (self, "class");
 	_tmp25 = NULL;
-	return (_tmp25 = cl, parent = (g_free (parent), NULL), (signals == NULL) ? NULL : (signals = (gee_collection_object_unref (signals), NULL)), (methods == NULL) ? NULL : (methods = (gee_collection_object_unref (methods), NULL)), (vmethods == NULL) ? NULL : (vmethods = (gee_collection_object_unref (vmethods), NULL)), (fields == NULL) ? NULL : (fields = (gee_collection_object_unref (fields), NULL)), _tmp25);
+	return (_tmp25 = cl, cname = (g_free (cname), NULL), parent = (g_free (parent), NULL), (signals == NULL) ? NULL : (signals = (gee_collection_object_unref (signals), NULL)), (methods == NULL) ? NULL : (methods = (gee_collection_object_unref (methods), NULL)), (vmethods == NULL) ? NULL : (vmethods = (gee_collection_object_unref (vmethods), NULL)), (fields == NULL) ? NULL : (fields = (gee_collection_object_unref (fields), NULL)), _tmp25);
 }
 
 
@@ -1334,9 +1401,10 @@ static ValaInterface* vala_gir_parser_parse_interface (ValaGirParser* self) {
 	char* _tmp0;
 	ValaInterface* _tmp2;
 	ValaInterface* iface;
+	char* cname;
 	GeeArrayList* methods;
 	GeeArrayList* vmethods;
-	ValaInterface* _tmp18;
+	ValaInterface* _tmp19;
 	g_return_val_if_fail (self != NULL, NULL);
 	vala_gir_parser_start_element (self, "interface");
 	_tmp1 = NULL;
@@ -1344,6 +1412,10 @@ static ValaInterface* vala_gir_parser_parse_interface (ValaGirParser* self) {
 	_tmp2 = NULL;
 	iface = (_tmp2 = vala_interface_new (_tmp0 = vala_markup_reader_get_attribute (self->priv->reader, "name"), _tmp1 = vala_gir_parser_get_current_src (self)), (_tmp1 == NULL) ? NULL : (_tmp1 = (vala_source_reference_unref (_tmp1), NULL)), _tmp0 = (g_free (_tmp0), NULL), _tmp2);
 	vala_symbol_set_access ((ValaSymbol*) iface, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+	cname = vala_markup_reader_get_attribute (self->priv->reader, "c:type");
+	if (cname != NULL) {
+		vala_interface_set_cname (iface, cname);
+	}
 	vala_gir_parser_next (self);
 	methods = gee_array_list_new (VALA_TYPE_METHOD, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
 	vmethods = gee_array_list_new (VALA_TYPE_METHOD, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
@@ -1378,27 +1450,34 @@ static ValaInterface* vala_gir_parser_parse_interface (ValaGirParser* self) {
 						gee_collection_add ((GeeCollection*) vmethods, _tmp7 = vala_gir_parser_parse_method (self, "callback"));
 						(_tmp7 == NULL) ? NULL : (_tmp7 = (vala_code_node_unref (_tmp7), NULL));
 					} else {
-						if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "method") == 0) {
+						if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "function") == 0) {
 							ValaMethod* _tmp8;
 							_tmp8 = NULL;
-							gee_collection_add ((GeeCollection*) methods, _tmp8 = vala_gir_parser_parse_method (self, "method"));
+							gee_collection_add ((GeeCollection*) methods, _tmp8 = vala_gir_parser_parse_method (self, "function"));
 							(_tmp8 == NULL) ? NULL : (_tmp8 = (vala_code_node_unref (_tmp8), NULL));
 						} else {
-							if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "glib:signal") == 0) {
-								ValaSignal* _tmp9;
+							if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "method") == 0) {
+								ValaMethod* _tmp9;
 								_tmp9 = NULL;
-								vala_interface_add_signal (iface, _tmp9 = vala_gir_parser_parse_signal (self));
+								gee_collection_add ((GeeCollection*) methods, _tmp9 = vala_gir_parser_parse_method (self, "method"));
 								(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_code_node_unref (_tmp9), NULL));
 							} else {
-								char* _tmp11;
-								ValaSourceReference* _tmp10;
-								/* error*/
-								_tmp11 = NULL;
-								_tmp10 = NULL;
-								vala_report_error (_tmp10 = vala_gir_parser_get_current_src (self), _tmp11 = g_strdup_printf ("unknown child element `%s' in `interface'", vala_markup_reader_get_name (self->priv->reader)));
-								_tmp11 = (g_free (_tmp11), NULL);
-								(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_source_reference_unref (_tmp10), NULL));
-								break;
+								if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "glib:signal") == 0) {
+									ValaSignal* _tmp10;
+									_tmp10 = NULL;
+									vala_interface_add_signal (iface, _tmp10 = vala_gir_parser_parse_signal (self));
+									(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_code_node_unref (_tmp10), NULL));
+								} else {
+									char* _tmp12;
+									ValaSourceReference* _tmp11;
+									/* error*/
+									_tmp12 = NULL;
+									_tmp11 = NULL;
+									vala_report_error (_tmp11 = vala_gir_parser_get_current_src (self), _tmp12 = g_strdup_printf ("unknown child element `%s' in `interface'", vala_markup_reader_get_name (self->priv->reader)));
+									_tmp12 = (g_free (_tmp12), NULL);
+									(_tmp11 == NULL) ? NULL : (_tmp11 = (vala_source_reference_unref (_tmp11), NULL));
+									break;
+								}
 							}
 						}
 					}
@@ -1422,20 +1501,20 @@ static ValaInterface* vala_gir_parser_parse_interface (ValaGirParser* self) {
 				vala_interface_add_method (iface, m);
 			} else {
 				if (VALA_IS_SIGNAL (symbol)) {
-					ValaSignal* _tmp12;
+					ValaSignal* _tmp13;
 					ValaSignal* sig;
-					_tmp12 = NULL;
-					sig = (_tmp12 = VALA_SIGNAL (symbol), (_tmp12 == NULL) ? NULL : vala_code_node_ref (_tmp12));
+					_tmp13 = NULL;
+					sig = (_tmp13 = VALA_SIGNAL (symbol), (_tmp13 == NULL) ? NULL : vala_code_node_ref (_tmp13));
 					vala_signal_set_is_virtual (sig, TRUE);
 					(sig == NULL) ? NULL : (sig = (vala_code_node_unref (sig), NULL));
 				} else {
-					char* _tmp14;
-					ValaSourceReference* _tmp13;
+					char* _tmp15;
+					ValaSourceReference* _tmp14;
+					_tmp15 = NULL;
 					_tmp14 = NULL;
-					_tmp13 = NULL;
-					vala_report_error (_tmp13 = vala_gir_parser_get_current_src (self), _tmp14 = g_strdup_printf ("duplicate member `%s' in `%s'", vala_symbol_get_name ((ValaSymbol*) m), vala_symbol_get_name ((ValaSymbol*) iface)));
-					_tmp14 = (g_free (_tmp14), NULL);
-					(_tmp13 == NULL) ? NULL : (_tmp13 = (vala_source_reference_unref (_tmp13), NULL));
+					vala_report_error (_tmp14 = vala_gir_parser_get_current_src (self), _tmp15 = g_strdup_printf ("duplicate member `%s' in `%s'", vala_symbol_get_name ((ValaSymbol*) m), vala_symbol_get_name ((ValaSymbol*) iface)));
+					_tmp15 = (g_free (_tmp15), NULL);
+					(_tmp14 == NULL) ? NULL : (_tmp14 = (vala_source_reference_unref (_tmp14), NULL));
 				}
 			}
 			(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
@@ -1459,23 +1538,23 @@ static ValaInterface* vala_gir_parser_parse_interface (ValaGirParser* self) {
 				vala_interface_add_method (iface, m);
 			} else {
 				if (VALA_IS_SIGNAL (symbol)) {
-					ValaSignal* _tmp15;
+					ValaSignal* _tmp16;
 					ValaSignal* sig;
-					_tmp15 = NULL;
-					sig = (_tmp15 = VALA_SIGNAL (symbol), (_tmp15 == NULL) ? NULL : vala_code_node_ref (_tmp15));
+					_tmp16 = NULL;
+					sig = (_tmp16 = VALA_SIGNAL (symbol), (_tmp16 == NULL) ? NULL : vala_code_node_ref (_tmp16));
 					vala_signal_set_has_emitter (sig, TRUE);
 					(sig == NULL) ? NULL : (sig = (vala_code_node_unref (sig), NULL));
 				} else {
 					if (VALA_IS_METHOD (symbol)) {
 					} else {
-						char* _tmp17;
-						ValaSourceReference* _tmp16;
+						char* _tmp18;
+						ValaSourceReference* _tmp17;
 						/* assume method is wrapper for virtual method*/
+						_tmp18 = NULL;
 						_tmp17 = NULL;
-						_tmp16 = NULL;
-						vala_report_error (_tmp16 = vala_gir_parser_get_current_src (self), _tmp17 = g_strdup_printf ("duplicate member `%s' in `%s'", vala_symbol_get_name ((ValaSymbol*) m), vala_symbol_get_name ((ValaSymbol*) iface)));
-						_tmp17 = (g_free (_tmp17), NULL);
-						(_tmp16 == NULL) ? NULL : (_tmp16 = (vala_source_reference_unref (_tmp16), NULL));
+						vala_report_error (_tmp17 = vala_gir_parser_get_current_src (self), _tmp18 = g_strdup_printf ("duplicate member `%s' in `%s'", vala_symbol_get_name ((ValaSymbol*) m), vala_symbol_get_name ((ValaSymbol*) iface)));
+						_tmp18 = (g_free (_tmp18), NULL);
+						(_tmp17 == NULL) ? NULL : (_tmp17 = (vala_source_reference_unref (_tmp17), NULL));
 					}
 				}
 			}
@@ -1485,8 +1564,8 @@ static ValaInterface* vala_gir_parser_parse_interface (ValaGirParser* self) {
 		(_m_it == NULL) ? NULL : (_m_it = (gee_collection_object_unref (_m_it), NULL));
 	}
 	vala_gir_parser_end_element (self, "interface");
-	_tmp18 = NULL;
-	return (_tmp18 = iface, (methods == NULL) ? NULL : (methods = (gee_collection_object_unref (methods), NULL)), (vmethods == NULL) ? NULL : (vmethods = (gee_collection_object_unref (vmethods), NULL)), _tmp18);
+	_tmp19 = NULL;
+	return (_tmp19 = iface, cname = (g_free (cname), NULL), (methods == NULL) ? NULL : (methods = (gee_collection_object_unref (methods), NULL)), (vmethods == NULL) ? NULL : (vmethods = (gee_collection_object_unref (vmethods), NULL)), _tmp19);
 }
 
 
@@ -1564,7 +1643,7 @@ static ValaProperty* vala_gir_parser_parse_property (ValaGirParser* self) {
 		ValaDataType* _tmp9;
 		_tmp10 = NULL;
 		_tmp9 = NULL;
-		vala_property_set_set_accessor (prop, _tmp10 = vala_property_accessor_new (FALSE, (_vala_strcmp0 (writable, "1") == 0), (_vala_strcmp0 (construct_, "1") == 0), _tmp9 = vala_data_type_copy (vala_property_get_property_type (prop)), NULL, NULL));
+		vala_property_set_set_accessor (prop, _tmp10 = vala_property_accessor_new (FALSE, _vala_strcmp0 (writable, "1") == 0, _vala_strcmp0 (construct_, "1") == 0, _tmp9 = vala_data_type_copy (vala_property_get_property_type (prop)), NULL, NULL));
 		(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_code_node_unref (_tmp10), NULL));
 		(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_code_node_unref (_tmp9), NULL));
 	}
@@ -1884,12 +1963,18 @@ static ValaStruct* vala_gir_parser_parse_boxed (ValaGirParser* self) {
 	char* _tmp0;
 	ValaStruct* _tmp1;
 	ValaStruct* st;
+	char* cname;
+	ValaStruct* _tmp7;
 	g_return_val_if_fail (self != NULL, NULL);
 	vala_gir_parser_start_element (self, "glib:boxed");
 	_tmp0 = NULL;
 	_tmp1 = NULL;
 	st = (_tmp1 = vala_struct_new (_tmp0 = vala_markup_reader_get_attribute (self->priv->reader, "glib:name"), NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 	vala_symbol_set_access ((ValaSymbol*) st, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+	cname = vala_markup_reader_get_attribute (self->priv->reader, "c:type");
+	if (cname != NULL) {
+		vala_struct_set_cname (st, cname);
+	}
 	vala_gir_parser_next (self);
 	while (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
 		if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "field") == 0) {
@@ -1924,7 +2009,8 @@ static ValaStruct* vala_gir_parser_parse_boxed (ValaGirParser* self) {
 		}
 	}
 	vala_gir_parser_end_element (self, "glib:boxed");
-	return st;
+	_tmp7 = NULL;
+	return (_tmp7 = st, cname = (g_free (cname), NULL), _tmp7);
 }
 
 
@@ -2165,6 +2251,22 @@ ValaGirParser* vala_gir_parser_new (void) {
 }
 
 
+const char* vala_gir_parser_get_package_name (ValaGirParser* self) {
+	g_return_val_if_fail (self != NULL, NULL);
+	return self->priv->_package_name;
+}
+
+
+static void vala_gir_parser_set_package_name (ValaGirParser* self, const char* value) {
+	char* _tmp2;
+	const char* _tmp1;
+	g_return_if_fail (self != NULL);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_package_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_package_name = (g_free (self->priv->_package_name), NULL), _tmp2);
+}
+
+
 static void vala_gir_parser_class_init (ValaGirParserClass * klass) {
 	vala_gir_parser_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_VISITOR_CLASS (klass)->finalize = vala_gir_parser_finalize;
@@ -2182,10 +2284,12 @@ static void vala_gir_parser_instance_init (ValaGirParser * self) {
 static void vala_gir_parser_finalize (ValaCodeVisitor* obj) {
 	ValaGirParser * self;
 	self = VALA_GIR_PARSER (obj);
+	self->priv->_package_name = (g_free (self->priv->_package_name), NULL);
 	(self->priv->reader == NULL) ? NULL : (self->priv->reader = (g_object_unref (self->priv->reader), NULL));
 	(self->priv->context == NULL) ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL));
 	(self->priv->glib_ns == NULL) ? NULL : (self->priv->glib_ns = (vala_code_node_unref (self->priv->glib_ns), NULL));
 	(self->priv->current_source_file == NULL) ? NULL : (self->priv->current_source_file = (vala_source_file_unref (self->priv->current_source_file), NULL));
+	self->priv->cheader_filenames = (_vala_array_free (self->priv->cheader_filenames, self->priv->cheader_filenames_length1, (GDestroyNotify) g_free), NULL);
 	(self->priv->attributes_map == NULL) ? NULL : (self->priv->attributes_map = (gee_collection_object_unref (self->priv->attributes_map), NULL));
 	VALA_CODE_VISITOR_CLASS (vala_gir_parser_parent_class)->finalize (obj);
 }
