@@ -21,12 +21,8 @@
  */
 
 #include <vapigen/valavapicheck.h>
-#include <vala/valacodecontext.h>
-#include <vala/valasourcefile.h>
 #include <gee/list.h>
 #include <gee/set.h>
-#include <stdlib.h>
-#include <string.h>
 #include <gee/arraylist.h>
 #include <gee/hashset.h>
 #include <gidlparser.h>
@@ -39,26 +35,6 @@
 #include <glib/gstdio.h>
 
 
-#define VALA_TYPE_VAPI_CHECK (vala_vapi_check_get_type ())
-#define VALA_VAPI_CHECK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VAPI_CHECK, ValaVAPICheck))
-#define VALA_VAPI_CHECK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_VAPI_CHECK, ValaVAPICheckClass))
-#define VALA_IS_VAPI_CHECK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_VAPI_CHECK))
-#define VALA_IS_VAPI_CHECK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VAPI_CHECK))
-#define VALA_VAPI_CHECK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VAPI_CHECK, ValaVAPICheckClass))
-
-typedef struct _ValaVAPICheck ValaVAPICheck;
-typedef struct _ValaVAPICheckClass ValaVAPICheckClass;
-typedef struct _ValaVAPICheckPrivate ValaVAPICheckPrivate;
-
-struct _ValaVAPICheck {
-	GObject parent_instance;
-	ValaVAPICheckPrivate * priv;
-};
-
-struct _ValaVAPICheckClass {
-	GObjectClass parent_class;
-};
-
 
 
 static char* string_substring (const char* self, glong offset, glong len);
@@ -77,8 +53,6 @@ enum  {
 	VALA_VAPI_CHECK_GIDL,
 	VALA_VAPI_CHECK_METADATA
 };
-static ValaVAPICheck* vala_vapi_check_construct (GType object_type, const char* gidlname, ValaCodeContext* context);
-static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context);
 static void _g_list_free_g_idl_module_free (GList* self);
 static void vala_vapi_check_parse_gidl (ValaVAPICheck* self);
 static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, const char* separator);
@@ -87,17 +61,12 @@ static void vala_vapi_check_enter_scope (ValaVAPICheck* self, const char* name);
 static void vala_vapi_check_leave_scope (ValaVAPICheck* self);
 static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name, GList* members);
 static gint vala_vapi_check_check_metadata (ValaVAPICheck* self);
-static gint vala_vapi_check_run (ValaVAPICheck* self);
 static gint vala_vapi_check_main (char** args, int args_length1);
-static ValaCodeContext* vala_vapi_check_get_context (ValaVAPICheck* self);
 static void vala_vapi_check_set_context (ValaVAPICheck* self, ValaCodeContext* value);
-static ValaSourceFile* vala_vapi_check_get_gidl (ValaVAPICheck* self);
 static void vala_vapi_check_set_gidl (ValaVAPICheck* self, ValaSourceFile* value);
-static ValaSourceFile* vala_vapi_check_get_metadata (ValaVAPICheck* self);
 static void vala_vapi_check_set_metadata (ValaVAPICheck* self, ValaSourceFile* value);
 static gpointer vala_vapi_check_parent_class = NULL;
 static void vala_vapi_check_finalize (GObject* obj);
-static GType vala_vapi_check_get_type (void);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static gint _vala_array_length (gpointer array);
 
@@ -123,7 +92,7 @@ static char* string_substring (const char* self, glong offset, glong len) {
 }
 
 
-static ValaVAPICheck* vala_vapi_check_construct (GType object_type, const char* gidlname, ValaCodeContext* context) {
+ValaVAPICheck* vala_vapi_check_construct (GType object_type, const char* gidlname, ValaCodeContext* context) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaSourceFile* _tmp1;
@@ -168,7 +137,7 @@ static ValaVAPICheck* vala_vapi_check_construct (GType object_type, const char*
 }
 
 
-static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context) {
+ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context) {
 	return vala_vapi_check_construct (VALA_TYPE_VAPI_CHECK, gidlname, context);
 }
 
@@ -407,7 +376,7 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 				_tmp8 = (g_free (_tmp8), NULL);
 				(src == NULL) ? NULL : (src = (vala_source_reference_unref (src), NULL));
 			}
-			lineno = lineno + (1);
+			lineno = lineno + 1;
 			tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
 			symbol = (g_free (symbol), NULL);
 		}
@@ -437,7 +406,7 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 }
 
 
-static gint vala_vapi_check_run (ValaVAPICheck* self) {
+gint vala_vapi_check_run (ValaVAPICheck* self) {
 	g_return_val_if_fail (self != NULL, 0);
 	if (!g_file_test (vala_source_file_get_filename (self->priv->_gidl), G_FILE_TEST_IS_REGULAR)) {
 		char* _tmp0;
@@ -490,7 +459,7 @@ int main (int argc, char ** argv) {
 }
 
 
-static ValaCodeContext* vala_vapi_check_get_context (ValaVAPICheck* self) {
+ValaCodeContext* vala_vapi_check_get_context (ValaVAPICheck* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_context;
 }
@@ -507,7 +476,7 @@ static void vala_vapi_check_set_context (ValaVAPICheck* self, ValaCodeContext* v
 }
 
 
-static ValaSourceFile* vala_vapi_check_get_gidl (ValaVAPICheck* self) {
+ValaSourceFile* vala_vapi_check_get_gidl (ValaVAPICheck* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_gidl;
 }
@@ -524,7 +493,7 @@ static void vala_vapi_check_set_gidl (ValaVAPICheck* self, ValaSourceFile* value
 }
 
 
-static ValaSourceFile* vala_vapi_check_get_metadata (ValaVAPICheck* self) {
+ValaSourceFile* vala_vapi_check_get_metadata (ValaVAPICheck* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_metadata;
 }
@@ -611,7 +580,7 @@ static void vala_vapi_check_finalize (GObject* obj) {
 }
 
 
-static GType vala_vapi_check_get_type (void) {
+GType vala_vapi_check_get_type (void) {
 	static GType vala_vapi_check_type_id = 0;
 	if (vala_vapi_check_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPICheckClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_check_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPICheck), 0, (GInstanceInitFunc) vala_vapi_check_instance_init, NULL };
